# -*- coding: utf-8
    
# this file is generated by:
# chncal.constant_creator.trade_dates.create_trade_dates_constant

from __future__ import absolute_import, unicode_literals

import datetime


# 支持查交易日历的交易所的最早交易日期
# TODO: 目前交易所首个交易日以tushare交易日历数据最早的日期为准，待查证准确的日期
MARKETS = {
    'SSE': datetime.date(1990, 12, 19),  # 上交所
    'SZSE': datetime.date(1991, 7, 3),  # 深交所
    'CFFEX': datetime.date(2006, 9, 8),  # 中金所
    'SHFE': datetime.date(1991, 5, 28),  # 上期所
    'CZCE': datetime.date(1990, 10, 12),  # 郑商所
    'DCE': datetime.date(1993, 3, 1),  # 大商所
    'INE': datetime.date(2017, 5, 23),  # 上能源
}


trade_dates = {
    ('CFFEX', datetime.date(year=2006, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=9)): 0,
    ('CFFEX', datetime.date(year=2006, month=9, day=10)): 0,
    ('CFFEX', datetime.date(year=2006, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2006, month=9, day=17)): 0,
    ('CFFEX', datetime.date(year=2006, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2006, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2006, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2006, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=14)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=15)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=21)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=22)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=28)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=29)): 0,
    ('CFFEX', datetime.date(year=2006, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2006, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=4)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=5)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=11)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=12)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=18)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=19)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=25)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=26)): 0,
    ('CFFEX', datetime.date(year=2006, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2006, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=2)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=3)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=9)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=10)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=16)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=17)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=23)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=24)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2006, month=12, day=30)): 0,
    ('CFFEX', datetime.date(year=2006, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=6)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=7)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=13)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=14)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=20)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=21)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2007, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=22)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=25)): 0,
    ('CFFEX', datetime.date(year=2007, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=4)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=10)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=11)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=17)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=18)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=24)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=25)): 0,
    ('CFFEX', datetime.date(year=2007, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=3, day=31)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=4)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=8)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=14)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=15)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=21)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=22)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=4, day=28)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=29)): 0,
    ('CFFEX', datetime.date(year=2007, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=6)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=7)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=12)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=13)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=19)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=20)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=26)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=27)): 0,
    ('CFFEX', datetime.date(year=2007, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=17)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=24)): 0,
    ('CFFEX', datetime.date(year=2007, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=6, day=30)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=7)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=8)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=14)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=15)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=21)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=22)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=28)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=29)): 0,
    ('CFFEX', datetime.date(year=2007, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=4)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=5)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=11)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=12)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=18)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=19)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=25)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=26)): 0,
    ('CFFEX', datetime.date(year=2007, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=2)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=8)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=9)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=22)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2007, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=13)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=14)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=20)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=21)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=27)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=28)): 0,
    ('CFFEX', datetime.date(year=2007, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=3)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=4)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=10)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=11)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=17)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=18)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=24)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=25)): 0,
    ('CFFEX', datetime.date(year=2007, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2007, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=1)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=2)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=8)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=9)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=15)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=16)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=22)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=23)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2007, month=12, day=29)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=30)): 0,
    ('CFFEX', datetime.date(year=2007, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=2)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=5)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=6)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=12)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=13)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=19)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=20)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2008, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2008, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=2, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=1)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=2)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=8)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=9)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=15)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=16)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=22)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=23)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=3, day=29)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=30)): 0,
    ('CFFEX', datetime.date(year=2008, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=12)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=13)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=19)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=20)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=26)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=27)): 0,
    ('CFFEX', datetime.date(year=2008, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=10)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=11)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=17)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=18)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=24)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=25)): 0,
    ('CFFEX', datetime.date(year=2008, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=5, day=31)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=1)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=7)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=8)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=15)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=21)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=6, day=28)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=29)): 0,
    ('CFFEX', datetime.date(year=2008, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=5)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=6)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=12)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=13)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=19)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=20)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=26)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=27)): 0,
    ('CFFEX', datetime.date(year=2008, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=2)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=3)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=9)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=10)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=16)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=17)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=23)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=24)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=8, day=30)): 0,
    ('CFFEX', datetime.date(year=2008, month=8, day=31)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=6)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=7)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=13)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=14)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=21)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=9, day=27)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=28)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2008, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=6)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=11)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=12)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=18)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=19)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=25)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=26)): 0,
    ('CFFEX', datetime.date(year=2008, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=1)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=2)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=8)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=9)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=15)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=16)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=22)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=23)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2008, month=11, day=29)): 0,
    ('CFFEX', datetime.date(year=2008, month=11, day=30)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=6)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=7)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=13)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=14)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=20)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=21)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=27)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=28)): 0,
    ('CFFEX', datetime.date(year=2008, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2008, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=4)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=10)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=11)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=17)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=18)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=25)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2009, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=22)): 0,
    ('CFFEX', datetime.date(year=2009, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=2, day=28)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=7)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=8)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=14)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=15)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=21)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=22)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=28)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=29)): 0,
    ('CFFEX', datetime.date(year=2009, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=11)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=12)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=18)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=19)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=25)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=26)): 0,
    ('CFFEX', datetime.date(year=2009, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2009, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=9)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=10)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=16)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=17)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=23)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=24)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=5, day=28)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=30)): 0,
    ('CFFEX', datetime.date(year=2009, month=5, day=31)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=6)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=7)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=13)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=20)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=21)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=27)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=28)): 0,
    ('CFFEX', datetime.date(year=2009, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2009, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=4)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=5)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=11)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=12)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=18)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=19)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=25)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=26)): 0,
    ('CFFEX', datetime.date(year=2009, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=2)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=8)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=9)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=15)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=16)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=22)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=23)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2009, month=8, day=29)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=30)): 0,
    ('CFFEX', datetime.date(year=2009, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=5)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=6)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=13)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=19)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=26)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=27)): 0,
    ('CFFEX', datetime.date(year=2009, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2009, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=10)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=11)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=17)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=18)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=24)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=25)): 0,
    ('CFFEX', datetime.date(year=2009, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=10, day=31)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=1)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=7)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=8)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=14)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=15)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=21)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=22)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2009, month=11, day=28)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=29)): 0,
    ('CFFEX', datetime.date(year=2009, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=5)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=6)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=12)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=13)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=19)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=20)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=26)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=27)): 0,
    ('CFFEX', datetime.date(year=2009, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2009, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=9)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=10)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=16)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=17)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2010, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=2, day=27)): 0,
    ('CFFEX', datetime.date(year=2010, month=2, day=28)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=6)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=7)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=13)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=14)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=20)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=21)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=27)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=28)): 0,
    ('CFFEX', datetime.date(year=2010, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=10)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=11)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=17)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=18)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=24)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=25)): 0,
    ('CFFEX', datetime.date(year=2010, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=8)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=9)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=15)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=16)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=22)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=23)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=30)): 0,
    ('CFFEX', datetime.date(year=2010, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=5)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=6)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=12)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=13)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=15)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=19)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=20)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=26)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=27)): 0,
    ('CFFEX', datetime.date(year=2010, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=3)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=4)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=10)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=11)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=17)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=18)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=24)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=25)): 0,
    ('CFFEX', datetime.date(year=2010, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=7, day=31)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=1)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=7)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=8)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=14)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=15)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=21)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=22)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=28)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=29)): 0,
    ('CFFEX', datetime.date(year=2010, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=4)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=5)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=11)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=18)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=19)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=22)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=25)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=26)): 0,
    ('CFFEX', datetime.date(year=2010, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=9)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=10)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=16)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=17)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=23)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=24)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=10, day=30)): 0,
    ('CFFEX', datetime.date(year=2010, month=10, day=31)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=6)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=7)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=13)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=14)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=20)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=21)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=27)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=28)): 0,
    ('CFFEX', datetime.date(year=2010, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=4)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=5)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=11)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=12)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=18)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=19)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=25)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=26)): 0,
    ('CFFEX', datetime.date(year=2010, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2010, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=8)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=9)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=15)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=16)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=22)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2011, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=2, day=26)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=27)): 0,
    ('CFFEX', datetime.date(year=2011, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=5)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=6)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=12)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=13)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=19)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=20)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=26)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=27)): 0,
    ('CFFEX', datetime.date(year=2011, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=2)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=9)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=10)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=16)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=17)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=23)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=24)): 0,
    ('CFFEX', datetime.date(year=2011, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=3)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=7)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=8)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=14)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=15)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=21)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=22)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=28)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2011, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=4)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=5)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=6)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=11)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=12)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=18)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=19)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=25)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=26)): 0,
    ('CFFEX', datetime.date(year=2011, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=2)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=9)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=10)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=16)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=17)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=23)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=24)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=7, day=30)): 0,
    ('CFFEX', datetime.date(year=2011, month=7, day=31)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=6)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=7)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=13)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=14)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=20)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=21)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=27)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=28)): 0,
    ('CFFEX', datetime.date(year=2011, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=4)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=10)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=11)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=17)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=18)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=25)): 0,
    ('CFFEX', datetime.date(year=2011, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=9)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=15)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=16)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=22)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=23)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=10, day=29)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=30)): 0,
    ('CFFEX', datetime.date(year=2011, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=5)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=6)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=12)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=13)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=19)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=20)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=26)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=27)): 0,
    ('CFFEX', datetime.date(year=2011, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=3)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=4)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=10)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=11)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=17)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=18)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=24)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=25)): 0,
    ('CFFEX', datetime.date(year=2011, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2011, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=7)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=8)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=14)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=15)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=21)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=22)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=25)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2012, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=25)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=26)): 0,
    ('CFFEX', datetime.date(year=2012, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=2, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=3)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=4)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=10)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=11)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=17)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=18)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=24)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=25)): 0,
    ('CFFEX', datetime.date(year=2012, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=3, day=31)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=2)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=8)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=14)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=15)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=21)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=22)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=4, day=28)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=29)): 0,
    ('CFFEX', datetime.date(year=2012, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=2)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=3)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=6)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=12)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=13)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=19)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=20)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=26)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=27)): 0,
    ('CFFEX', datetime.date(year=2012, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=3)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=17)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=24)): 0,
    ('CFFEX', datetime.date(year=2012, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=6, day=30)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=7)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=8)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=14)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=15)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=21)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=22)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=28)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=29)): 0,
    ('CFFEX', datetime.date(year=2012, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=4)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=5)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=11)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=12)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=18)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=19)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=25)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=26)): 0,
    ('CFFEX', datetime.date(year=2012, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=2)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=8)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=9)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=22)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2012, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=13)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=14)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=20)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=21)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=27)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=28)): 0,
    ('CFFEX', datetime.date(year=2012, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=3)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=4)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=10)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=11)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=17)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=18)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=24)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=25)): 0,
    ('CFFEX', datetime.date(year=2012, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2012, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=1)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=2)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=8)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=9)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=15)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=16)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=22)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=23)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2012, month=12, day=29)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=30)): 0,
    ('CFFEX', datetime.date(year=2012, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=5)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=6)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=12)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=13)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=19)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=20)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2013, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2013, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=2)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=3)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=9)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=10)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=16)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=17)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=23)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=24)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=3, day=30)): 0,
    ('CFFEX', datetime.date(year=2013, month=3, day=31)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=13)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=14)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=20)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=21)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=4, day=27)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=28)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=29)): 0,
    ('CFFEX', datetime.date(year=2013, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=2)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=3)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=11)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=12)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=18)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=19)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=25)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=26)): 0,
    ('CFFEX', datetime.date(year=2013, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=1)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=8)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=11)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=12)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=15)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=6, day=29)): 0,
    ('CFFEX', datetime.date(year=2013, month=6, day=30)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=6)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=7)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=13)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=14)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=20)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=21)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=27)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=28)): 0,
    ('CFFEX', datetime.date(year=2013, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=3)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=4)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=10)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=11)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=17)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=18)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=24)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=25)): 0,
    ('CFFEX', datetime.date(year=2013, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=8, day=31)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=1)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=7)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=8)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=14)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=19)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=21)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=22)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=9, day=28)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2013, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=12)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=13)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=19)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=20)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=26)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=27)): 0,
    ('CFFEX', datetime.date(year=2013, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=2)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=3)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=9)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=10)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=16)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=17)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=23)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=24)): 0,
    ('CFFEX', datetime.date(year=2013, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2013, month=11, day=30)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=1)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=7)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=8)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=14)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=15)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=21)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=22)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=28)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=29)): 0,
    ('CFFEX', datetime.date(year=2013, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2013, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=2)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=4)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=5)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=11)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=12)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=18)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=19)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=25)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2014, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=22)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2014, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=8)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=9)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=15)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=16)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=22)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=23)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=3, day=29)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=30)): 0,
    ('CFFEX', datetime.date(year=2014, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=12)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=13)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=19)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=20)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=26)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=27)): 0,
    ('CFFEX', datetime.date(year=2014, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=10)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=11)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=17)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=18)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=24)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=25)): 0,
    ('CFFEX', datetime.date(year=2014, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=5, day=31)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=7)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=8)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=15)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=21)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=6, day=28)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=29)): 0,
    ('CFFEX', datetime.date(year=2014, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=5)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=6)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=12)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=13)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=19)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=20)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=26)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=27)): 0,
    ('CFFEX', datetime.date(year=2014, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=3)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=9)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=10)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=16)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=17)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=23)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=24)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=8, day=30)): 0,
    ('CFFEX', datetime.date(year=2014, month=8, day=31)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=6)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=7)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=8)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=13)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=14)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=21)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=27)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=28)): 0,
    ('CFFEX', datetime.date(year=2014, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=11)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=12)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=18)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=19)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=25)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=26)): 0,
    ('CFFEX', datetime.date(year=2014, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=1)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=2)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=8)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=9)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=15)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=16)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=22)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=23)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2014, month=11, day=29)): 0,
    ('CFFEX', datetime.date(year=2014, month=11, day=30)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=6)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=7)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=13)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=14)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=20)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=21)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=27)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=28)): 0,
    ('CFFEX', datetime.date(year=2014, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2014, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=4)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=10)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=11)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=17)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=18)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=25)): 0,
    ('CFFEX', datetime.date(year=2015, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=22)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2015, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=2, day=28)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=7)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=8)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=14)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=15)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=21)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=22)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=28)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=29)): 0,
    ('CFFEX', datetime.date(year=2015, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=11)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=12)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=18)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=19)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=25)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=26)): 0,
    ('CFFEX', datetime.date(year=2015, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=9)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=10)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=16)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=17)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=23)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=24)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=5, day=30)): 0,
    ('CFFEX', datetime.date(year=2015, month=5, day=31)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=6)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=7)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=13)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=20)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=21)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=27)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=28)): 0,
    ('CFFEX', datetime.date(year=2015, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=4)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=5)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=11)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=12)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=18)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=19)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=25)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=26)): 0,
    ('CFFEX', datetime.date(year=2015, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=2)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=8)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=9)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=15)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=16)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=22)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=23)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=8, day=29)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=30)): 0,
    ('CFFEX', datetime.date(year=2015, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=3)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=4)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=5)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=6)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=13)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=19)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=26)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=27)): 0,
    ('CFFEX', datetime.date(year=2015, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=10)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=11)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=17)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=18)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=24)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=25)): 0,
    ('CFFEX', datetime.date(year=2015, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=10, day=31)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=1)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=7)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=8)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=14)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=15)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=21)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=22)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2015, month=11, day=28)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=29)): 0,
    ('CFFEX', datetime.date(year=2015, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=5)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=6)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=12)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=13)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=19)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=20)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=26)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=27)): 0,
    ('CFFEX', datetime.date(year=2015, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2015, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=9)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=16)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=17)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2016, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=2, day=27)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=28)): 0,
    ('CFFEX', datetime.date(year=2016, month=2, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=5)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=6)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=12)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=13)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=19)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=20)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=26)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=27)): 0,
    ('CFFEX', datetime.date(year=2016, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=2)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=9)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=16)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=17)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=23)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=24)): 0,
    ('CFFEX', datetime.date(year=2016, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=3)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=7)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=8)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=14)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=15)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=21)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=22)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=28)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2016, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=4)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=5)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=11)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=12)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=18)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=19)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=25)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=26)): 0,
    ('CFFEX', datetime.date(year=2016, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=2)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=3)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=9)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=16)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=17)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=23)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=24)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=7, day=30)): 0,
    ('CFFEX', datetime.date(year=2016, month=7, day=31)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=6)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=7)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=13)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=14)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=20)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=21)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=27)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=28)): 0,
    ('CFFEX', datetime.date(year=2016, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=3)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=4)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=11)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=17)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=18)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=25)): 0,
    ('CFFEX', datetime.date(year=2016, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=9)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=15)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=16)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=22)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=23)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=10, day=29)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=30)): 0,
    ('CFFEX', datetime.date(year=2016, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=5)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=6)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=12)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=13)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=19)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=20)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=26)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=27)): 0,
    ('CFFEX', datetime.date(year=2016, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=3)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=4)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=10)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=11)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=17)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=18)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=24)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=25)): 0,
    ('CFFEX', datetime.date(year=2016, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2016, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=7)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=8)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=14)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=15)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=21)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=22)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2017, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=1)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=25)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=26)): 0,
    ('CFFEX', datetime.date(year=2017, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=4)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=5)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=11)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=12)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=18)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=19)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=25)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=26)): 0,
    ('CFFEX', datetime.date(year=2017, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2017, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=1)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=8)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=9)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=15)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=16)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=22)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=23)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=4, day=29)): 0,
    ('CFFEX', datetime.date(year=2017, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=2)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=6)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=7)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=13)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=14)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=20)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=21)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=5, day=27)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=28)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=30)): 0,
    ('CFFEX', datetime.date(year=2017, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=3)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=4)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=11)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=17)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=18)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=24)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=25)): 0,
    ('CFFEX', datetime.date(year=2017, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2017, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=1)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=8)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=9)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=15)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=16)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=22)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=23)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=7, day=29)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=30)): 0,
    ('CFFEX', datetime.date(year=2017, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=5)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=6)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=12)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=13)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=19)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=20)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=26)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=27)): 0,
    ('CFFEX', datetime.date(year=2017, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2017, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=3)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=9)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=10)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=17)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2017, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2017, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=14)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=15)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=21)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=22)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=28)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=29)): 0,
    ('CFFEX', datetime.date(year=2017, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2017, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=4)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=5)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=11)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=12)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=18)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=19)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=25)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=26)): 0,
    ('CFFEX', datetime.date(year=2017, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2017, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=2)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=3)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=9)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=10)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=16)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=17)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=23)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=24)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2017, month=12, day=30)): 0,
    ('CFFEX', datetime.date(year=2017, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=6)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=7)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=13)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=14)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=20)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=21)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2018, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=25)): 0,
    ('CFFEX', datetime.date(year=2018, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=3)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=4)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=10)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=11)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=17)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=18)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=24)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=25)): 0,
    ('CFFEX', datetime.date(year=2018, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=3, day=31)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=8)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=14)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=15)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=21)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=22)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=4, day=28)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=29)): 0,
    ('CFFEX', datetime.date(year=2018, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=6)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=12)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=13)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=19)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=20)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=26)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=27)): 0,
    ('CFFEX', datetime.date(year=2018, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=3)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=17)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=18)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=24)): 0,
    ('CFFEX', datetime.date(year=2018, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=6, day=30)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=7)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=8)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=14)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=15)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=21)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=22)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=28)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=29)): 0,
    ('CFFEX', datetime.date(year=2018, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=4)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=5)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=11)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=12)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=18)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=19)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=25)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=26)): 0,
    ('CFFEX', datetime.date(year=2018, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=2)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=8)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=9)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=22)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2018, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=13)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=14)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=20)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=21)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=27)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=28)): 0,
    ('CFFEX', datetime.date(year=2018, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=3)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=4)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=10)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=11)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=17)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=18)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=24)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=25)): 0,
    ('CFFEX', datetime.date(year=2018, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2018, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=1)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=2)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=8)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=9)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=15)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=16)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=22)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=23)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2018, month=12, day=29)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=30)): 0,
    ('CFFEX', datetime.date(year=2018, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=2)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=5)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=6)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=12)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=13)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=19)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=20)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2019, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2019, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=2)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=3)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=9)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=10)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=16)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=17)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=23)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=24)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=3, day=30)): 0,
    ('CFFEX', datetime.date(year=2019, month=3, day=31)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=13)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=14)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=20)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=21)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=27)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=28)): 0,
    ('CFFEX', datetime.date(year=2019, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=11)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=12)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=18)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=19)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=25)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=26)): 0,
    ('CFFEX', datetime.date(year=2019, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=1)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=8)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=15)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=6, day=29)): 0,
    ('CFFEX', datetime.date(year=2019, month=6, day=30)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=6)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=13)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=14)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=20)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=21)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=27)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=28)): 0,
    ('CFFEX', datetime.date(year=2019, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=3)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=4)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=10)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=11)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=17)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=18)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=24)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=25)): 0,
    ('CFFEX', datetime.date(year=2019, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=8, day=31)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=1)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=8)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=13)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=14)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=15)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=21)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=22)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=9, day=28)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2019, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=12)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=13)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=19)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=20)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=26)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=27)): 0,
    ('CFFEX', datetime.date(year=2019, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=2)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=3)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=9)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=10)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=16)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=17)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=23)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=24)): 0,
    ('CFFEX', datetime.date(year=2019, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2019, month=11, day=30)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=1)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=7)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=8)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=14)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=15)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=21)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=22)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=28)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=29)): 0,
    ('CFFEX', datetime.date(year=2019, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2019, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=4)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=11)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=12)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=18)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=19)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=25)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2020, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=8)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=22)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=23)): 0,
    ('CFFEX', datetime.date(year=2020, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=2, day=29)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=7)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=8)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=14)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=15)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=21)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=22)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=28)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=29)): 0,
    ('CFFEX', datetime.date(year=2020, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=11)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=12)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=18)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=19)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=25)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=26)): 0,
    ('CFFEX', datetime.date(year=2020, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=9)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=10)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=16)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=17)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=23)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=24)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=5, day=30)): 0,
    ('CFFEX', datetime.date(year=2020, month=5, day=31)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=6)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=7)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=13)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=20)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=21)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=25)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=26)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=27)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=28)): 0,
    ('CFFEX', datetime.date(year=2020, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=4)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=11)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=12)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=18)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=19)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=25)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=26)): 0,
    ('CFFEX', datetime.date(year=2020, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=2)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=8)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=9)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=15)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=16)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=22)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=23)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=8, day=29)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=30)): 0,
    ('CFFEX', datetime.date(year=2020, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=6)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=13)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=19)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=26)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=27)): 0,
    ('CFFEX', datetime.date(year=2020, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=10)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=11)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=17)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=18)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=24)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=25)): 0,
    ('CFFEX', datetime.date(year=2020, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=10, day=31)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=1)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=7)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=8)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=14)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=15)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=21)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=22)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2020, month=11, day=28)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=29)): 0,
    ('CFFEX', datetime.date(year=2020, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=5)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=6)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=12)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=13)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=19)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=20)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=26)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=27)): 0,
    ('CFFEX', datetime.date(year=2020, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2020, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=9)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=10)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=16)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=17)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2021, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=4)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=7)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=21)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=2, day=27)): 0,
    ('CFFEX', datetime.date(year=2021, month=2, day=28)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=6)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=7)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=13)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=14)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=20)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=21)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=27)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=28)): 0,
    ('CFFEX', datetime.date(year=2021, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=10)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=11)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=17)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=18)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=24)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=25)): 0,
    ('CFFEX', datetime.date(year=2021, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=8)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=9)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=15)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=16)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=22)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=23)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=30)): 0,
    ('CFFEX', datetime.date(year=2021, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=5)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=6)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=12)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=13)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=14)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=19)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=20)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=26)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=27)): 0,
    ('CFFEX', datetime.date(year=2021, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=3)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=4)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=10)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=11)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=17)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=18)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=24)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=25)): 0,
    ('CFFEX', datetime.date(year=2021, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=7, day=31)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=1)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=7)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=8)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=14)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=15)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=21)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=22)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=28)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=29)): 0,
    ('CFFEX', datetime.date(year=2021, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=4)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=5)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=11)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=18)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=19)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=20)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=21)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=25)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=26)): 0,
    ('CFFEX', datetime.date(year=2021, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=9)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=10)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=16)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=17)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=23)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=24)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=10, day=30)): 0,
    ('CFFEX', datetime.date(year=2021, month=10, day=31)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=5)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=6)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=7)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=12)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=13)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=14)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=19)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=20)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=21)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=26)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=27)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=28)): 0,
    ('CFFEX', datetime.date(year=2021, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=3)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=4)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=5)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=10)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=11)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=12)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=17)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=18)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=19)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=24)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=25)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=26)): 0,
    ('CFFEX', datetime.date(year=2021, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2021, month=12, day=31)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=8)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=9)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=15)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=16)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=22)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=30)): 0,
    ('CFFEX', datetime.date(year=2022, month=1, day=31)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=1)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=2)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=6)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=20)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=2, day=26)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=27)): 0,
    ('CFFEX', datetime.date(year=2022, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=5)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=6)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=12)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=13)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=19)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=20)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=26)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=27)): 0,
    ('CFFEX', datetime.date(year=2022, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2022, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=2)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=9)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=10)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=16)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=17)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=23)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=24)): 0,
    ('CFFEX', datetime.date(year=2022, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=7)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=8)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=14)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=15)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=21)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=22)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=28)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=29)): 0,
    ('CFFEX', datetime.date(year=2022, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2022, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=5)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=11)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=12)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=18)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=19)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=25)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=26)): 0,
    ('CFFEX', datetime.date(year=2022, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=2)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=9)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=10)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=16)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=17)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=23)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=24)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=7, day=30)): 0,
    ('CFFEX', datetime.date(year=2022, month=7, day=31)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=5)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=6)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=7)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=13)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=14)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=20)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=21)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=27)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=28)): 0,
    ('CFFEX', datetime.date(year=2022, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2022, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=2)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=10)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=11)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=12)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=17)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=18)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=25)): 0,
    ('CFFEX', datetime.date(year=2022, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=9, day=30)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=9)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=15)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=16)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=22)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=23)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=10, day=29)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=30)): 0,
    ('CFFEX', datetime.date(year=2022, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=4)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=5)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=6)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=11)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=12)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=13)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=18)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=19)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=20)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=25)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=26)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=27)): 0,
    ('CFFEX', datetime.date(year=2022, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=2)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=3)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=4)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=9)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=10)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=11)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=16)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=17)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=18)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=23)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=24)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=25)): 0,
    ('CFFEX', datetime.date(year=2022, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2022, month=12, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=7)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=8)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=14)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=15)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=21)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=22)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=23)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=24)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=25)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=26)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=29)): 0,
    ('CFFEX', datetime.date(year=2023, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=5)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=19)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=25)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=26)): 0,
    ('CFFEX', datetime.date(year=2023, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=2)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=4)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=5)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=11)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=12)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=18)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=19)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=23)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=25)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=26)): 0,
    ('CFFEX', datetime.date(year=2023, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=3, day=31)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=1)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=8)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=9)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=15)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=16)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=22)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=23)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=4, day=29)): 0,
    ('CFFEX', datetime.date(year=2023, month=4, day=30)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=5)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=6)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=7)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=13)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=14)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=20)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=21)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=27)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=28)): 0,
    ('CFFEX', datetime.date(year=2023, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=2)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=3)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=4)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=11)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=17)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=18)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=24)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=25)): 0,
    ('CFFEX', datetime.date(year=2023, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=29)): 1,
    ('CFFEX', datetime.date(year=2023, month=6, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=1)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=8)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=9)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=15)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=16)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=22)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=23)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=7, day=29)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=30)): 0,
    ('CFFEX', datetime.date(year=2023, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=5)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=6)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=12)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=13)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=19)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=20)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=23)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=26)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=27)): 0,
    ('CFFEX', datetime.date(year=2023, month=8, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=29)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=8, day=31)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=3)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=5)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=9)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=10)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=16)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=17)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=23)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=24)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=9, day=29)): 0,
    ('CFFEX', datetime.date(year=2023, month=9, day=30)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=1)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=3)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=4)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=5)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=6)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=7)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=8)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=14)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=15)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=21)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=22)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=23)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=28)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=29)): 0,
    ('CFFEX', datetime.date(year=2023, month=10, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=10, day=31)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=2)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=3)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=4)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=5)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=9)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=10)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=11)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=12)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=16)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=17)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=18)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=19)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=23)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=24)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=25)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=26)): 0,
    ('CFFEX', datetime.date(year=2023, month=11, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=29)): 1,
    ('CFFEX', datetime.date(year=2023, month=11, day=30)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=1)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=2)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=3)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=4)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=5)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=6)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=7)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=8)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=9)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=10)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=11)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=12)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=13)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=14)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=15)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=16)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=17)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=18)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=19)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=20)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=21)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=22)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=23)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=24)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=25)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=26)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=27)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=28)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=29)): 1,
    ('CFFEX', datetime.date(year=2023, month=12, day=30)): 0,
    ('CFFEX', datetime.date(year=2023, month=12, day=31)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=1)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=2)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=3)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=4)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=5)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=6)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=7)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=8)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=9)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=10)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=11)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=12)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=13)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=14)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=15)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=16)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=17)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=18)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=19)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=20)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=21)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=22)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=23)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=24)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=25)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=26)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=27)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=28)): 0,
    ('CFFEX', datetime.date(year=2024, month=1, day=29)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=30)): 1,
    ('CFFEX', datetime.date(year=2024, month=1, day=31)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=1)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=2)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=3)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=4)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=5)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=6)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=7)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=8)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=9)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=10)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=11)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=12)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=13)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=14)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=15)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=16)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=17)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=18)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=19)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=20)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=21)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=22)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=23)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=24)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=25)): 0,
    ('CFFEX', datetime.date(year=2024, month=2, day=26)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=27)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=28)): 1,
    ('CFFEX', datetime.date(year=2024, month=2, day=29)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=1)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=2)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=3)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=4)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=5)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=6)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=7)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=8)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=9)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=10)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=11)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=12)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=13)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=14)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=15)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=16)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=17)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=18)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=19)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=20)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=21)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=22)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=23)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=24)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=25)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=26)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=27)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=28)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=29)): 1,
    ('CFFEX', datetime.date(year=2024, month=3, day=30)): 0,
    ('CFFEX', datetime.date(year=2024, month=3, day=31)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=1)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=2)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=3)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=4)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=5)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=6)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=7)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=8)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=9)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=10)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=11)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=12)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=13)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=14)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=15)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=16)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=17)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=18)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=19)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=20)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=21)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=22)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=23)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=24)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=25)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=26)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=27)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=28)): 0,
    ('CFFEX', datetime.date(year=2024, month=4, day=29)): 1,
    ('CFFEX', datetime.date(year=2024, month=4, day=30)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=1)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=2)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=3)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=4)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=5)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=6)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=7)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=8)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=9)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=10)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=11)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=12)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=13)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=14)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=15)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=16)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=17)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=18)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=19)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=20)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=21)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=22)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=23)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=24)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=25)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=26)): 0,
    ('CFFEX', datetime.date(year=2024, month=5, day=27)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=28)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=29)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=30)): 1,
    ('CFFEX', datetime.date(year=2024, month=5, day=31)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=1)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=2)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=3)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=4)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=5)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=6)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=7)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=8)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=9)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=10)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=11)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=12)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=13)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=14)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=15)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=16)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=17)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=18)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=19)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=20)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=21)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=22)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=23)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=24)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=25)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=26)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=27)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=28)): 1,
    ('CFFEX', datetime.date(year=2024, month=6, day=29)): 0,
    ('CFFEX', datetime.date(year=2024, month=6, day=30)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=1)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=2)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=3)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=4)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=5)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=6)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=7)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=8)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=9)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=10)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=11)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=12)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=13)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=14)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=15)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=16)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=17)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=18)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=19)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=20)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=21)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=22)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=23)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=24)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=25)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=26)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=27)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=28)): 0,
    ('CFFEX', datetime.date(year=2024, month=7, day=29)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=30)): 1,
    ('CFFEX', datetime.date(year=2024, month=7, day=31)): 1,
    ('CFFEX', datetime.date(year=2024, month=8, day=1)): 1,
    ('CFFEX', datetime.date(year=2024, month=8, day=2)): 1,
    ('CFFEX', datetime.date(year=2024, month=8, day=3)): 0,
    ('CFFEX', datetime.date(year=2024, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=1990, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1990, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=1990, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1990, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1990, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=1990, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=1991, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=1991, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=1991, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=1991, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=1991, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=1991, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=1991, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=1991, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=1991, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=1991, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=1991, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1991, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=1991, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1991, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=1992, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=1992, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=2, day=29)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=1992, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=1992, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=1992, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=1992, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=1992, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=1992, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=1992, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=5)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=1992, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1992, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=1992, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=1992, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1992, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=1993, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=1993, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=1993, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=1993, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=1993, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=1993, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=1993, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=1993, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=1993, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=1993, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=1993, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=1993, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1993, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=1994, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=1994, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=1994, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=1994, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=1994, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=1994, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=1994, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=1994, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=1994, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=1994, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=1994, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=1994, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1994, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=1995, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=1995, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=1995, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=1995, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=1995, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=1995, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=1995, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=1995, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=1995, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=1995, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=1995, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=1995, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=1995, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1995, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=1995, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1995, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=1995, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=1996, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=1996, month=2, day=29)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=1996, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=1996, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=1996, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=1996, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=1996, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=1996, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=1996, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=1996, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=1996, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=1996, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1996, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=1996, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1996, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=1997, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=1997, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=1997, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=1997, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=1997, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=1997, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=1997, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=1997, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=1997, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=1997, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=1997, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=1997, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=1997, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1997, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=1998, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=1998, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=1998, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=1998, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=1998, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=1998, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=1998, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=1998, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=1998, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=1998, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=1998, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=1998, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=1998, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1998, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=1999, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=1999, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=1999, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=1999, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=1999, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=1999, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=1999, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=1999, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=1999, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=1999, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=1999, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=1999, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=1999, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2000, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2000, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=2, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2000, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2000, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2000, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2000, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2000, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2000, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2000, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2000, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2000, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2000, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2000, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2000, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2000, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2000, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2000, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2001, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2001, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2001, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2001, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2001, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2001, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2001, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2001, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2001, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2001, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2001, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2001, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2001, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2001, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2001, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2002, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2002, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2002, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2002, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2002, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2002, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2002, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2002, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2002, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2002, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2002, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2002, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2002, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2002, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2003, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2003, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2003, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2003, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2003, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2003, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2003, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=2003, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=2003, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=2003, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2003, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=2003, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=2003, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2003, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2004, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=2004, month=2, day=29)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=2004, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=2004, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2004, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=2004, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=2004, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=2004, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=2004, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2004, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=2004, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=2004, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2004, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2005, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2005, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2005, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2005, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2005, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2005, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2005, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2005, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2005, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2005, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2005, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2005, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2005, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2006, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2006, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2006, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2006, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2006, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2006, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2006, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2006, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2006, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2006, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2006, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2006, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2006, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2006, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2006, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2006, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2006, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2007, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2007, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2007, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2007, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2007, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2007, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2007, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2007, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2007, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2007, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2007, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2007, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2007, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2007, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2008, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2008, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=2, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2008, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2008, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2008, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2008, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2008, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=2008, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2008, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=6)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=2008, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2008, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=2008, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=2008, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2008, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2009, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2009, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=2009, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=2009, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2009, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2009, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=2009, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2009, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=2009, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2009, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=2009, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=2009, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2009, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=2009, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2009, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=2009, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=2009, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2009, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2010, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2010, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=2010, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=2010, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2010, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=2010, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=2010, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=2010, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=2010, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2010, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=2010, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=2010, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2010, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2011, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2011, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2011, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2011, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2011, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2011, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2011, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2011, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2011, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2011, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2011, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2011, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2011, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2012, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2012, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=2, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2012, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2012, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2012, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2012, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2012, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2012, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2012, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2012, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2012, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2012, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2012, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2012, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2013, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2013, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2013, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2013, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2013, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2013, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2013, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2013, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2013, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2013, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2013, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2013, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2013, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2013, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2014, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2014, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2014, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2014, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2014, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2014, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2014, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=2014, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=2014, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=2014, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2014, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=2014, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=2014, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2014, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2015, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2015, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=2015, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=2015, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2015, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=2015, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=2015, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=2015, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=2015, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=2015, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2015, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=2015, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=2015, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2015, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2016, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=2016, month=2, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2016, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2016, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2016, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2016, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2016, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2016, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2016, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2016, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2016, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2016, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2016, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2017, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2017, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2017, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2017, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2017, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2017, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2017, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2017, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2017, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2017, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2017, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2017, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2017, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2017, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2017, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2017, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2017, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2017, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2017, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2018, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2018, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2018, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2018, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2018, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2018, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2018, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2018, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2018, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2018, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2018, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2018, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2018, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2018, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2019, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2019, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2019, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2019, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2019, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2019, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2019, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=4)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=10)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=11)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=17)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=18)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=24)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=25)): 0,
    ('CZCE', datetime.date(year=2019, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=8, day=31)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=1)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=8)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=14)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=15)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=22)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=9, day=28)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2019, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=12)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=13)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=19)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=20)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=26)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=27)): 0,
    ('CZCE', datetime.date(year=2019, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=2)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=3)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=9)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=10)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=16)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=17)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=23)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=24)): 0,
    ('CZCE', datetime.date(year=2019, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2019, month=11, day=30)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=1)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=7)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=8)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=14)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=15)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=21)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=22)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=28)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=29)): 0,
    ('CZCE', datetime.date(year=2019, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2019, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=4)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=11)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=12)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=18)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=19)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2020, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=8)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=22)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=23)): 0,
    ('CZCE', datetime.date(year=2020, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=2, day=29)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=8)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=15)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=22)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=29)): 0,
    ('CZCE', datetime.date(year=2020, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=12)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=19)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=26)): 0,
    ('CZCE', datetime.date(year=2020, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=10)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=17)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=24)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2020, month=5, day=31)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=7)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=21)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=28)): 0,
    ('CZCE', datetime.date(year=2020, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=12)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=19)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=26)): 0,
    ('CZCE', datetime.date(year=2020, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=2)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=9)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=16)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=23)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=30)): 0,
    ('CZCE', datetime.date(year=2020, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=6)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=13)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=27)): 0,
    ('CZCE', datetime.date(year=2020, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=11)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=18)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=25)): 0,
    ('CZCE', datetime.date(year=2020, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=1)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=8)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=15)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=22)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2020, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=29)): 0,
    ('CZCE', datetime.date(year=2020, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=6)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=13)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=20)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=27)): 0,
    ('CZCE', datetime.date(year=2020, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2020, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=10)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=17)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2021, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=4)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=7)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=21)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2021, month=2, day=28)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=7)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=14)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=21)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=28)): 0,
    ('CZCE', datetime.date(year=2021, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=11)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=18)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=25)): 0,
    ('CZCE', datetime.date(year=2021, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=9)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=16)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=23)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=30)): 0,
    ('CZCE', datetime.date(year=2021, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=6)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=13)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=14)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=20)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=27)): 0,
    ('CZCE', datetime.date(year=2021, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=4)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=11)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=18)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=25)): 0,
    ('CZCE', datetime.date(year=2021, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=1)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=8)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=15)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=22)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=29)): 0,
    ('CZCE', datetime.date(year=2021, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=5)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=19)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=20)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=21)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=26)): 0,
    ('CZCE', datetime.date(year=2021, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=10)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=17)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=24)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2021, month=10, day=31)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=5)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=7)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=12)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=14)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=19)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=21)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=26)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=28)): 0,
    ('CZCE', datetime.date(year=2021, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=3)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=5)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=10)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=12)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=17)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=19)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=24)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=26)): 0,
    ('CZCE', datetime.date(year=2021, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2021, month=12, day=31)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=9)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=16)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=30)): 0,
    ('CZCE', datetime.date(year=2022, month=1, day=31)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=1)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=2)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=6)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=20)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=27)): 0,
    ('CZCE', datetime.date(year=2022, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=6)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=13)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=20)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=27)): 0,
    ('CZCE', datetime.date(year=2022, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2022, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=10)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=17)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=24)): 0,
    ('CZCE', datetime.date(year=2022, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=8)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=15)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=22)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=29)): 0,
    ('CZCE', datetime.date(year=2022, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2022, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=5)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=12)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=19)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=26)): 0,
    ('CZCE', datetime.date(year=2022, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=10)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=17)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=24)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2022, month=7, day=31)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=5)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=7)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=14)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=21)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=28)): 0,
    ('CZCE', datetime.date(year=2022, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2022, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=2)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=11)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=12)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=18)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=25)): 0,
    ('CZCE', datetime.date(year=2022, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=9, day=30)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=9)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=16)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=23)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=30)): 0,
    ('CZCE', datetime.date(year=2022, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=4)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=6)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=11)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=13)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=18)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=20)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=25)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=27)): 0,
    ('CZCE', datetime.date(year=2022, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=2)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=4)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=9)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=11)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=16)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=18)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=23)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=25)): 0,
    ('CZCE', datetime.date(year=2022, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2022, month=12, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=8)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=15)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=22)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=23)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=24)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=25)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=26)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=29)): 0,
    ('CZCE', datetime.date(year=2023, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=5)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=19)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=26)): 0,
    ('CZCE', datetime.date(year=2023, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=2)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=4)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=5)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=11)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=12)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=18)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=19)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=23)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=25)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=26)): 0,
    ('CZCE', datetime.date(year=2023, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=3, day=31)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=1)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=8)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=9)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=15)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=16)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=22)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=23)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=4, day=29)): 0,
    ('CZCE', datetime.date(year=2023, month=4, day=30)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=5)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=6)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=7)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=13)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=14)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=20)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=21)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=27)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=28)): 0,
    ('CZCE', datetime.date(year=2023, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=2)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=3)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=4)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=11)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=17)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=18)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=24)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=25)): 0,
    ('CZCE', datetime.date(year=2023, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=29)): 1,
    ('CZCE', datetime.date(year=2023, month=6, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=1)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=8)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=9)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=15)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=16)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=22)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=23)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=7, day=29)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=30)): 0,
    ('CZCE', datetime.date(year=2023, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=5)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=6)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=12)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=13)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=19)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=20)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=23)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=26)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=27)): 0,
    ('CZCE', datetime.date(year=2023, month=8, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=29)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=8, day=31)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=3)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=5)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=9)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=10)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=16)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=17)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=23)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=24)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=9, day=29)): 0,
    ('CZCE', datetime.date(year=2023, month=9, day=30)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=1)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=3)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=4)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=5)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=6)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=7)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=8)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=14)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=15)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=21)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=22)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=23)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=28)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=29)): 0,
    ('CZCE', datetime.date(year=2023, month=10, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=10, day=31)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=2)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=3)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=4)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=5)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=9)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=10)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=11)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=12)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=16)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=17)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=18)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=19)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=23)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=24)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=25)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=26)): 0,
    ('CZCE', datetime.date(year=2023, month=11, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=29)): 1,
    ('CZCE', datetime.date(year=2023, month=11, day=30)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=1)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=2)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=3)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=4)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=5)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=6)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=7)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=8)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=9)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=10)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=11)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=12)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=13)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=14)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=15)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=16)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=17)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=18)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=19)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=20)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=21)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=22)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=23)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=24)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=25)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=26)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=27)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=28)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=29)): 1,
    ('CZCE', datetime.date(year=2023, month=12, day=30)): 0,
    ('CZCE', datetime.date(year=2023, month=12, day=31)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=1)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=2)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=3)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=4)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=5)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=6)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=7)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=8)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=9)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=10)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=11)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=12)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=13)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=14)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=15)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=16)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=17)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=18)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=19)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=20)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=21)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=22)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=23)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=24)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=25)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=26)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=27)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=28)): 0,
    ('CZCE', datetime.date(year=2024, month=1, day=29)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=30)): 1,
    ('CZCE', datetime.date(year=2024, month=1, day=31)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=1)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=2)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=3)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=4)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=5)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=6)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=7)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=8)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=9)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=10)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=11)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=12)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=13)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=14)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=15)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=16)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=17)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=18)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=19)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=20)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=21)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=22)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=23)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=24)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=25)): 0,
    ('CZCE', datetime.date(year=2024, month=2, day=26)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=27)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=28)): 1,
    ('CZCE', datetime.date(year=2024, month=2, day=29)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=1)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=2)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=3)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=4)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=5)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=6)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=7)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=8)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=9)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=10)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=11)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=12)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=13)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=14)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=15)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=16)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=17)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=18)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=19)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=20)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=21)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=22)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=23)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=24)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=25)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=26)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=27)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=28)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=29)): 1,
    ('CZCE', datetime.date(year=2024, month=3, day=30)): 0,
    ('CZCE', datetime.date(year=2024, month=3, day=31)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=1)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=2)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=3)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=4)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=5)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=6)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=7)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=8)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=9)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=10)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=11)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=12)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=13)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=14)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=15)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=16)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=17)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=18)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=19)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=20)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=21)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=22)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=23)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=24)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=25)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=26)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=27)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=28)): 0,
    ('CZCE', datetime.date(year=2024, month=4, day=29)): 1,
    ('CZCE', datetime.date(year=2024, month=4, day=30)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=1)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=2)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=3)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=4)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=5)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=6)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=7)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=8)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=9)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=10)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=11)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=12)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=13)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=14)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=15)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=16)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=17)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=18)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=19)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=20)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=21)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=22)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=23)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=24)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=25)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=26)): 0,
    ('CZCE', datetime.date(year=2024, month=5, day=27)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=28)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=29)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=30)): 1,
    ('CZCE', datetime.date(year=2024, month=5, day=31)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=1)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=2)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=3)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=4)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=5)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=6)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=7)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=8)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=9)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=10)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=11)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=12)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=13)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=14)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=15)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=16)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=17)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=18)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=19)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=20)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=21)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=22)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=23)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=24)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=25)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=26)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=27)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=28)): 1,
    ('CZCE', datetime.date(year=2024, month=6, day=29)): 0,
    ('CZCE', datetime.date(year=2024, month=6, day=30)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=1)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=2)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=3)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=4)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=5)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=6)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=7)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=8)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=9)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=10)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=11)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=12)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=13)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=14)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=15)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=16)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=17)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=18)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=19)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=20)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=21)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=22)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=23)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=24)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=25)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=26)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=27)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=28)): 0,
    ('CZCE', datetime.date(year=2024, month=7, day=29)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=30)): 1,
    ('CZCE', datetime.date(year=2024, month=7, day=31)): 1,
    ('CZCE', datetime.date(year=2024, month=8, day=1)): 1,
    ('CZCE', datetime.date(year=2024, month=8, day=2)): 1,
    ('CZCE', datetime.date(year=2024, month=8, day=3)): 0,
    ('CZCE', datetime.date(year=2024, month=8, day=4)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=4)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=6)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=7)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=11)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=13)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=14)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=18)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=20)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=21)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=25)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=27)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=28)): 0,
    ('DCE', datetime.date(year=1993, month=3, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=3, day=31)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=3)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=4)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=10)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=11)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=17)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=18)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=24)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=25)): 0,
    ('DCE', datetime.date(year=1993, month=4, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=4, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=2)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=4)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=8)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=9)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=11)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=15)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=16)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=18)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=22)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=23)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=25)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=5, day=29)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=30)): 0,
    ('DCE', datetime.date(year=1993, month=5, day=31)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=4)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=5)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=6)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=11)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=12)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=13)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=18)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=19)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=20)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=25)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=26)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=27)): 0,
    ('DCE', datetime.date(year=1993, month=6, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=6, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=3)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=4)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=10)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=11)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=17)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=18)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=24)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=25)): 0,
    ('DCE', datetime.date(year=1993, month=7, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=7, day=31)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=1)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=4)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=7)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=8)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=11)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=14)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=15)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=18)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=21)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=22)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=25)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=28)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=29)): 0,
    ('DCE', datetime.date(year=1993, month=8, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=8, day=31)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=4)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=5)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=11)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=12)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=18)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=19)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=25)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=26)): 0,
    ('DCE', datetime.date(year=1993, month=9, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=9, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=3)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=4)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=9)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=10)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=11)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=16)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=17)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=18)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=23)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=24)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=25)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=10, day=30)): 0,
    ('DCE', datetime.date(year=1993, month=10, day=31)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=4)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=5)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=6)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=7)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=11)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=12)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=13)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=14)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=18)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=19)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=20)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=21)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=25)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=26)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=27)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=28)): 0,
    ('DCE', datetime.date(year=1993, month=11, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=11, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=1)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=2)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=3)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=4)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=5)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=6)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=7)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=8)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=9)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=10)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=11)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=12)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=13)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=14)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=15)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=16)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=17)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=18)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=19)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=20)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=21)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=22)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=23)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=24)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=25)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=26)): 0,
    ('DCE', datetime.date(year=1993, month=12, day=27)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=28)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=29)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=30)): 1,
    ('DCE', datetime.date(year=1993, month=12, day=31)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=1)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=2)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=8)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=9)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=15)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=16)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=22)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=23)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=1, day=29)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=30)): 0,
    ('DCE', datetime.date(year=1994, month=1, day=31)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=5)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=6)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=7)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=8)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=9)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=10)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=11)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=12)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=13)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=19)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=20)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=2, day=26)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=27)): 0,
    ('DCE', datetime.date(year=1994, month=2, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=5)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=6)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=12)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=13)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=19)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=20)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=26)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=27)): 0,
    ('DCE', datetime.date(year=1994, month=3, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=3, day=31)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=2)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=3)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=9)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=10)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=16)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=17)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=23)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=24)): 0,
    ('DCE', datetime.date(year=1994, month=4, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=4, day=30)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=2)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=7)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=8)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=14)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=15)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=21)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=22)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=28)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=29)): 0,
    ('DCE', datetime.date(year=1994, month=5, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=5, day=31)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=4)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=5)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=11)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=12)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=18)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=19)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=25)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=26)): 0,
    ('DCE', datetime.date(year=1994, month=6, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=6, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=2)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=3)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=9)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=10)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=16)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=17)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=23)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=24)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=7, day=30)): 0,
    ('DCE', datetime.date(year=1994, month=7, day=31)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=6)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=7)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=13)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=14)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=20)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=21)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=27)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=28)): 0,
    ('DCE', datetime.date(year=1994, month=8, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=8, day=31)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=3)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=4)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=10)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=11)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=17)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=18)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=24)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=25)): 0,
    ('DCE', datetime.date(year=1994, month=9, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=9, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=3)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=4)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=8)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=9)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=15)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=16)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=22)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=23)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=10, day=29)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=30)): 0,
    ('DCE', datetime.date(year=1994, month=10, day=31)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=3)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=4)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=5)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=6)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=10)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=11)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=12)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=13)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=17)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=18)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=19)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=20)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=24)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=25)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=26)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=27)): 0,
    ('DCE', datetime.date(year=1994, month=11, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=11, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=1)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=2)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=3)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=4)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=5)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=6)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=7)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=8)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=9)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=10)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=11)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=12)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=13)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=14)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=15)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=16)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=17)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=18)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=19)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=20)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=21)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=22)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=23)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=24)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=25)): 0,
    ('DCE', datetime.date(year=1994, month=12, day=26)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=27)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=28)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=29)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=30)): 1,
    ('DCE', datetime.date(year=1994, month=12, day=31)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=1)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=7)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=8)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=14)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=15)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=21)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=22)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=1, day=28)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=29)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=30)): 0,
    ('DCE', datetime.date(year=1995, month=1, day=31)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=1)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=3)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=4)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=5)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=11)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=12)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=18)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=19)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=25)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=26)): 0,
    ('DCE', datetime.date(year=1995, month=2, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=2, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=1)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=2)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=4)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=5)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=11)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=12)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=18)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=19)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=25)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=26)): 0,
    ('DCE', datetime.date(year=1995, month=3, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=30)): 1,
    ('DCE', datetime.date(year=1995, month=3, day=31)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=1)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=8)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=9)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=15)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=16)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=22)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=23)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=4, day=29)): 0,
    ('DCE', datetime.date(year=1995, month=4, day=30)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=2)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=6)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=7)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=13)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=14)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=20)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=21)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=27)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=28)): 0,
    ('DCE', datetime.date(year=1995, month=5, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=30)): 1,
    ('DCE', datetime.date(year=1995, month=5, day=31)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=1)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=2)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=3)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=4)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=10)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=11)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=17)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=18)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=24)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=25)): 0,
    ('DCE', datetime.date(year=1995, month=6, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=6, day=30)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=1)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=8)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=9)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=15)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=16)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=22)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=23)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=7, day=29)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=30)): 0,
    ('DCE', datetime.date(year=1995, month=7, day=31)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=1)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=2)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=5)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=6)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=12)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=13)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=19)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=20)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=26)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=27)): 0,
    ('DCE', datetime.date(year=1995, month=8, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=30)): 1,
    ('DCE', datetime.date(year=1995, month=8, day=31)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=1)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=3)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=9)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=10)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=16)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=17)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=23)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=24)): 0,
    ('DCE', datetime.date(year=1995, month=9, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=9, day=30)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=3)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=7)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=8)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=14)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=15)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=21)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=22)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=28)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=29)): 0,
    ('DCE', datetime.date(year=1995, month=10, day=30)): 1,
    ('DCE', datetime.date(year=1995, month=10, day=31)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=1)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=2)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=3)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=4)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=5)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=9)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=10)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=11)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=12)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=16)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=17)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=18)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=19)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=23)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=24)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=25)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=26)): 0,
    ('DCE', datetime.date(year=1995, month=11, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=11, day=30)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=1)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=2)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=3)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=4)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=5)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=6)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=7)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=8)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=9)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=10)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=11)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=12)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=13)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=14)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=15)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=16)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=17)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=18)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=19)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=20)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=21)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=22)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=23)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=24)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=25)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=26)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=27)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=28)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=29)): 1,
    ('DCE', datetime.date(year=1995, month=12, day=30)): 0,
    ('DCE', datetime.date(year=1995, month=12, day=31)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=6)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=7)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=13)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=14)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=20)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=21)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=27)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=28)): 0,
    ('DCE', datetime.date(year=1996, month=1, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=1, day=31)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=1)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=3)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=4)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=10)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=11)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=2, day=17)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=18)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=19)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=20)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=21)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=22)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=23)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=24)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=25)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=26)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=27)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=28)): 0,
    ('DCE', datetime.date(year=1996, month=2, day=29)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=2)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=3)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=9)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=10)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=16)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=17)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=21)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=23)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=24)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=28)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=3, day=30)): 0,
    ('DCE', datetime.date(year=1996, month=3, day=31)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=1)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=6)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=7)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=13)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=14)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=20)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=21)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=27)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=28)): 0,
    ('DCE', datetime.date(year=1996, month=4, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=4, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=4)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=5)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=11)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=12)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=18)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=19)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=21)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=25)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=26)): 0,
    ('DCE', datetime.date(year=1996, month=5, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=28)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=5, day=31)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=2)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=8)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=9)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=15)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=16)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=21)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=22)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=23)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=28)): 1,
    ('DCE', datetime.date(year=1996, month=6, day=29)): 0,
    ('DCE', datetime.date(year=1996, month=6, day=30)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=1)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=6)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=7)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=13)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=14)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=20)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=21)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=27)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=28)): 0,
    ('DCE', datetime.date(year=1996, month=7, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=7, day=31)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=1)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=3)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=4)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=10)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=11)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=17)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=18)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=21)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=24)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=25)): 0,
    ('DCE', datetime.date(year=1996, month=8, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=28)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=8, day=31)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=7)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=8)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=14)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=15)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=21)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=22)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=9, day=28)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=29)): 0,
    ('DCE', datetime.date(year=1996, month=9, day=30)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=5)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=6)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=12)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=13)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=19)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=20)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=21)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=26)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=27)): 0,
    ('DCE', datetime.date(year=1996, month=10, day=28)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=10, day=31)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=1)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=2)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=3)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=7)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=8)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=9)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=10)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=14)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=15)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=16)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=17)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=21)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=22)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=23)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=24)): 0,
    ('DCE', datetime.date(year=1996, month=11, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=28)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=29)): 1,
    ('DCE', datetime.date(year=1996, month=11, day=30)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=1)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=2)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=3)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=4)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=5)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=6)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=7)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=8)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=9)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=10)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=11)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=12)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=13)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=14)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=15)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=16)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=17)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=18)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=19)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=20)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=21)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=22)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=23)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=24)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=25)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=26)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=27)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=28)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=29)): 0,
    ('DCE', datetime.date(year=1996, month=12, day=30)): 1,
    ('DCE', datetime.date(year=1996, month=12, day=31)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=2)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=4)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=5)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=11)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=12)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=18)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=19)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=25)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=26)): 0,
    ('DCE', datetime.date(year=1997, month=1, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=1, day=31)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=2)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=3)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=4)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=5)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=6)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=7)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=8)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=9)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=10)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=11)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=12)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=13)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=14)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=15)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=16)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=22)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=23)): 0,
    ('DCE', datetime.date(year=1997, month=2, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=2, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=2)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=8)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=9)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=15)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=16)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=22)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=23)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=3, day=29)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=30)): 0,
    ('DCE', datetime.date(year=1997, month=3, day=31)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=1)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=2)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=5)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=6)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=12)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=13)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=19)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=20)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=26)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=27)): 0,
    ('DCE', datetime.date(year=1997, month=4, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=4, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=2)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=3)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=4)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=10)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=11)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=17)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=18)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=24)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=25)): 0,
    ('DCE', datetime.date(year=1997, month=5, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=5, day=31)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=2)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=7)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=8)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=14)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=15)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=21)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=22)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=6, day=28)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=29)): 0,
    ('DCE', datetime.date(year=1997, month=6, day=30)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=2)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=5)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=6)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=12)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=13)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=19)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=20)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=26)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=27)): 0,
    ('DCE', datetime.date(year=1997, month=7, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=7, day=31)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=1)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=2)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=3)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=9)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=10)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=16)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=17)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=23)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=24)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=8, day=30)): 0,
    ('DCE', datetime.date(year=1997, month=8, day=31)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=1)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=2)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=6)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=7)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=13)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=14)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=20)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=21)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=27)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=28)): 0,
    ('DCE', datetime.date(year=1997, month=9, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=9, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=3)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=4)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=5)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=11)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=12)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=18)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=19)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=25)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=26)): 0,
    ('DCE', datetime.date(year=1997, month=10, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=10, day=31)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=1)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=2)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=6)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=7)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=8)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=9)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=13)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=14)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=15)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=16)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=20)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=21)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=22)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=23)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=27)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=28)): 1,
    ('DCE', datetime.date(year=1997, month=11, day=29)): 0,
    ('DCE', datetime.date(year=1997, month=11, day=30)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=1)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=2)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=3)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=4)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=5)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=6)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=7)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=8)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=9)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=10)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=11)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=12)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=13)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=14)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=15)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=16)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=17)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=18)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=19)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=20)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=21)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=22)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=23)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=24)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=25)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=26)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=27)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=28)): 0,
    ('DCE', datetime.date(year=1997, month=12, day=29)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=30)): 1,
    ('DCE', datetime.date(year=1997, month=12, day=31)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=2)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=3)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=4)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=10)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=11)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=17)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=18)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=1, day=24)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=25)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=26)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=27)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=28)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=29)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=30)): 0,
    ('DCE', datetime.date(year=1998, month=1, day=31)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=2)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=3)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=4)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=5)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=6)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=7)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=8)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=14)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=15)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=21)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=22)): 0,
    ('DCE', datetime.date(year=1998, month=2, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=2, day=28)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=7)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=8)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=14)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=15)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=21)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=22)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=28)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=29)): 0,
    ('DCE', datetime.date(year=1998, month=3, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=3, day=31)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=1)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=4)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=5)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=11)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=12)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=18)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=19)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=25)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=26)): 0,
    ('DCE', datetime.date(year=1998, month=4, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=4, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=2)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=3)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=9)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=10)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=16)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=17)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=23)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=24)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=5, day=30)): 0,
    ('DCE', datetime.date(year=1998, month=5, day=31)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=1)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=6)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=7)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=13)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=14)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=20)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=21)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=27)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=28)): 0,
    ('DCE', datetime.date(year=1998, month=6, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=6, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=1)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=4)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=5)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=11)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=12)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=18)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=19)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=25)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=26)): 0,
    ('DCE', datetime.date(year=1998, month=7, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=7, day=31)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=2)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=8)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=9)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=15)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=16)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=22)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=23)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=8, day=29)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=30)): 0,
    ('DCE', datetime.date(year=1998, month=8, day=31)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=1)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=5)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=6)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=12)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=13)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=19)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=20)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=26)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=27)): 0,
    ('DCE', datetime.date(year=1998, month=9, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=9, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=3)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=4)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=10)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=11)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=17)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=18)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=24)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=25)): 0,
    ('DCE', datetime.date(year=1998, month=10, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=10, day=31)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=1)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=5)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=6)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=7)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=8)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=12)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=13)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=14)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=15)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=19)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=20)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=21)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=22)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=26)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=27)): 1,
    ('DCE', datetime.date(year=1998, month=11, day=28)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=29)): 0,
    ('DCE', datetime.date(year=1998, month=11, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=1)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=2)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=3)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=4)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=5)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=6)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=7)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=8)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=9)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=10)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=11)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=12)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=13)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=14)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=15)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=16)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=17)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=18)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=19)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=20)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=21)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=22)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=23)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=24)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=25)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=26)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=27)): 0,
    ('DCE', datetime.date(year=1998, month=12, day=28)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=29)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=30)): 1,
    ('DCE', datetime.date(year=1998, month=12, day=31)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=1)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=2)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=3)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=9)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=10)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=16)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=17)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=23)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=24)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=1, day=30)): 0,
    ('DCE', datetime.date(year=1999, month=1, day=31)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=6)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=7)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=2, day=10)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=11)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=12)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=13)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=14)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=15)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=16)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=17)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=18)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=19)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=20)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=21)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=22)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=23)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=24)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=25)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=26)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=27)): 0,
    ('DCE', datetime.date(year=1999, month=2, day=28)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=6)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=7)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=13)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=14)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=20)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=21)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=27)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=28)): 0,
    ('DCE', datetime.date(year=1999, month=3, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=3, day=31)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=3)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=4)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=10)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=11)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=17)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=18)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=24)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=25)): 0,
    ('DCE', datetime.date(year=1999, month=4, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=4, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=1)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=2)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=3)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=8)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=9)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=15)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=16)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=22)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=23)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=5, day=29)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=30)): 0,
    ('DCE', datetime.date(year=1999, month=5, day=31)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=5)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=6)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=12)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=13)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=19)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=20)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=26)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=27)): 0,
    ('DCE', datetime.date(year=1999, month=6, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=6, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=3)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=4)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=10)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=11)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=17)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=18)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=24)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=25)): 0,
    ('DCE', datetime.date(year=1999, month=7, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=7, day=31)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=1)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=7)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=8)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=14)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=15)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=21)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=22)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=28)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=29)): 0,
    ('DCE', datetime.date(year=1999, month=8, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=8, day=31)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=4)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=5)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=11)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=12)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=18)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=19)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=25)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=26)): 0,
    ('DCE', datetime.date(year=1999, month=9, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=9, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=1)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=2)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=3)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=4)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=5)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=6)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=7)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=9)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=10)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=16)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=17)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=20)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=23)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=24)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=10, day=30)): 0,
    ('DCE', datetime.date(year=1999, month=10, day=31)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=4)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=5)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=6)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=7)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=11)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=12)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=13)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=14)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=18)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=19)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=20)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=21)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=25)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=26)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=27)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=28)): 0,
    ('DCE', datetime.date(year=1999, month=11, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=11, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=1)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=2)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=3)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=4)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=5)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=6)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=7)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=8)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=9)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=10)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=11)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=12)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=13)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=14)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=15)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=16)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=17)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=18)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=19)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=20)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=21)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=22)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=23)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=24)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=25)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=26)): 0,
    ('DCE', datetime.date(year=1999, month=12, day=27)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=28)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=29)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=30)): 1,
    ('DCE', datetime.date(year=1999, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2000, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2000, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=2, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2000, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2000, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2000, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2000, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2000, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2000, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2000, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2000, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2000, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2000, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2000, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2000, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2000, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2000, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2000, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2001, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2001, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2001, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2001, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2001, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2001, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2001, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2001, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2001, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2001, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2001, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2001, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2001, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2002, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2002, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2002, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2002, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2002, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2002, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2002, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=10)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=17)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=24)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2002, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=8, day=31)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=7)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=14)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2002, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=12)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=19)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=26)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2002, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=2)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=9)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=16)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=23)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2002, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2002, month=11, day=30)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=7)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=14)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=21)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=28)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=29)): 0,
    ('DCE', datetime.date(year=2002, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2002, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=11)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=18)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2003, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2003, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=8)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=15)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=22)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=3, day=29)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2003, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=12)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=19)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=26)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2003, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=10)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=17)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=24)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2003, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=5, day=31)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=21)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=6, day=28)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2003, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=5)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=12)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=19)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=26)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2003, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=2)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=9)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=10)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=16)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=17)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=23)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=24)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=8, day=30)): 0,
    ('DCE', datetime.date(year=2003, month=8, day=31)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=7)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=14)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=27)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=28)): 0,
    ('DCE', datetime.date(year=2003, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=11)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=12)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=18)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=19)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=25)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=26)): 0,
    ('DCE', datetime.date(year=2003, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=1)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=2)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=8)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=9)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=15)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=16)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=22)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=23)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2003, month=11, day=29)): 0,
    ('DCE', datetime.date(year=2003, month=11, day=30)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=6)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=7)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=13)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=14)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=20)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=21)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=27)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=28)): 0,
    ('DCE', datetime.date(year=2003, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2003, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=10)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=11)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=17)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=18)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2004, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=2, day=28)): 0,
    ('DCE', datetime.date(year=2004, month=2, day=29)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=7)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=14)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=21)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=28)): 0,
    ('DCE', datetime.date(year=2004, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=11)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=18)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=25)): 0,
    ('DCE', datetime.date(year=2004, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=16)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=23)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2004, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=13)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=20)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=27)): 0,
    ('DCE', datetime.date(year=2004, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=11)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=18)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=25)): 0,
    ('DCE', datetime.date(year=2004, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=1)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=8)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=15)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=22)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=29)): 0,
    ('DCE', datetime.date(year=2004, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=5)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=26)): 0,
    ('DCE', datetime.date(year=2004, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=10)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=17)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=24)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2004, month=10, day=31)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=7)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=14)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=21)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=28)): 0,
    ('DCE', datetime.date(year=2004, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=5)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=12)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=19)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=26)): 0,
    ('DCE', datetime.date(year=2004, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2004, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2005, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2005, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2005, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2005, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2005, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2005, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2005, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2005, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2005, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2005, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2005, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2005, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2005, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2006, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2006, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2006, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2006, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2006, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2006, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2006, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2006, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2006, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2006, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2006, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2006, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2006, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2006, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2006, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2006, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2006, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2007, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2007, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2007, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2007, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2007, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2007, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2007, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2007, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2007, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2007, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2007, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2007, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2007, month=12, day=29)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2007, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2008, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2008, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=2, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=1)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=8)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=15)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=22)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=3, day=29)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2008, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=12)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=19)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=26)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2008, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=10)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=17)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=24)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2008, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=5, day=31)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=21)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=6, day=28)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2008, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=5)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=12)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=19)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=26)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2008, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=2)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=9)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=10)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=16)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=17)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=23)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=24)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=8, day=30)): 0,
    ('DCE', datetime.date(year=2008, month=8, day=31)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=6)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=7)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=14)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=9, day=27)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=28)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2008, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=6)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=11)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=12)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=18)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=19)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=25)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=26)): 0,
    ('DCE', datetime.date(year=2008, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=1)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=2)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=8)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=9)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=15)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=16)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=22)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=23)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2008, month=11, day=29)): 0,
    ('DCE', datetime.date(year=2008, month=11, day=30)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=6)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=7)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=13)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=14)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=20)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=21)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=27)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=28)): 0,
    ('DCE', datetime.date(year=2008, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2008, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=10)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=11)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=17)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=18)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2009, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2009, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=2, day=28)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=7)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=8)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=14)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=15)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=21)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=22)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=28)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=29)): 0,
    ('DCE', datetime.date(year=2009, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=11)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=12)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=18)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=19)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=25)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=26)): 0,
    ('DCE', datetime.date(year=2009, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2009, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=10)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=16)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=17)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=23)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=24)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2009, month=5, day=31)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=13)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=20)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=21)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=27)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=28)): 0,
    ('DCE', datetime.date(year=2009, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2009, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=4)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=5)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=11)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=12)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=18)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=19)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=25)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=26)): 0,
    ('DCE', datetime.date(year=2009, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=2)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=8)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=9)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=15)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=16)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=22)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=23)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2009, month=8, day=29)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=30)): 0,
    ('DCE', datetime.date(year=2009, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=5)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=6)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=26)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=27)): 0,
    ('DCE', datetime.date(year=2009, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2009, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=10)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=11)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=17)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=18)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=24)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=25)): 0,
    ('DCE', datetime.date(year=2009, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=10, day=31)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=1)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=7)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=8)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=14)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=15)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=21)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=22)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2009, month=11, day=28)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=29)): 0,
    ('DCE', datetime.date(year=2009, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=5)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=6)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=12)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=13)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=19)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=20)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=26)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=27)): 0,
    ('DCE', datetime.date(year=2009, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2009, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=10)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=17)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2010, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2010, month=2, day=28)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=7)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=14)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=21)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=28)): 0,
    ('DCE', datetime.date(year=2010, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=11)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=18)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=25)): 0,
    ('DCE', datetime.date(year=2010, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=16)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=23)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2010, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=13)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=20)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=27)): 0,
    ('DCE', datetime.date(year=2010, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=4)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=11)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=18)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=25)): 0,
    ('DCE', datetime.date(year=2010, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=1)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=8)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=15)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=22)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=29)): 0,
    ('DCE', datetime.date(year=2010, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=5)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=26)): 0,
    ('DCE', datetime.date(year=2010, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=10)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=17)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=24)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2010, month=10, day=31)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=7)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=14)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=21)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=28)): 0,
    ('DCE', datetime.date(year=2010, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=5)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=12)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=19)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=26)): 0,
    ('DCE', datetime.date(year=2010, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2010, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2011, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2011, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2011, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2011, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=3)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2011, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2011, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2011, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2011, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2011, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2011, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2011, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2011, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2011, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2012, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2012, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=2, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2012, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2012, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=2)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=3)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2012, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2012, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2012, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2012, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2012, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2012, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2012, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2012, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2012, month=12, day=29)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2012, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2013, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2013, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2013, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2013, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=2)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=3)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2013, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2013, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2013, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=10)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=17)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=24)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2013, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=8, day=31)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=7)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=14)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=9, day=28)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2013, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=12)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=19)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=26)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2013, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=2)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=9)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=16)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=23)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2013, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2013, month=11, day=30)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=7)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=14)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=21)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=28)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=29)): 0,
    ('DCE', datetime.date(year=2013, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2013, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=11)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=18)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2014, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2014, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=8)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=15)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=22)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=3, day=29)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2014, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=12)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=19)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=26)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2014, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=10)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=17)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=24)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2014, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=5, day=31)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=21)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=6, day=28)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2014, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=5)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=12)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=19)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=26)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2014, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=9)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=10)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=16)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=17)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=23)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=24)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=8, day=30)): 0,
    ('DCE', datetime.date(year=2014, month=8, day=31)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=6)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=7)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=14)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=27)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=28)): 0,
    ('DCE', datetime.date(year=2014, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=11)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=12)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=18)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=19)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=25)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=26)): 0,
    ('DCE', datetime.date(year=2014, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=1)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=2)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=8)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=9)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=15)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=16)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=22)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=23)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2014, month=11, day=29)): 0,
    ('DCE', datetime.date(year=2014, month=11, day=30)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=6)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=7)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=13)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=14)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=20)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=21)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=27)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=28)): 0,
    ('DCE', datetime.date(year=2014, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2014, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=10)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=11)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=17)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=18)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2015, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2015, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=2, day=28)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=7)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=8)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=14)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=15)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=21)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=22)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=28)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=29)): 0,
    ('DCE', datetime.date(year=2015, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=11)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=12)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=18)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=19)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=25)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=26)): 0,
    ('DCE', datetime.date(year=2015, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=10)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=16)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=17)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=23)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=24)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2015, month=5, day=31)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=13)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=20)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=21)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=27)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=28)): 0,
    ('DCE', datetime.date(year=2015, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=4)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=5)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=11)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=12)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=18)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=19)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=25)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=26)): 0,
    ('DCE', datetime.date(year=2015, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=2)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=8)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=9)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=15)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=16)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=22)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=23)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=8, day=29)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=30)): 0,
    ('DCE', datetime.date(year=2015, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=5)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=6)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=26)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=27)): 0,
    ('DCE', datetime.date(year=2015, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=10)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=11)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=17)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=18)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=24)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=25)): 0,
    ('DCE', datetime.date(year=2015, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=10, day=31)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=1)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=7)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=8)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=14)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=15)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=21)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=22)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2015, month=11, day=28)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=29)): 0,
    ('DCE', datetime.date(year=2015, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=5)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=6)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=12)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=13)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=19)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=20)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=26)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=27)): 0,
    ('DCE', datetime.date(year=2015, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2015, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=17)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2016, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=28)): 0,
    ('DCE', datetime.date(year=2016, month=2, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2016, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2016, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=3)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2016, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2016, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2016, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2016, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2016, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2016, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2016, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2016, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2016, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2017, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2017, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2017, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2017, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2017, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=2)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2017, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2017, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2017, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2017, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2017, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2017, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2017, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2017, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2017, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2017, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2017, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2017, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2017, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2017, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2018, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2018, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2018, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2018, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2018, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2018, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2018, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2018, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2018, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2018, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2018, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2018, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2018, month=12, day=29)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2018, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2019, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2019, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2019, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2019, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2019, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2019, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2019, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=4)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=10)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=11)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=17)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=18)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=24)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=25)): 0,
    ('DCE', datetime.date(year=2019, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=8, day=31)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=1)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=8)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=14)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=15)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=22)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=9, day=28)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2019, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=12)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=13)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=19)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=20)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=26)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=27)): 0,
    ('DCE', datetime.date(year=2019, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=2)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=3)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=9)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=10)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=16)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=17)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=23)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=24)): 0,
    ('DCE', datetime.date(year=2019, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2019, month=11, day=30)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=1)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=7)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=8)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=14)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=15)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=21)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=22)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=28)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=29)): 0,
    ('DCE', datetime.date(year=2019, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2019, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=4)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=11)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=12)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=18)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=19)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2020, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=8)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=22)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=23)): 0,
    ('DCE', datetime.date(year=2020, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=2, day=29)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=7)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=8)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=14)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=15)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=21)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=22)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=28)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=29)): 0,
    ('DCE', datetime.date(year=2020, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=11)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=12)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=18)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=19)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=25)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=26)): 0,
    ('DCE', datetime.date(year=2020, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=10)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=16)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=17)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=23)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=24)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2020, month=5, day=31)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=7)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=13)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=20)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=21)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=27)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=28)): 0,
    ('DCE', datetime.date(year=2020, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=4)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=11)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=12)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=18)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=19)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=25)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=26)): 0,
    ('DCE', datetime.date(year=2020, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=2)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=8)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=9)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=15)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=16)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=22)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=23)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=8, day=29)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=30)): 0,
    ('DCE', datetime.date(year=2020, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=6)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=13)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=26)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=27)): 0,
    ('DCE', datetime.date(year=2020, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=10)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=11)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=17)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=18)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=24)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=25)): 0,
    ('DCE', datetime.date(year=2020, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=10, day=31)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=1)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=7)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=8)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=14)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=15)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=21)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=22)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2020, month=11, day=28)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=29)): 0,
    ('DCE', datetime.date(year=2020, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=5)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=6)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=12)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=13)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=19)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=20)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=26)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=27)): 0,
    ('DCE', datetime.date(year=2020, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2020, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=10)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=17)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2021, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=4)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=7)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=21)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2021, month=2, day=28)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=7)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=14)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=21)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=28)): 0,
    ('DCE', datetime.date(year=2021, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=11)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=18)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=25)): 0,
    ('DCE', datetime.date(year=2021, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=9)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=16)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=23)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=30)): 0,
    ('DCE', datetime.date(year=2021, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=6)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=13)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=14)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=20)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=27)): 0,
    ('DCE', datetime.date(year=2021, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=4)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=11)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=18)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=25)): 0,
    ('DCE', datetime.date(year=2021, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=1)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=8)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=15)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=22)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=29)): 0,
    ('DCE', datetime.date(year=2021, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=5)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=19)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=20)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=21)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=26)): 0,
    ('DCE', datetime.date(year=2021, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=10)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=17)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=24)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2021, month=10, day=31)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=5)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=7)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=12)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=14)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=19)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=21)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=26)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=28)): 0,
    ('DCE', datetime.date(year=2021, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=3)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=5)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=10)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=12)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=17)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=19)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=24)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=26)): 0,
    ('DCE', datetime.date(year=2021, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2021, month=12, day=31)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=9)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=16)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=30)): 0,
    ('DCE', datetime.date(year=2022, month=1, day=31)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=1)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=2)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=6)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=20)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=27)): 0,
    ('DCE', datetime.date(year=2022, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=6)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=13)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=20)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=27)): 0,
    ('DCE', datetime.date(year=2022, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2022, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=10)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=17)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=24)): 0,
    ('DCE', datetime.date(year=2022, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=8)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=15)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=22)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=29)): 0,
    ('DCE', datetime.date(year=2022, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2022, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=5)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=12)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=19)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=26)): 0,
    ('DCE', datetime.date(year=2022, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=10)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=17)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=24)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2022, month=7, day=31)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=5)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=7)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=14)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=21)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=28)): 0,
    ('DCE', datetime.date(year=2022, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2022, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=2)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=11)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=12)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=18)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=25)): 0,
    ('DCE', datetime.date(year=2022, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=9, day=30)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=9)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=16)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=23)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=30)): 0,
    ('DCE', datetime.date(year=2022, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=4)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=6)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=11)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=13)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=18)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=20)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=25)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=27)): 0,
    ('DCE', datetime.date(year=2022, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=2)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=4)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=9)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=11)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=16)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=18)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=23)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=25)): 0,
    ('DCE', datetime.date(year=2022, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2022, month=12, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=8)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=15)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=22)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=23)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=24)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=25)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=26)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=29)): 0,
    ('DCE', datetime.date(year=2023, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=5)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=19)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=26)): 0,
    ('DCE', datetime.date(year=2023, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=2)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=4)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=5)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=11)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=12)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=18)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=19)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=23)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=25)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=26)): 0,
    ('DCE', datetime.date(year=2023, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=3, day=31)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=1)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=8)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=9)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=15)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=16)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=22)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=23)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=4, day=29)): 0,
    ('DCE', datetime.date(year=2023, month=4, day=30)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=5)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=6)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=7)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=13)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=14)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=20)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=21)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=27)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=28)): 0,
    ('DCE', datetime.date(year=2023, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=2)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=3)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=4)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=11)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=17)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=18)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=24)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=25)): 0,
    ('DCE', datetime.date(year=2023, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=29)): 1,
    ('DCE', datetime.date(year=2023, month=6, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=1)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=8)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=9)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=15)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=16)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=22)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=23)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=7, day=29)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=30)): 0,
    ('DCE', datetime.date(year=2023, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=5)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=6)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=12)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=13)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=19)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=20)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=23)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=26)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=27)): 0,
    ('DCE', datetime.date(year=2023, month=8, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=29)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=8, day=31)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=3)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=5)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=9)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=10)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=16)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=17)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=23)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=24)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=9, day=29)): 0,
    ('DCE', datetime.date(year=2023, month=9, day=30)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=1)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=3)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=4)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=5)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=6)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=7)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=8)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=14)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=15)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=21)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=22)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=23)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=28)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=29)): 0,
    ('DCE', datetime.date(year=2023, month=10, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=10, day=31)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=2)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=3)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=4)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=5)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=9)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=10)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=11)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=12)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=16)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=17)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=18)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=19)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=23)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=24)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=25)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=26)): 0,
    ('DCE', datetime.date(year=2023, month=11, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=29)): 1,
    ('DCE', datetime.date(year=2023, month=11, day=30)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=1)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=2)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=3)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=4)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=5)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=6)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=7)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=8)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=9)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=10)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=11)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=12)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=13)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=14)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=15)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=16)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=17)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=18)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=19)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=20)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=21)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=22)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=23)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=24)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=25)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=26)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=27)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=28)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=29)): 1,
    ('DCE', datetime.date(year=2023, month=12, day=30)): 0,
    ('DCE', datetime.date(year=2023, month=12, day=31)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=1)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=2)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=3)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=4)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=5)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=6)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=7)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=8)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=9)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=10)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=11)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=12)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=13)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=14)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=15)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=16)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=17)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=18)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=19)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=20)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=21)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=22)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=23)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=24)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=25)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=26)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=27)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=28)): 0,
    ('DCE', datetime.date(year=2024, month=1, day=29)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=30)): 1,
    ('DCE', datetime.date(year=2024, month=1, day=31)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=1)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=2)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=3)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=4)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=5)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=6)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=7)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=8)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=9)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=10)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=11)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=12)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=13)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=14)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=15)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=16)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=17)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=18)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=19)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=20)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=21)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=22)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=23)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=24)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=25)): 0,
    ('DCE', datetime.date(year=2024, month=2, day=26)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=27)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=28)): 1,
    ('DCE', datetime.date(year=2024, month=2, day=29)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=1)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=2)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=3)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=4)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=5)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=6)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=7)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=8)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=9)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=10)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=11)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=12)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=13)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=14)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=15)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=16)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=17)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=18)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=19)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=20)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=21)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=22)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=23)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=24)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=25)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=26)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=27)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=28)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=29)): 1,
    ('DCE', datetime.date(year=2024, month=3, day=30)): 0,
    ('DCE', datetime.date(year=2024, month=3, day=31)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=1)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=2)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=3)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=4)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=5)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=6)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=7)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=8)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=9)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=10)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=11)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=12)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=13)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=14)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=15)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=16)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=17)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=18)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=19)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=20)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=21)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=22)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=23)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=24)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=25)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=26)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=27)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=28)): 0,
    ('DCE', datetime.date(year=2024, month=4, day=29)): 1,
    ('DCE', datetime.date(year=2024, month=4, day=30)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=1)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=2)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=3)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=4)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=5)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=6)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=7)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=8)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=9)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=10)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=11)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=12)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=13)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=14)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=15)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=16)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=17)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=18)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=19)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=20)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=21)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=22)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=23)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=24)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=25)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=26)): 0,
    ('DCE', datetime.date(year=2024, month=5, day=27)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=28)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=29)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=30)): 1,
    ('DCE', datetime.date(year=2024, month=5, day=31)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=1)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=2)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=3)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=4)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=5)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=6)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=7)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=8)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=9)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=10)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=11)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=12)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=13)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=14)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=15)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=16)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=17)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=18)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=19)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=20)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=21)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=22)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=23)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=24)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=25)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=26)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=27)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=28)): 1,
    ('DCE', datetime.date(year=2024, month=6, day=29)): 0,
    ('DCE', datetime.date(year=2024, month=6, day=30)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=1)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=2)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=3)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=4)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=5)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=6)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=7)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=8)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=9)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=10)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=11)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=12)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=13)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=14)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=15)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=16)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=17)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=18)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=19)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=20)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=21)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=22)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=23)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=24)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=25)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=26)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=27)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=28)): 0,
    ('DCE', datetime.date(year=2024, month=7, day=29)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=30)): 1,
    ('DCE', datetime.date(year=2024, month=7, day=31)): 1,
    ('DCE', datetime.date(year=2024, month=8, day=1)): 1,
    ('DCE', datetime.date(year=2024, month=8, day=2)): 1,
    ('DCE', datetime.date(year=2024, month=8, day=3)): 0,
    ('DCE', datetime.date(year=2024, month=8, day=4)): 0,
    ('INE', datetime.date(year=2017, month=5, day=23)): 1,
    ('INE', datetime.date(year=2017, month=5, day=24)): 1,
    ('INE', datetime.date(year=2017, month=5, day=25)): 1,
    ('INE', datetime.date(year=2017, month=5, day=26)): 1,
    ('INE', datetime.date(year=2017, month=5, day=27)): 0,
    ('INE', datetime.date(year=2017, month=5, day=28)): 0,
    ('INE', datetime.date(year=2017, month=5, day=29)): 0,
    ('INE', datetime.date(year=2017, month=5, day=30)): 0,
    ('INE', datetime.date(year=2017, month=5, day=31)): 1,
    ('INE', datetime.date(year=2017, month=6, day=1)): 1,
    ('INE', datetime.date(year=2017, month=6, day=2)): 1,
    ('INE', datetime.date(year=2017, month=6, day=3)): 0,
    ('INE', datetime.date(year=2017, month=6, day=4)): 0,
    ('INE', datetime.date(year=2017, month=6, day=5)): 1,
    ('INE', datetime.date(year=2017, month=6, day=6)): 1,
    ('INE', datetime.date(year=2017, month=6, day=7)): 1,
    ('INE', datetime.date(year=2017, month=6, day=8)): 1,
    ('INE', datetime.date(year=2017, month=6, day=9)): 1,
    ('INE', datetime.date(year=2017, month=6, day=10)): 0,
    ('INE', datetime.date(year=2017, month=6, day=11)): 0,
    ('INE', datetime.date(year=2017, month=6, day=12)): 1,
    ('INE', datetime.date(year=2017, month=6, day=13)): 1,
    ('INE', datetime.date(year=2017, month=6, day=14)): 1,
    ('INE', datetime.date(year=2017, month=6, day=15)): 1,
    ('INE', datetime.date(year=2017, month=6, day=16)): 1,
    ('INE', datetime.date(year=2017, month=6, day=17)): 0,
    ('INE', datetime.date(year=2017, month=6, day=18)): 0,
    ('INE', datetime.date(year=2017, month=6, day=19)): 1,
    ('INE', datetime.date(year=2017, month=6, day=20)): 1,
    ('INE', datetime.date(year=2017, month=6, day=21)): 1,
    ('INE', datetime.date(year=2017, month=6, day=22)): 1,
    ('INE', datetime.date(year=2017, month=6, day=23)): 1,
    ('INE', datetime.date(year=2017, month=6, day=24)): 0,
    ('INE', datetime.date(year=2017, month=6, day=25)): 0,
    ('INE', datetime.date(year=2017, month=6, day=26)): 1,
    ('INE', datetime.date(year=2017, month=6, day=27)): 1,
    ('INE', datetime.date(year=2017, month=6, day=28)): 1,
    ('INE', datetime.date(year=2017, month=6, day=29)): 1,
    ('INE', datetime.date(year=2017, month=6, day=30)): 1,
    ('INE', datetime.date(year=2017, month=7, day=1)): 0,
    ('INE', datetime.date(year=2017, month=7, day=2)): 0,
    ('INE', datetime.date(year=2017, month=7, day=3)): 1,
    ('INE', datetime.date(year=2017, month=7, day=4)): 1,
    ('INE', datetime.date(year=2017, month=7, day=5)): 1,
    ('INE', datetime.date(year=2017, month=7, day=6)): 1,
    ('INE', datetime.date(year=2017, month=7, day=7)): 1,
    ('INE', datetime.date(year=2017, month=7, day=8)): 0,
    ('INE', datetime.date(year=2017, month=7, day=9)): 0,
    ('INE', datetime.date(year=2017, month=7, day=10)): 1,
    ('INE', datetime.date(year=2017, month=7, day=11)): 1,
    ('INE', datetime.date(year=2017, month=7, day=12)): 1,
    ('INE', datetime.date(year=2017, month=7, day=13)): 1,
    ('INE', datetime.date(year=2017, month=7, day=14)): 1,
    ('INE', datetime.date(year=2017, month=7, day=15)): 0,
    ('INE', datetime.date(year=2017, month=7, day=16)): 0,
    ('INE', datetime.date(year=2017, month=7, day=17)): 1,
    ('INE', datetime.date(year=2017, month=7, day=18)): 1,
    ('INE', datetime.date(year=2017, month=7, day=19)): 1,
    ('INE', datetime.date(year=2017, month=7, day=20)): 1,
    ('INE', datetime.date(year=2017, month=7, day=21)): 1,
    ('INE', datetime.date(year=2017, month=7, day=22)): 0,
    ('INE', datetime.date(year=2017, month=7, day=23)): 0,
    ('INE', datetime.date(year=2017, month=7, day=24)): 1,
    ('INE', datetime.date(year=2017, month=7, day=25)): 1,
    ('INE', datetime.date(year=2017, month=7, day=26)): 1,
    ('INE', datetime.date(year=2017, month=7, day=27)): 1,
    ('INE', datetime.date(year=2017, month=7, day=28)): 1,
    ('INE', datetime.date(year=2017, month=7, day=29)): 0,
    ('INE', datetime.date(year=2017, month=7, day=30)): 0,
    ('INE', datetime.date(year=2017, month=7, day=31)): 1,
    ('INE', datetime.date(year=2017, month=8, day=1)): 1,
    ('INE', datetime.date(year=2017, month=8, day=2)): 1,
    ('INE', datetime.date(year=2017, month=8, day=3)): 1,
    ('INE', datetime.date(year=2017, month=8, day=4)): 1,
    ('INE', datetime.date(year=2017, month=8, day=5)): 0,
    ('INE', datetime.date(year=2017, month=8, day=6)): 0,
    ('INE', datetime.date(year=2017, month=8, day=7)): 1,
    ('INE', datetime.date(year=2017, month=8, day=8)): 1,
    ('INE', datetime.date(year=2017, month=8, day=9)): 1,
    ('INE', datetime.date(year=2017, month=8, day=10)): 1,
    ('INE', datetime.date(year=2017, month=8, day=11)): 1,
    ('INE', datetime.date(year=2017, month=8, day=12)): 0,
    ('INE', datetime.date(year=2017, month=8, day=13)): 0,
    ('INE', datetime.date(year=2017, month=8, day=14)): 1,
    ('INE', datetime.date(year=2017, month=8, day=15)): 1,
    ('INE', datetime.date(year=2017, month=8, day=16)): 1,
    ('INE', datetime.date(year=2017, month=8, day=17)): 1,
    ('INE', datetime.date(year=2017, month=8, day=18)): 1,
    ('INE', datetime.date(year=2017, month=8, day=19)): 0,
    ('INE', datetime.date(year=2017, month=8, day=20)): 0,
    ('INE', datetime.date(year=2017, month=8, day=21)): 1,
    ('INE', datetime.date(year=2017, month=8, day=22)): 1,
    ('INE', datetime.date(year=2017, month=8, day=23)): 1,
    ('INE', datetime.date(year=2017, month=8, day=24)): 1,
    ('INE', datetime.date(year=2017, month=8, day=25)): 1,
    ('INE', datetime.date(year=2017, month=8, day=26)): 0,
    ('INE', datetime.date(year=2017, month=8, day=27)): 0,
    ('INE', datetime.date(year=2017, month=8, day=28)): 1,
    ('INE', datetime.date(year=2017, month=8, day=29)): 1,
    ('INE', datetime.date(year=2017, month=8, day=30)): 1,
    ('INE', datetime.date(year=2017, month=8, day=31)): 1,
    ('INE', datetime.date(year=2017, month=9, day=1)): 1,
    ('INE', datetime.date(year=2017, month=9, day=2)): 0,
    ('INE', datetime.date(year=2017, month=9, day=3)): 0,
    ('INE', datetime.date(year=2017, month=9, day=4)): 1,
    ('INE', datetime.date(year=2017, month=9, day=5)): 1,
    ('INE', datetime.date(year=2017, month=9, day=6)): 1,
    ('INE', datetime.date(year=2017, month=9, day=7)): 1,
    ('INE', datetime.date(year=2017, month=9, day=8)): 1,
    ('INE', datetime.date(year=2017, month=9, day=9)): 0,
    ('INE', datetime.date(year=2017, month=9, day=10)): 0,
    ('INE', datetime.date(year=2017, month=9, day=11)): 1,
    ('INE', datetime.date(year=2017, month=9, day=12)): 1,
    ('INE', datetime.date(year=2017, month=9, day=13)): 1,
    ('INE', datetime.date(year=2017, month=9, day=14)): 1,
    ('INE', datetime.date(year=2017, month=9, day=15)): 1,
    ('INE', datetime.date(year=2017, month=9, day=16)): 0,
    ('INE', datetime.date(year=2017, month=9, day=17)): 0,
    ('INE', datetime.date(year=2017, month=9, day=18)): 1,
    ('INE', datetime.date(year=2017, month=9, day=19)): 1,
    ('INE', datetime.date(year=2017, month=9, day=20)): 1,
    ('INE', datetime.date(year=2017, month=9, day=21)): 1,
    ('INE', datetime.date(year=2017, month=9, day=22)): 1,
    ('INE', datetime.date(year=2017, month=9, day=23)): 0,
    ('INE', datetime.date(year=2017, month=9, day=24)): 0,
    ('INE', datetime.date(year=2017, month=9, day=25)): 1,
    ('INE', datetime.date(year=2017, month=9, day=26)): 1,
    ('INE', datetime.date(year=2017, month=9, day=27)): 1,
    ('INE', datetime.date(year=2017, month=9, day=28)): 1,
    ('INE', datetime.date(year=2017, month=9, day=29)): 1,
    ('INE', datetime.date(year=2017, month=9, day=30)): 0,
    ('INE', datetime.date(year=2017, month=10, day=1)): 0,
    ('INE', datetime.date(year=2017, month=10, day=2)): 0,
    ('INE', datetime.date(year=2017, month=10, day=3)): 0,
    ('INE', datetime.date(year=2017, month=10, day=4)): 0,
    ('INE', datetime.date(year=2017, month=10, day=5)): 0,
    ('INE', datetime.date(year=2017, month=10, day=6)): 0,
    ('INE', datetime.date(year=2017, month=10, day=7)): 0,
    ('INE', datetime.date(year=2017, month=10, day=8)): 0,
    ('INE', datetime.date(year=2017, month=10, day=9)): 1,
    ('INE', datetime.date(year=2017, month=10, day=10)): 1,
    ('INE', datetime.date(year=2017, month=10, day=11)): 1,
    ('INE', datetime.date(year=2017, month=10, day=12)): 1,
    ('INE', datetime.date(year=2017, month=10, day=13)): 1,
    ('INE', datetime.date(year=2017, month=10, day=14)): 0,
    ('INE', datetime.date(year=2017, month=10, day=15)): 0,
    ('INE', datetime.date(year=2017, month=10, day=16)): 1,
    ('INE', datetime.date(year=2017, month=10, day=17)): 1,
    ('INE', datetime.date(year=2017, month=10, day=18)): 1,
    ('INE', datetime.date(year=2017, month=10, day=19)): 1,
    ('INE', datetime.date(year=2017, month=10, day=20)): 1,
    ('INE', datetime.date(year=2017, month=10, day=21)): 0,
    ('INE', datetime.date(year=2017, month=10, day=22)): 0,
    ('INE', datetime.date(year=2017, month=10, day=23)): 1,
    ('INE', datetime.date(year=2017, month=10, day=24)): 1,
    ('INE', datetime.date(year=2017, month=10, day=25)): 1,
    ('INE', datetime.date(year=2017, month=10, day=26)): 1,
    ('INE', datetime.date(year=2017, month=10, day=27)): 1,
    ('INE', datetime.date(year=2017, month=10, day=28)): 0,
    ('INE', datetime.date(year=2017, month=10, day=29)): 0,
    ('INE', datetime.date(year=2017, month=10, day=30)): 1,
    ('INE', datetime.date(year=2017, month=10, day=31)): 1,
    ('INE', datetime.date(year=2017, month=11, day=1)): 1,
    ('INE', datetime.date(year=2017, month=11, day=2)): 1,
    ('INE', datetime.date(year=2017, month=11, day=3)): 1,
    ('INE', datetime.date(year=2017, month=11, day=4)): 0,
    ('INE', datetime.date(year=2017, month=11, day=5)): 0,
    ('INE', datetime.date(year=2017, month=11, day=6)): 1,
    ('INE', datetime.date(year=2017, month=11, day=7)): 1,
    ('INE', datetime.date(year=2017, month=11, day=8)): 1,
    ('INE', datetime.date(year=2017, month=11, day=9)): 1,
    ('INE', datetime.date(year=2017, month=11, day=10)): 1,
    ('INE', datetime.date(year=2017, month=11, day=11)): 0,
    ('INE', datetime.date(year=2017, month=11, day=12)): 0,
    ('INE', datetime.date(year=2017, month=11, day=13)): 1,
    ('INE', datetime.date(year=2017, month=11, day=14)): 1,
    ('INE', datetime.date(year=2017, month=11, day=15)): 1,
    ('INE', datetime.date(year=2017, month=11, day=16)): 1,
    ('INE', datetime.date(year=2017, month=11, day=17)): 1,
    ('INE', datetime.date(year=2017, month=11, day=18)): 0,
    ('INE', datetime.date(year=2017, month=11, day=19)): 0,
    ('INE', datetime.date(year=2017, month=11, day=20)): 1,
    ('INE', datetime.date(year=2017, month=11, day=21)): 1,
    ('INE', datetime.date(year=2017, month=11, day=22)): 1,
    ('INE', datetime.date(year=2017, month=11, day=23)): 1,
    ('INE', datetime.date(year=2017, month=11, day=24)): 1,
    ('INE', datetime.date(year=2017, month=11, day=25)): 0,
    ('INE', datetime.date(year=2017, month=11, day=26)): 0,
    ('INE', datetime.date(year=2017, month=11, day=27)): 1,
    ('INE', datetime.date(year=2017, month=11, day=28)): 1,
    ('INE', datetime.date(year=2017, month=11, day=29)): 1,
    ('INE', datetime.date(year=2017, month=11, day=30)): 1,
    ('INE', datetime.date(year=2017, month=12, day=1)): 1,
    ('INE', datetime.date(year=2017, month=12, day=2)): 0,
    ('INE', datetime.date(year=2017, month=12, day=3)): 0,
    ('INE', datetime.date(year=2017, month=12, day=4)): 1,
    ('INE', datetime.date(year=2017, month=12, day=5)): 1,
    ('INE', datetime.date(year=2017, month=12, day=6)): 1,
    ('INE', datetime.date(year=2017, month=12, day=7)): 1,
    ('INE', datetime.date(year=2017, month=12, day=8)): 1,
    ('INE', datetime.date(year=2017, month=12, day=9)): 0,
    ('INE', datetime.date(year=2017, month=12, day=10)): 0,
    ('INE', datetime.date(year=2017, month=12, day=11)): 1,
    ('INE', datetime.date(year=2017, month=12, day=12)): 1,
    ('INE', datetime.date(year=2017, month=12, day=13)): 1,
    ('INE', datetime.date(year=2017, month=12, day=14)): 1,
    ('INE', datetime.date(year=2017, month=12, day=15)): 1,
    ('INE', datetime.date(year=2017, month=12, day=16)): 0,
    ('INE', datetime.date(year=2017, month=12, day=17)): 0,
    ('INE', datetime.date(year=2017, month=12, day=18)): 1,
    ('INE', datetime.date(year=2017, month=12, day=19)): 1,
    ('INE', datetime.date(year=2017, month=12, day=20)): 1,
    ('INE', datetime.date(year=2017, month=12, day=21)): 1,
    ('INE', datetime.date(year=2017, month=12, day=22)): 1,
    ('INE', datetime.date(year=2017, month=12, day=23)): 0,
    ('INE', datetime.date(year=2017, month=12, day=24)): 0,
    ('INE', datetime.date(year=2017, month=12, day=25)): 1,
    ('INE', datetime.date(year=2017, month=12, day=26)): 1,
    ('INE', datetime.date(year=2017, month=12, day=27)): 1,
    ('INE', datetime.date(year=2017, month=12, day=28)): 1,
    ('INE', datetime.date(year=2017, month=12, day=29)): 1,
    ('INE', datetime.date(year=2017, month=12, day=30)): 0,
    ('INE', datetime.date(year=2017, month=12, day=31)): 0,
    ('INE', datetime.date(year=2018, month=1, day=1)): 0,
    ('INE', datetime.date(year=2018, month=1, day=2)): 1,
    ('INE', datetime.date(year=2018, month=1, day=3)): 1,
    ('INE', datetime.date(year=2018, month=1, day=4)): 1,
    ('INE', datetime.date(year=2018, month=1, day=5)): 1,
    ('INE', datetime.date(year=2018, month=1, day=6)): 0,
    ('INE', datetime.date(year=2018, month=1, day=7)): 0,
    ('INE', datetime.date(year=2018, month=1, day=8)): 1,
    ('INE', datetime.date(year=2018, month=1, day=9)): 1,
    ('INE', datetime.date(year=2018, month=1, day=10)): 1,
    ('INE', datetime.date(year=2018, month=1, day=11)): 1,
    ('INE', datetime.date(year=2018, month=1, day=12)): 1,
    ('INE', datetime.date(year=2018, month=1, day=13)): 0,
    ('INE', datetime.date(year=2018, month=1, day=14)): 0,
    ('INE', datetime.date(year=2018, month=1, day=15)): 1,
    ('INE', datetime.date(year=2018, month=1, day=16)): 1,
    ('INE', datetime.date(year=2018, month=1, day=17)): 1,
    ('INE', datetime.date(year=2018, month=1, day=18)): 1,
    ('INE', datetime.date(year=2018, month=1, day=19)): 1,
    ('INE', datetime.date(year=2018, month=1, day=20)): 0,
    ('INE', datetime.date(year=2018, month=1, day=21)): 0,
    ('INE', datetime.date(year=2018, month=1, day=22)): 1,
    ('INE', datetime.date(year=2018, month=1, day=23)): 1,
    ('INE', datetime.date(year=2018, month=1, day=24)): 1,
    ('INE', datetime.date(year=2018, month=1, day=25)): 1,
    ('INE', datetime.date(year=2018, month=1, day=26)): 1,
    ('INE', datetime.date(year=2018, month=1, day=27)): 0,
    ('INE', datetime.date(year=2018, month=1, day=28)): 0,
    ('INE', datetime.date(year=2018, month=1, day=29)): 1,
    ('INE', datetime.date(year=2018, month=1, day=30)): 1,
    ('INE', datetime.date(year=2018, month=1, day=31)): 1,
    ('INE', datetime.date(year=2018, month=2, day=1)): 1,
    ('INE', datetime.date(year=2018, month=2, day=2)): 1,
    ('INE', datetime.date(year=2018, month=2, day=3)): 0,
    ('INE', datetime.date(year=2018, month=2, day=4)): 0,
    ('INE', datetime.date(year=2018, month=2, day=5)): 1,
    ('INE', datetime.date(year=2018, month=2, day=6)): 1,
    ('INE', datetime.date(year=2018, month=2, day=7)): 1,
    ('INE', datetime.date(year=2018, month=2, day=8)): 1,
    ('INE', datetime.date(year=2018, month=2, day=9)): 1,
    ('INE', datetime.date(year=2018, month=2, day=10)): 0,
    ('INE', datetime.date(year=2018, month=2, day=11)): 0,
    ('INE', datetime.date(year=2018, month=2, day=12)): 1,
    ('INE', datetime.date(year=2018, month=2, day=13)): 1,
    ('INE', datetime.date(year=2018, month=2, day=14)): 1,
    ('INE', datetime.date(year=2018, month=2, day=15)): 0,
    ('INE', datetime.date(year=2018, month=2, day=16)): 0,
    ('INE', datetime.date(year=2018, month=2, day=17)): 0,
    ('INE', datetime.date(year=2018, month=2, day=18)): 0,
    ('INE', datetime.date(year=2018, month=2, day=19)): 0,
    ('INE', datetime.date(year=2018, month=2, day=20)): 0,
    ('INE', datetime.date(year=2018, month=2, day=21)): 0,
    ('INE', datetime.date(year=2018, month=2, day=22)): 1,
    ('INE', datetime.date(year=2018, month=2, day=23)): 1,
    ('INE', datetime.date(year=2018, month=2, day=24)): 0,
    ('INE', datetime.date(year=2018, month=2, day=25)): 0,
    ('INE', datetime.date(year=2018, month=2, day=26)): 1,
    ('INE', datetime.date(year=2018, month=2, day=27)): 1,
    ('INE', datetime.date(year=2018, month=2, day=28)): 1,
    ('INE', datetime.date(year=2018, month=3, day=1)): 1,
    ('INE', datetime.date(year=2018, month=3, day=2)): 1,
    ('INE', datetime.date(year=2018, month=3, day=3)): 0,
    ('INE', datetime.date(year=2018, month=3, day=4)): 0,
    ('INE', datetime.date(year=2018, month=3, day=5)): 1,
    ('INE', datetime.date(year=2018, month=3, day=6)): 1,
    ('INE', datetime.date(year=2018, month=3, day=7)): 1,
    ('INE', datetime.date(year=2018, month=3, day=8)): 1,
    ('INE', datetime.date(year=2018, month=3, day=9)): 1,
    ('INE', datetime.date(year=2018, month=3, day=10)): 0,
    ('INE', datetime.date(year=2018, month=3, day=11)): 0,
    ('INE', datetime.date(year=2018, month=3, day=12)): 1,
    ('INE', datetime.date(year=2018, month=3, day=13)): 1,
    ('INE', datetime.date(year=2018, month=3, day=14)): 1,
    ('INE', datetime.date(year=2018, month=3, day=15)): 1,
    ('INE', datetime.date(year=2018, month=3, day=16)): 1,
    ('INE', datetime.date(year=2018, month=3, day=17)): 0,
    ('INE', datetime.date(year=2018, month=3, day=18)): 0,
    ('INE', datetime.date(year=2018, month=3, day=19)): 1,
    ('INE', datetime.date(year=2018, month=3, day=20)): 1,
    ('INE', datetime.date(year=2018, month=3, day=21)): 1,
    ('INE', datetime.date(year=2018, month=3, day=22)): 1,
    ('INE', datetime.date(year=2018, month=3, day=23)): 1,
    ('INE', datetime.date(year=2018, month=3, day=24)): 0,
    ('INE', datetime.date(year=2018, month=3, day=25)): 0,
    ('INE', datetime.date(year=2018, month=3, day=26)): 1,
    ('INE', datetime.date(year=2018, month=3, day=27)): 1,
    ('INE', datetime.date(year=2018, month=3, day=28)): 1,
    ('INE', datetime.date(year=2018, month=3, day=29)): 1,
    ('INE', datetime.date(year=2018, month=3, day=30)): 1,
    ('INE', datetime.date(year=2018, month=3, day=31)): 0,
    ('INE', datetime.date(year=2018, month=4, day=1)): 0,
    ('INE', datetime.date(year=2018, month=4, day=2)): 1,
    ('INE', datetime.date(year=2018, month=4, day=3)): 1,
    ('INE', datetime.date(year=2018, month=4, day=4)): 1,
    ('INE', datetime.date(year=2018, month=4, day=5)): 0,
    ('INE', datetime.date(year=2018, month=4, day=6)): 0,
    ('INE', datetime.date(year=2018, month=4, day=7)): 0,
    ('INE', datetime.date(year=2018, month=4, day=8)): 0,
    ('INE', datetime.date(year=2018, month=4, day=9)): 1,
    ('INE', datetime.date(year=2018, month=4, day=10)): 1,
    ('INE', datetime.date(year=2018, month=4, day=11)): 1,
    ('INE', datetime.date(year=2018, month=4, day=12)): 1,
    ('INE', datetime.date(year=2018, month=4, day=13)): 1,
    ('INE', datetime.date(year=2018, month=4, day=14)): 0,
    ('INE', datetime.date(year=2018, month=4, day=15)): 0,
    ('INE', datetime.date(year=2018, month=4, day=16)): 1,
    ('INE', datetime.date(year=2018, month=4, day=17)): 1,
    ('INE', datetime.date(year=2018, month=4, day=18)): 1,
    ('INE', datetime.date(year=2018, month=4, day=19)): 1,
    ('INE', datetime.date(year=2018, month=4, day=20)): 1,
    ('INE', datetime.date(year=2018, month=4, day=21)): 0,
    ('INE', datetime.date(year=2018, month=4, day=22)): 0,
    ('INE', datetime.date(year=2018, month=4, day=23)): 1,
    ('INE', datetime.date(year=2018, month=4, day=24)): 1,
    ('INE', datetime.date(year=2018, month=4, day=25)): 1,
    ('INE', datetime.date(year=2018, month=4, day=26)): 1,
    ('INE', datetime.date(year=2018, month=4, day=27)): 1,
    ('INE', datetime.date(year=2018, month=4, day=28)): 0,
    ('INE', datetime.date(year=2018, month=4, day=29)): 0,
    ('INE', datetime.date(year=2018, month=4, day=30)): 0,
    ('INE', datetime.date(year=2018, month=5, day=1)): 0,
    ('INE', datetime.date(year=2018, month=5, day=2)): 1,
    ('INE', datetime.date(year=2018, month=5, day=3)): 1,
    ('INE', datetime.date(year=2018, month=5, day=4)): 1,
    ('INE', datetime.date(year=2018, month=5, day=5)): 0,
    ('INE', datetime.date(year=2018, month=5, day=6)): 0,
    ('INE', datetime.date(year=2018, month=5, day=7)): 1,
    ('INE', datetime.date(year=2018, month=5, day=8)): 1,
    ('INE', datetime.date(year=2018, month=5, day=9)): 1,
    ('INE', datetime.date(year=2018, month=5, day=10)): 1,
    ('INE', datetime.date(year=2018, month=5, day=11)): 1,
    ('INE', datetime.date(year=2018, month=5, day=12)): 0,
    ('INE', datetime.date(year=2018, month=5, day=13)): 0,
    ('INE', datetime.date(year=2018, month=5, day=14)): 1,
    ('INE', datetime.date(year=2018, month=5, day=15)): 1,
    ('INE', datetime.date(year=2018, month=5, day=16)): 1,
    ('INE', datetime.date(year=2018, month=5, day=17)): 1,
    ('INE', datetime.date(year=2018, month=5, day=18)): 1,
    ('INE', datetime.date(year=2018, month=5, day=19)): 0,
    ('INE', datetime.date(year=2018, month=5, day=20)): 0,
    ('INE', datetime.date(year=2018, month=5, day=21)): 1,
    ('INE', datetime.date(year=2018, month=5, day=22)): 1,
    ('INE', datetime.date(year=2018, month=5, day=23)): 1,
    ('INE', datetime.date(year=2018, month=5, day=24)): 1,
    ('INE', datetime.date(year=2018, month=5, day=25)): 1,
    ('INE', datetime.date(year=2018, month=5, day=26)): 0,
    ('INE', datetime.date(year=2018, month=5, day=27)): 0,
    ('INE', datetime.date(year=2018, month=5, day=28)): 1,
    ('INE', datetime.date(year=2018, month=5, day=29)): 1,
    ('INE', datetime.date(year=2018, month=5, day=30)): 1,
    ('INE', datetime.date(year=2018, month=5, day=31)): 1,
    ('INE', datetime.date(year=2018, month=6, day=1)): 1,
    ('INE', datetime.date(year=2018, month=6, day=2)): 0,
    ('INE', datetime.date(year=2018, month=6, day=3)): 0,
    ('INE', datetime.date(year=2018, month=6, day=4)): 1,
    ('INE', datetime.date(year=2018, month=6, day=5)): 1,
    ('INE', datetime.date(year=2018, month=6, day=6)): 1,
    ('INE', datetime.date(year=2018, month=6, day=7)): 1,
    ('INE', datetime.date(year=2018, month=6, day=8)): 1,
    ('INE', datetime.date(year=2018, month=6, day=9)): 0,
    ('INE', datetime.date(year=2018, month=6, day=10)): 0,
    ('INE', datetime.date(year=2018, month=6, day=11)): 1,
    ('INE', datetime.date(year=2018, month=6, day=12)): 1,
    ('INE', datetime.date(year=2018, month=6, day=13)): 1,
    ('INE', datetime.date(year=2018, month=6, day=14)): 1,
    ('INE', datetime.date(year=2018, month=6, day=15)): 1,
    ('INE', datetime.date(year=2018, month=6, day=16)): 0,
    ('INE', datetime.date(year=2018, month=6, day=17)): 0,
    ('INE', datetime.date(year=2018, month=6, day=18)): 0,
    ('INE', datetime.date(year=2018, month=6, day=19)): 1,
    ('INE', datetime.date(year=2018, month=6, day=20)): 1,
    ('INE', datetime.date(year=2018, month=6, day=21)): 1,
    ('INE', datetime.date(year=2018, month=6, day=22)): 1,
    ('INE', datetime.date(year=2018, month=6, day=23)): 0,
    ('INE', datetime.date(year=2018, month=6, day=24)): 0,
    ('INE', datetime.date(year=2018, month=6, day=25)): 1,
    ('INE', datetime.date(year=2018, month=6, day=26)): 1,
    ('INE', datetime.date(year=2018, month=6, day=27)): 1,
    ('INE', datetime.date(year=2018, month=6, day=28)): 1,
    ('INE', datetime.date(year=2018, month=6, day=29)): 1,
    ('INE', datetime.date(year=2018, month=6, day=30)): 0,
    ('INE', datetime.date(year=2018, month=7, day=1)): 0,
    ('INE', datetime.date(year=2018, month=7, day=2)): 1,
    ('INE', datetime.date(year=2018, month=7, day=3)): 1,
    ('INE', datetime.date(year=2018, month=7, day=4)): 1,
    ('INE', datetime.date(year=2018, month=7, day=5)): 1,
    ('INE', datetime.date(year=2018, month=7, day=6)): 1,
    ('INE', datetime.date(year=2018, month=7, day=7)): 0,
    ('INE', datetime.date(year=2018, month=7, day=8)): 0,
    ('INE', datetime.date(year=2018, month=7, day=9)): 1,
    ('INE', datetime.date(year=2018, month=7, day=10)): 1,
    ('INE', datetime.date(year=2018, month=7, day=11)): 1,
    ('INE', datetime.date(year=2018, month=7, day=12)): 1,
    ('INE', datetime.date(year=2018, month=7, day=13)): 1,
    ('INE', datetime.date(year=2018, month=7, day=14)): 0,
    ('INE', datetime.date(year=2018, month=7, day=15)): 0,
    ('INE', datetime.date(year=2018, month=7, day=16)): 1,
    ('INE', datetime.date(year=2018, month=7, day=17)): 1,
    ('INE', datetime.date(year=2018, month=7, day=18)): 1,
    ('INE', datetime.date(year=2018, month=7, day=19)): 1,
    ('INE', datetime.date(year=2018, month=7, day=20)): 1,
    ('INE', datetime.date(year=2018, month=7, day=21)): 0,
    ('INE', datetime.date(year=2018, month=7, day=22)): 0,
    ('INE', datetime.date(year=2018, month=7, day=23)): 1,
    ('INE', datetime.date(year=2018, month=7, day=24)): 1,
    ('INE', datetime.date(year=2018, month=7, day=25)): 1,
    ('INE', datetime.date(year=2018, month=7, day=26)): 1,
    ('INE', datetime.date(year=2018, month=7, day=27)): 1,
    ('INE', datetime.date(year=2018, month=7, day=28)): 0,
    ('INE', datetime.date(year=2018, month=7, day=29)): 0,
    ('INE', datetime.date(year=2018, month=7, day=30)): 1,
    ('INE', datetime.date(year=2018, month=7, day=31)): 1,
    ('INE', datetime.date(year=2018, month=8, day=1)): 1,
    ('INE', datetime.date(year=2018, month=8, day=2)): 1,
    ('INE', datetime.date(year=2018, month=8, day=3)): 1,
    ('INE', datetime.date(year=2018, month=8, day=4)): 0,
    ('INE', datetime.date(year=2018, month=8, day=5)): 0,
    ('INE', datetime.date(year=2018, month=8, day=6)): 1,
    ('INE', datetime.date(year=2018, month=8, day=7)): 1,
    ('INE', datetime.date(year=2018, month=8, day=8)): 1,
    ('INE', datetime.date(year=2018, month=8, day=9)): 1,
    ('INE', datetime.date(year=2018, month=8, day=10)): 1,
    ('INE', datetime.date(year=2018, month=8, day=11)): 0,
    ('INE', datetime.date(year=2018, month=8, day=12)): 0,
    ('INE', datetime.date(year=2018, month=8, day=13)): 1,
    ('INE', datetime.date(year=2018, month=8, day=14)): 1,
    ('INE', datetime.date(year=2018, month=8, day=15)): 1,
    ('INE', datetime.date(year=2018, month=8, day=16)): 1,
    ('INE', datetime.date(year=2018, month=8, day=17)): 1,
    ('INE', datetime.date(year=2018, month=8, day=18)): 0,
    ('INE', datetime.date(year=2018, month=8, day=19)): 0,
    ('INE', datetime.date(year=2018, month=8, day=20)): 1,
    ('INE', datetime.date(year=2018, month=8, day=21)): 1,
    ('INE', datetime.date(year=2018, month=8, day=22)): 1,
    ('INE', datetime.date(year=2018, month=8, day=23)): 1,
    ('INE', datetime.date(year=2018, month=8, day=24)): 1,
    ('INE', datetime.date(year=2018, month=8, day=25)): 0,
    ('INE', datetime.date(year=2018, month=8, day=26)): 0,
    ('INE', datetime.date(year=2018, month=8, day=27)): 1,
    ('INE', datetime.date(year=2018, month=8, day=28)): 1,
    ('INE', datetime.date(year=2018, month=8, day=29)): 1,
    ('INE', datetime.date(year=2018, month=8, day=30)): 1,
    ('INE', datetime.date(year=2018, month=8, day=31)): 1,
    ('INE', datetime.date(year=2018, month=9, day=1)): 0,
    ('INE', datetime.date(year=2018, month=9, day=2)): 0,
    ('INE', datetime.date(year=2018, month=9, day=3)): 1,
    ('INE', datetime.date(year=2018, month=9, day=4)): 1,
    ('INE', datetime.date(year=2018, month=9, day=5)): 1,
    ('INE', datetime.date(year=2018, month=9, day=6)): 1,
    ('INE', datetime.date(year=2018, month=9, day=7)): 1,
    ('INE', datetime.date(year=2018, month=9, day=8)): 0,
    ('INE', datetime.date(year=2018, month=9, day=9)): 0,
    ('INE', datetime.date(year=2018, month=9, day=10)): 1,
    ('INE', datetime.date(year=2018, month=9, day=11)): 1,
    ('INE', datetime.date(year=2018, month=9, day=12)): 1,
    ('INE', datetime.date(year=2018, month=9, day=13)): 1,
    ('INE', datetime.date(year=2018, month=9, day=14)): 1,
    ('INE', datetime.date(year=2018, month=9, day=15)): 0,
    ('INE', datetime.date(year=2018, month=9, day=16)): 0,
    ('INE', datetime.date(year=2018, month=9, day=17)): 1,
    ('INE', datetime.date(year=2018, month=9, day=18)): 1,
    ('INE', datetime.date(year=2018, month=9, day=19)): 1,
    ('INE', datetime.date(year=2018, month=9, day=20)): 1,
    ('INE', datetime.date(year=2018, month=9, day=21)): 1,
    ('INE', datetime.date(year=2018, month=9, day=22)): 0,
    ('INE', datetime.date(year=2018, month=9, day=23)): 0,
    ('INE', datetime.date(year=2018, month=9, day=24)): 0,
    ('INE', datetime.date(year=2018, month=9, day=25)): 1,
    ('INE', datetime.date(year=2018, month=9, day=26)): 1,
    ('INE', datetime.date(year=2018, month=9, day=27)): 1,
    ('INE', datetime.date(year=2018, month=9, day=28)): 1,
    ('INE', datetime.date(year=2018, month=9, day=29)): 0,
    ('INE', datetime.date(year=2018, month=9, day=30)): 0,
    ('INE', datetime.date(year=2018, month=10, day=1)): 0,
    ('INE', datetime.date(year=2018, month=10, day=2)): 0,
    ('INE', datetime.date(year=2018, month=10, day=3)): 0,
    ('INE', datetime.date(year=2018, month=10, day=4)): 0,
    ('INE', datetime.date(year=2018, month=10, day=5)): 0,
    ('INE', datetime.date(year=2018, month=10, day=6)): 0,
    ('INE', datetime.date(year=2018, month=10, day=7)): 0,
    ('INE', datetime.date(year=2018, month=10, day=8)): 1,
    ('INE', datetime.date(year=2018, month=10, day=9)): 1,
    ('INE', datetime.date(year=2018, month=10, day=10)): 1,
    ('INE', datetime.date(year=2018, month=10, day=11)): 1,
    ('INE', datetime.date(year=2018, month=10, day=12)): 1,
    ('INE', datetime.date(year=2018, month=10, day=13)): 0,
    ('INE', datetime.date(year=2018, month=10, day=14)): 0,
    ('INE', datetime.date(year=2018, month=10, day=15)): 1,
    ('INE', datetime.date(year=2018, month=10, day=16)): 1,
    ('INE', datetime.date(year=2018, month=10, day=17)): 1,
    ('INE', datetime.date(year=2018, month=10, day=18)): 1,
    ('INE', datetime.date(year=2018, month=10, day=19)): 1,
    ('INE', datetime.date(year=2018, month=10, day=20)): 0,
    ('INE', datetime.date(year=2018, month=10, day=21)): 0,
    ('INE', datetime.date(year=2018, month=10, day=22)): 1,
    ('INE', datetime.date(year=2018, month=10, day=23)): 1,
    ('INE', datetime.date(year=2018, month=10, day=24)): 1,
    ('INE', datetime.date(year=2018, month=10, day=25)): 1,
    ('INE', datetime.date(year=2018, month=10, day=26)): 1,
    ('INE', datetime.date(year=2018, month=10, day=27)): 0,
    ('INE', datetime.date(year=2018, month=10, day=28)): 0,
    ('INE', datetime.date(year=2018, month=10, day=29)): 1,
    ('INE', datetime.date(year=2018, month=10, day=30)): 1,
    ('INE', datetime.date(year=2018, month=10, day=31)): 1,
    ('INE', datetime.date(year=2018, month=11, day=1)): 1,
    ('INE', datetime.date(year=2018, month=11, day=2)): 1,
    ('INE', datetime.date(year=2018, month=11, day=3)): 0,
    ('INE', datetime.date(year=2018, month=11, day=4)): 0,
    ('INE', datetime.date(year=2018, month=11, day=5)): 1,
    ('INE', datetime.date(year=2018, month=11, day=6)): 1,
    ('INE', datetime.date(year=2018, month=11, day=7)): 1,
    ('INE', datetime.date(year=2018, month=11, day=8)): 1,
    ('INE', datetime.date(year=2018, month=11, day=9)): 1,
    ('INE', datetime.date(year=2018, month=11, day=10)): 0,
    ('INE', datetime.date(year=2018, month=11, day=11)): 0,
    ('INE', datetime.date(year=2018, month=11, day=12)): 1,
    ('INE', datetime.date(year=2018, month=11, day=13)): 1,
    ('INE', datetime.date(year=2018, month=11, day=14)): 1,
    ('INE', datetime.date(year=2018, month=11, day=15)): 1,
    ('INE', datetime.date(year=2018, month=11, day=16)): 1,
    ('INE', datetime.date(year=2018, month=11, day=17)): 0,
    ('INE', datetime.date(year=2018, month=11, day=18)): 0,
    ('INE', datetime.date(year=2018, month=11, day=19)): 1,
    ('INE', datetime.date(year=2018, month=11, day=20)): 1,
    ('INE', datetime.date(year=2018, month=11, day=21)): 1,
    ('INE', datetime.date(year=2018, month=11, day=22)): 1,
    ('INE', datetime.date(year=2018, month=11, day=23)): 1,
    ('INE', datetime.date(year=2018, month=11, day=24)): 0,
    ('INE', datetime.date(year=2018, month=11, day=25)): 0,
    ('INE', datetime.date(year=2018, month=11, day=26)): 1,
    ('INE', datetime.date(year=2018, month=11, day=27)): 1,
    ('INE', datetime.date(year=2018, month=11, day=28)): 1,
    ('INE', datetime.date(year=2018, month=11, day=29)): 1,
    ('INE', datetime.date(year=2018, month=11, day=30)): 1,
    ('INE', datetime.date(year=2018, month=12, day=1)): 0,
    ('INE', datetime.date(year=2018, month=12, day=2)): 0,
    ('INE', datetime.date(year=2018, month=12, day=3)): 1,
    ('INE', datetime.date(year=2018, month=12, day=4)): 1,
    ('INE', datetime.date(year=2018, month=12, day=5)): 1,
    ('INE', datetime.date(year=2018, month=12, day=6)): 1,
    ('INE', datetime.date(year=2018, month=12, day=7)): 1,
    ('INE', datetime.date(year=2018, month=12, day=8)): 0,
    ('INE', datetime.date(year=2018, month=12, day=9)): 0,
    ('INE', datetime.date(year=2018, month=12, day=10)): 1,
    ('INE', datetime.date(year=2018, month=12, day=11)): 1,
    ('INE', datetime.date(year=2018, month=12, day=12)): 1,
    ('INE', datetime.date(year=2018, month=12, day=13)): 1,
    ('INE', datetime.date(year=2018, month=12, day=14)): 1,
    ('INE', datetime.date(year=2018, month=12, day=15)): 0,
    ('INE', datetime.date(year=2018, month=12, day=16)): 0,
    ('INE', datetime.date(year=2018, month=12, day=17)): 1,
    ('INE', datetime.date(year=2018, month=12, day=18)): 1,
    ('INE', datetime.date(year=2018, month=12, day=19)): 1,
    ('INE', datetime.date(year=2018, month=12, day=20)): 1,
    ('INE', datetime.date(year=2018, month=12, day=21)): 1,
    ('INE', datetime.date(year=2018, month=12, day=22)): 0,
    ('INE', datetime.date(year=2018, month=12, day=23)): 0,
    ('INE', datetime.date(year=2018, month=12, day=24)): 1,
    ('INE', datetime.date(year=2018, month=12, day=25)): 1,
    ('INE', datetime.date(year=2018, month=12, day=26)): 1,
    ('INE', datetime.date(year=2018, month=12, day=27)): 1,
    ('INE', datetime.date(year=2018, month=12, day=28)): 1,
    ('INE', datetime.date(year=2018, month=12, day=29)): 0,
    ('INE', datetime.date(year=2018, month=12, day=30)): 0,
    ('INE', datetime.date(year=2018, month=12, day=31)): 0,
    ('INE', datetime.date(year=2019, month=1, day=1)): 0,
    ('INE', datetime.date(year=2019, month=1, day=2)): 1,
    ('INE', datetime.date(year=2019, month=1, day=3)): 1,
    ('INE', datetime.date(year=2019, month=1, day=4)): 1,
    ('INE', datetime.date(year=2019, month=1, day=5)): 0,
    ('INE', datetime.date(year=2019, month=1, day=6)): 0,
    ('INE', datetime.date(year=2019, month=1, day=7)): 1,
    ('INE', datetime.date(year=2019, month=1, day=8)): 1,
    ('INE', datetime.date(year=2019, month=1, day=9)): 1,
    ('INE', datetime.date(year=2019, month=1, day=10)): 1,
    ('INE', datetime.date(year=2019, month=1, day=11)): 1,
    ('INE', datetime.date(year=2019, month=1, day=12)): 0,
    ('INE', datetime.date(year=2019, month=1, day=13)): 0,
    ('INE', datetime.date(year=2019, month=1, day=14)): 1,
    ('INE', datetime.date(year=2019, month=1, day=15)): 1,
    ('INE', datetime.date(year=2019, month=1, day=16)): 1,
    ('INE', datetime.date(year=2019, month=1, day=17)): 1,
    ('INE', datetime.date(year=2019, month=1, day=18)): 1,
    ('INE', datetime.date(year=2019, month=1, day=19)): 0,
    ('INE', datetime.date(year=2019, month=1, day=20)): 0,
    ('INE', datetime.date(year=2019, month=1, day=21)): 1,
    ('INE', datetime.date(year=2019, month=1, day=22)): 1,
    ('INE', datetime.date(year=2019, month=1, day=23)): 1,
    ('INE', datetime.date(year=2019, month=1, day=24)): 1,
    ('INE', datetime.date(year=2019, month=1, day=25)): 1,
    ('INE', datetime.date(year=2019, month=1, day=26)): 0,
    ('INE', datetime.date(year=2019, month=1, day=27)): 0,
    ('INE', datetime.date(year=2019, month=1, day=28)): 1,
    ('INE', datetime.date(year=2019, month=1, day=29)): 1,
    ('INE', datetime.date(year=2019, month=1, day=30)): 1,
    ('INE', datetime.date(year=2019, month=1, day=31)): 1,
    ('INE', datetime.date(year=2019, month=2, day=1)): 1,
    ('INE', datetime.date(year=2019, month=2, day=2)): 0,
    ('INE', datetime.date(year=2019, month=2, day=3)): 0,
    ('INE', datetime.date(year=2019, month=2, day=4)): 0,
    ('INE', datetime.date(year=2019, month=2, day=5)): 0,
    ('INE', datetime.date(year=2019, month=2, day=6)): 0,
    ('INE', datetime.date(year=2019, month=2, day=7)): 0,
    ('INE', datetime.date(year=2019, month=2, day=8)): 0,
    ('INE', datetime.date(year=2019, month=2, day=9)): 0,
    ('INE', datetime.date(year=2019, month=2, day=10)): 0,
    ('INE', datetime.date(year=2019, month=2, day=11)): 1,
    ('INE', datetime.date(year=2019, month=2, day=12)): 1,
    ('INE', datetime.date(year=2019, month=2, day=13)): 1,
    ('INE', datetime.date(year=2019, month=2, day=14)): 1,
    ('INE', datetime.date(year=2019, month=2, day=15)): 1,
    ('INE', datetime.date(year=2019, month=2, day=16)): 0,
    ('INE', datetime.date(year=2019, month=2, day=17)): 0,
    ('INE', datetime.date(year=2019, month=2, day=18)): 1,
    ('INE', datetime.date(year=2019, month=2, day=19)): 1,
    ('INE', datetime.date(year=2019, month=2, day=20)): 1,
    ('INE', datetime.date(year=2019, month=2, day=21)): 1,
    ('INE', datetime.date(year=2019, month=2, day=22)): 1,
    ('INE', datetime.date(year=2019, month=2, day=23)): 0,
    ('INE', datetime.date(year=2019, month=2, day=24)): 0,
    ('INE', datetime.date(year=2019, month=2, day=25)): 1,
    ('INE', datetime.date(year=2019, month=2, day=26)): 1,
    ('INE', datetime.date(year=2019, month=2, day=27)): 1,
    ('INE', datetime.date(year=2019, month=2, day=28)): 1,
    ('INE', datetime.date(year=2019, month=3, day=1)): 1,
    ('INE', datetime.date(year=2019, month=3, day=2)): 0,
    ('INE', datetime.date(year=2019, month=3, day=3)): 0,
    ('INE', datetime.date(year=2019, month=3, day=4)): 1,
    ('INE', datetime.date(year=2019, month=3, day=5)): 1,
    ('INE', datetime.date(year=2019, month=3, day=6)): 1,
    ('INE', datetime.date(year=2019, month=3, day=7)): 1,
    ('INE', datetime.date(year=2019, month=3, day=8)): 1,
    ('INE', datetime.date(year=2019, month=3, day=9)): 0,
    ('INE', datetime.date(year=2019, month=3, day=10)): 0,
    ('INE', datetime.date(year=2019, month=3, day=11)): 1,
    ('INE', datetime.date(year=2019, month=3, day=12)): 1,
    ('INE', datetime.date(year=2019, month=3, day=13)): 1,
    ('INE', datetime.date(year=2019, month=3, day=14)): 1,
    ('INE', datetime.date(year=2019, month=3, day=15)): 1,
    ('INE', datetime.date(year=2019, month=3, day=16)): 0,
    ('INE', datetime.date(year=2019, month=3, day=17)): 0,
    ('INE', datetime.date(year=2019, month=3, day=18)): 1,
    ('INE', datetime.date(year=2019, month=3, day=19)): 1,
    ('INE', datetime.date(year=2019, month=3, day=20)): 1,
    ('INE', datetime.date(year=2019, month=3, day=21)): 1,
    ('INE', datetime.date(year=2019, month=3, day=22)): 1,
    ('INE', datetime.date(year=2019, month=3, day=23)): 0,
    ('INE', datetime.date(year=2019, month=3, day=24)): 0,
    ('INE', datetime.date(year=2019, month=3, day=25)): 1,
    ('INE', datetime.date(year=2019, month=3, day=26)): 1,
    ('INE', datetime.date(year=2019, month=3, day=27)): 1,
    ('INE', datetime.date(year=2019, month=3, day=28)): 1,
    ('INE', datetime.date(year=2019, month=3, day=29)): 1,
    ('INE', datetime.date(year=2019, month=3, day=30)): 0,
    ('INE', datetime.date(year=2019, month=3, day=31)): 0,
    ('INE', datetime.date(year=2019, month=4, day=1)): 1,
    ('INE', datetime.date(year=2019, month=4, day=2)): 1,
    ('INE', datetime.date(year=2019, month=4, day=3)): 1,
    ('INE', datetime.date(year=2019, month=4, day=4)): 1,
    ('INE', datetime.date(year=2019, month=4, day=5)): 0,
    ('INE', datetime.date(year=2019, month=4, day=6)): 0,
    ('INE', datetime.date(year=2019, month=4, day=7)): 0,
    ('INE', datetime.date(year=2019, month=4, day=8)): 1,
    ('INE', datetime.date(year=2019, month=4, day=9)): 1,
    ('INE', datetime.date(year=2019, month=4, day=10)): 1,
    ('INE', datetime.date(year=2019, month=4, day=11)): 1,
    ('INE', datetime.date(year=2019, month=4, day=12)): 1,
    ('INE', datetime.date(year=2019, month=4, day=13)): 0,
    ('INE', datetime.date(year=2019, month=4, day=14)): 0,
    ('INE', datetime.date(year=2019, month=4, day=15)): 1,
    ('INE', datetime.date(year=2019, month=4, day=16)): 1,
    ('INE', datetime.date(year=2019, month=4, day=17)): 1,
    ('INE', datetime.date(year=2019, month=4, day=18)): 1,
    ('INE', datetime.date(year=2019, month=4, day=19)): 1,
    ('INE', datetime.date(year=2019, month=4, day=20)): 0,
    ('INE', datetime.date(year=2019, month=4, day=21)): 0,
    ('INE', datetime.date(year=2019, month=4, day=22)): 1,
    ('INE', datetime.date(year=2019, month=4, day=23)): 1,
    ('INE', datetime.date(year=2019, month=4, day=24)): 1,
    ('INE', datetime.date(year=2019, month=4, day=25)): 1,
    ('INE', datetime.date(year=2019, month=4, day=26)): 1,
    ('INE', datetime.date(year=2019, month=4, day=27)): 0,
    ('INE', datetime.date(year=2019, month=4, day=28)): 0,
    ('INE', datetime.date(year=2019, month=4, day=29)): 1,
    ('INE', datetime.date(year=2019, month=4, day=30)): 1,
    ('INE', datetime.date(year=2019, month=5, day=1)): 0,
    ('INE', datetime.date(year=2019, month=5, day=2)): 0,
    ('INE', datetime.date(year=2019, month=5, day=3)): 0,
    ('INE', datetime.date(year=2019, month=5, day=4)): 0,
    ('INE', datetime.date(year=2019, month=5, day=5)): 0,
    ('INE', datetime.date(year=2019, month=5, day=6)): 1,
    ('INE', datetime.date(year=2019, month=5, day=7)): 1,
    ('INE', datetime.date(year=2019, month=5, day=8)): 1,
    ('INE', datetime.date(year=2019, month=5, day=9)): 1,
    ('INE', datetime.date(year=2019, month=5, day=10)): 1,
    ('INE', datetime.date(year=2019, month=5, day=11)): 0,
    ('INE', datetime.date(year=2019, month=5, day=12)): 0,
    ('INE', datetime.date(year=2019, month=5, day=13)): 1,
    ('INE', datetime.date(year=2019, month=5, day=14)): 1,
    ('INE', datetime.date(year=2019, month=5, day=15)): 1,
    ('INE', datetime.date(year=2019, month=5, day=16)): 1,
    ('INE', datetime.date(year=2019, month=5, day=17)): 1,
    ('INE', datetime.date(year=2019, month=5, day=18)): 0,
    ('INE', datetime.date(year=2019, month=5, day=19)): 0,
    ('INE', datetime.date(year=2019, month=5, day=20)): 1,
    ('INE', datetime.date(year=2019, month=5, day=21)): 1,
    ('INE', datetime.date(year=2019, month=5, day=22)): 1,
    ('INE', datetime.date(year=2019, month=5, day=23)): 1,
    ('INE', datetime.date(year=2019, month=5, day=24)): 1,
    ('INE', datetime.date(year=2019, month=5, day=25)): 0,
    ('INE', datetime.date(year=2019, month=5, day=26)): 0,
    ('INE', datetime.date(year=2019, month=5, day=27)): 1,
    ('INE', datetime.date(year=2019, month=5, day=28)): 1,
    ('INE', datetime.date(year=2019, month=5, day=29)): 1,
    ('INE', datetime.date(year=2019, month=5, day=30)): 1,
    ('INE', datetime.date(year=2019, month=5, day=31)): 1,
    ('INE', datetime.date(year=2019, month=6, day=1)): 0,
    ('INE', datetime.date(year=2019, month=6, day=2)): 0,
    ('INE', datetime.date(year=2019, month=6, day=3)): 1,
    ('INE', datetime.date(year=2019, month=6, day=4)): 1,
    ('INE', datetime.date(year=2019, month=6, day=5)): 1,
    ('INE', datetime.date(year=2019, month=6, day=6)): 1,
    ('INE', datetime.date(year=2019, month=6, day=7)): 0,
    ('INE', datetime.date(year=2019, month=6, day=8)): 0,
    ('INE', datetime.date(year=2019, month=6, day=9)): 0,
    ('INE', datetime.date(year=2019, month=6, day=10)): 1,
    ('INE', datetime.date(year=2019, month=6, day=11)): 1,
    ('INE', datetime.date(year=2019, month=6, day=12)): 1,
    ('INE', datetime.date(year=2019, month=6, day=13)): 1,
    ('INE', datetime.date(year=2019, month=6, day=14)): 1,
    ('INE', datetime.date(year=2019, month=6, day=15)): 0,
    ('INE', datetime.date(year=2019, month=6, day=16)): 0,
    ('INE', datetime.date(year=2019, month=6, day=17)): 1,
    ('INE', datetime.date(year=2019, month=6, day=18)): 1,
    ('INE', datetime.date(year=2019, month=6, day=19)): 1,
    ('INE', datetime.date(year=2019, month=6, day=20)): 1,
    ('INE', datetime.date(year=2019, month=6, day=21)): 1,
    ('INE', datetime.date(year=2019, month=6, day=22)): 0,
    ('INE', datetime.date(year=2019, month=6, day=23)): 0,
    ('INE', datetime.date(year=2019, month=6, day=24)): 1,
    ('INE', datetime.date(year=2019, month=6, day=25)): 1,
    ('INE', datetime.date(year=2019, month=6, day=26)): 1,
    ('INE', datetime.date(year=2019, month=6, day=27)): 1,
    ('INE', datetime.date(year=2019, month=6, day=28)): 1,
    ('INE', datetime.date(year=2019, month=6, day=29)): 0,
    ('INE', datetime.date(year=2019, month=6, day=30)): 0,
    ('INE', datetime.date(year=2019, month=7, day=1)): 1,
    ('INE', datetime.date(year=2019, month=7, day=2)): 1,
    ('INE', datetime.date(year=2019, month=7, day=3)): 1,
    ('INE', datetime.date(year=2019, month=7, day=4)): 1,
    ('INE', datetime.date(year=2019, month=7, day=5)): 1,
    ('INE', datetime.date(year=2019, month=7, day=6)): 0,
    ('INE', datetime.date(year=2019, month=7, day=7)): 0,
    ('INE', datetime.date(year=2019, month=7, day=8)): 1,
    ('INE', datetime.date(year=2019, month=7, day=9)): 1,
    ('INE', datetime.date(year=2019, month=7, day=10)): 1,
    ('INE', datetime.date(year=2019, month=7, day=11)): 1,
    ('INE', datetime.date(year=2019, month=7, day=12)): 1,
    ('INE', datetime.date(year=2019, month=7, day=13)): 0,
    ('INE', datetime.date(year=2019, month=7, day=14)): 0,
    ('INE', datetime.date(year=2019, month=7, day=15)): 1,
    ('INE', datetime.date(year=2019, month=7, day=16)): 1,
    ('INE', datetime.date(year=2019, month=7, day=17)): 1,
    ('INE', datetime.date(year=2019, month=7, day=18)): 1,
    ('INE', datetime.date(year=2019, month=7, day=19)): 1,
    ('INE', datetime.date(year=2019, month=7, day=20)): 0,
    ('INE', datetime.date(year=2019, month=7, day=21)): 0,
    ('INE', datetime.date(year=2019, month=7, day=22)): 1,
    ('INE', datetime.date(year=2019, month=7, day=23)): 1,
    ('INE', datetime.date(year=2019, month=7, day=24)): 1,
    ('INE', datetime.date(year=2019, month=7, day=25)): 1,
    ('INE', datetime.date(year=2019, month=7, day=26)): 1,
    ('INE', datetime.date(year=2019, month=7, day=27)): 0,
    ('INE', datetime.date(year=2019, month=7, day=28)): 0,
    ('INE', datetime.date(year=2019, month=7, day=29)): 1,
    ('INE', datetime.date(year=2019, month=7, day=30)): 1,
    ('INE', datetime.date(year=2019, month=7, day=31)): 1,
    ('INE', datetime.date(year=2019, month=8, day=1)): 1,
    ('INE', datetime.date(year=2019, month=8, day=2)): 1,
    ('INE', datetime.date(year=2019, month=8, day=3)): 0,
    ('INE', datetime.date(year=2019, month=8, day=4)): 0,
    ('INE', datetime.date(year=2019, month=8, day=5)): 1,
    ('INE', datetime.date(year=2019, month=8, day=6)): 1,
    ('INE', datetime.date(year=2019, month=8, day=7)): 1,
    ('INE', datetime.date(year=2019, month=8, day=8)): 1,
    ('INE', datetime.date(year=2019, month=8, day=9)): 1,
    ('INE', datetime.date(year=2019, month=8, day=10)): 0,
    ('INE', datetime.date(year=2019, month=8, day=11)): 0,
    ('INE', datetime.date(year=2019, month=8, day=12)): 1,
    ('INE', datetime.date(year=2019, month=8, day=13)): 1,
    ('INE', datetime.date(year=2019, month=8, day=14)): 1,
    ('INE', datetime.date(year=2019, month=8, day=15)): 1,
    ('INE', datetime.date(year=2019, month=8, day=16)): 1,
    ('INE', datetime.date(year=2019, month=8, day=17)): 0,
    ('INE', datetime.date(year=2019, month=8, day=18)): 0,
    ('INE', datetime.date(year=2019, month=8, day=19)): 1,
    ('INE', datetime.date(year=2019, month=8, day=20)): 1,
    ('INE', datetime.date(year=2019, month=8, day=21)): 1,
    ('INE', datetime.date(year=2019, month=8, day=22)): 1,
    ('INE', datetime.date(year=2019, month=8, day=23)): 1,
    ('INE', datetime.date(year=2019, month=8, day=24)): 0,
    ('INE', datetime.date(year=2019, month=8, day=25)): 0,
    ('INE', datetime.date(year=2019, month=8, day=26)): 1,
    ('INE', datetime.date(year=2019, month=8, day=27)): 1,
    ('INE', datetime.date(year=2019, month=8, day=28)): 1,
    ('INE', datetime.date(year=2019, month=8, day=29)): 1,
    ('INE', datetime.date(year=2019, month=8, day=30)): 1,
    ('INE', datetime.date(year=2019, month=8, day=31)): 0,
    ('INE', datetime.date(year=2019, month=9, day=1)): 0,
    ('INE', datetime.date(year=2019, month=9, day=2)): 1,
    ('INE', datetime.date(year=2019, month=9, day=3)): 1,
    ('INE', datetime.date(year=2019, month=9, day=4)): 1,
    ('INE', datetime.date(year=2019, month=9, day=5)): 1,
    ('INE', datetime.date(year=2019, month=9, day=6)): 1,
    ('INE', datetime.date(year=2019, month=9, day=7)): 0,
    ('INE', datetime.date(year=2019, month=9, day=8)): 0,
    ('INE', datetime.date(year=2019, month=9, day=9)): 1,
    ('INE', datetime.date(year=2019, month=9, day=10)): 1,
    ('INE', datetime.date(year=2019, month=9, day=11)): 1,
    ('INE', datetime.date(year=2019, month=9, day=12)): 1,
    ('INE', datetime.date(year=2019, month=9, day=13)): 0,
    ('INE', datetime.date(year=2019, month=9, day=14)): 0,
    ('INE', datetime.date(year=2019, month=9, day=15)): 0,
    ('INE', datetime.date(year=2019, month=9, day=16)): 1,
    ('INE', datetime.date(year=2019, month=9, day=17)): 1,
    ('INE', datetime.date(year=2019, month=9, day=18)): 1,
    ('INE', datetime.date(year=2019, month=9, day=19)): 1,
    ('INE', datetime.date(year=2019, month=9, day=20)): 1,
    ('INE', datetime.date(year=2019, month=9, day=21)): 0,
    ('INE', datetime.date(year=2019, month=9, day=22)): 0,
    ('INE', datetime.date(year=2019, month=9, day=23)): 1,
    ('INE', datetime.date(year=2019, month=9, day=24)): 1,
    ('INE', datetime.date(year=2019, month=9, day=25)): 1,
    ('INE', datetime.date(year=2019, month=9, day=26)): 1,
    ('INE', datetime.date(year=2019, month=9, day=27)): 1,
    ('INE', datetime.date(year=2019, month=9, day=28)): 0,
    ('INE', datetime.date(year=2019, month=9, day=29)): 0,
    ('INE', datetime.date(year=2019, month=9, day=30)): 1,
    ('INE', datetime.date(year=2019, month=10, day=1)): 0,
    ('INE', datetime.date(year=2019, month=10, day=2)): 0,
    ('INE', datetime.date(year=2019, month=10, day=3)): 0,
    ('INE', datetime.date(year=2019, month=10, day=4)): 0,
    ('INE', datetime.date(year=2019, month=10, day=5)): 0,
    ('INE', datetime.date(year=2019, month=10, day=6)): 0,
    ('INE', datetime.date(year=2019, month=10, day=7)): 0,
    ('INE', datetime.date(year=2019, month=10, day=8)): 1,
    ('INE', datetime.date(year=2019, month=10, day=9)): 1,
    ('INE', datetime.date(year=2019, month=10, day=10)): 1,
    ('INE', datetime.date(year=2019, month=10, day=11)): 1,
    ('INE', datetime.date(year=2019, month=10, day=12)): 0,
    ('INE', datetime.date(year=2019, month=10, day=13)): 0,
    ('INE', datetime.date(year=2019, month=10, day=14)): 1,
    ('INE', datetime.date(year=2019, month=10, day=15)): 1,
    ('INE', datetime.date(year=2019, month=10, day=16)): 1,
    ('INE', datetime.date(year=2019, month=10, day=17)): 1,
    ('INE', datetime.date(year=2019, month=10, day=18)): 1,
    ('INE', datetime.date(year=2019, month=10, day=19)): 0,
    ('INE', datetime.date(year=2019, month=10, day=20)): 0,
    ('INE', datetime.date(year=2019, month=10, day=21)): 1,
    ('INE', datetime.date(year=2019, month=10, day=22)): 1,
    ('INE', datetime.date(year=2019, month=10, day=23)): 1,
    ('INE', datetime.date(year=2019, month=10, day=24)): 1,
    ('INE', datetime.date(year=2019, month=10, day=25)): 1,
    ('INE', datetime.date(year=2019, month=10, day=26)): 0,
    ('INE', datetime.date(year=2019, month=10, day=27)): 0,
    ('INE', datetime.date(year=2019, month=10, day=28)): 1,
    ('INE', datetime.date(year=2019, month=10, day=29)): 1,
    ('INE', datetime.date(year=2019, month=10, day=30)): 1,
    ('INE', datetime.date(year=2019, month=10, day=31)): 1,
    ('INE', datetime.date(year=2019, month=11, day=1)): 1,
    ('INE', datetime.date(year=2019, month=11, day=2)): 0,
    ('INE', datetime.date(year=2019, month=11, day=3)): 0,
    ('INE', datetime.date(year=2019, month=11, day=4)): 1,
    ('INE', datetime.date(year=2019, month=11, day=5)): 1,
    ('INE', datetime.date(year=2019, month=11, day=6)): 1,
    ('INE', datetime.date(year=2019, month=11, day=7)): 1,
    ('INE', datetime.date(year=2019, month=11, day=8)): 1,
    ('INE', datetime.date(year=2019, month=11, day=9)): 0,
    ('INE', datetime.date(year=2019, month=11, day=10)): 0,
    ('INE', datetime.date(year=2019, month=11, day=11)): 1,
    ('INE', datetime.date(year=2019, month=11, day=12)): 1,
    ('INE', datetime.date(year=2019, month=11, day=13)): 1,
    ('INE', datetime.date(year=2019, month=11, day=14)): 1,
    ('INE', datetime.date(year=2019, month=11, day=15)): 1,
    ('INE', datetime.date(year=2019, month=11, day=16)): 0,
    ('INE', datetime.date(year=2019, month=11, day=17)): 0,
    ('INE', datetime.date(year=2019, month=11, day=18)): 1,
    ('INE', datetime.date(year=2019, month=11, day=19)): 1,
    ('INE', datetime.date(year=2019, month=11, day=20)): 1,
    ('INE', datetime.date(year=2019, month=11, day=21)): 1,
    ('INE', datetime.date(year=2019, month=11, day=22)): 1,
    ('INE', datetime.date(year=2019, month=11, day=23)): 0,
    ('INE', datetime.date(year=2019, month=11, day=24)): 0,
    ('INE', datetime.date(year=2019, month=11, day=25)): 1,
    ('INE', datetime.date(year=2019, month=11, day=26)): 1,
    ('INE', datetime.date(year=2019, month=11, day=27)): 1,
    ('INE', datetime.date(year=2019, month=11, day=28)): 1,
    ('INE', datetime.date(year=2019, month=11, day=29)): 1,
    ('INE', datetime.date(year=2019, month=11, day=30)): 0,
    ('INE', datetime.date(year=2019, month=12, day=1)): 0,
    ('INE', datetime.date(year=2019, month=12, day=2)): 1,
    ('INE', datetime.date(year=2019, month=12, day=3)): 1,
    ('INE', datetime.date(year=2019, month=12, day=4)): 1,
    ('INE', datetime.date(year=2019, month=12, day=5)): 1,
    ('INE', datetime.date(year=2019, month=12, day=6)): 1,
    ('INE', datetime.date(year=2019, month=12, day=7)): 0,
    ('INE', datetime.date(year=2019, month=12, day=8)): 0,
    ('INE', datetime.date(year=2019, month=12, day=9)): 1,
    ('INE', datetime.date(year=2019, month=12, day=10)): 1,
    ('INE', datetime.date(year=2019, month=12, day=11)): 1,
    ('INE', datetime.date(year=2019, month=12, day=12)): 1,
    ('INE', datetime.date(year=2019, month=12, day=13)): 1,
    ('INE', datetime.date(year=2019, month=12, day=14)): 0,
    ('INE', datetime.date(year=2019, month=12, day=15)): 0,
    ('INE', datetime.date(year=2019, month=12, day=16)): 1,
    ('INE', datetime.date(year=2019, month=12, day=17)): 1,
    ('INE', datetime.date(year=2019, month=12, day=18)): 1,
    ('INE', datetime.date(year=2019, month=12, day=19)): 1,
    ('INE', datetime.date(year=2019, month=12, day=20)): 1,
    ('INE', datetime.date(year=2019, month=12, day=21)): 0,
    ('INE', datetime.date(year=2019, month=12, day=22)): 0,
    ('INE', datetime.date(year=2019, month=12, day=23)): 1,
    ('INE', datetime.date(year=2019, month=12, day=24)): 1,
    ('INE', datetime.date(year=2019, month=12, day=25)): 1,
    ('INE', datetime.date(year=2019, month=12, day=26)): 1,
    ('INE', datetime.date(year=2019, month=12, day=27)): 1,
    ('INE', datetime.date(year=2019, month=12, day=28)): 0,
    ('INE', datetime.date(year=2019, month=12, day=29)): 0,
    ('INE', datetime.date(year=2019, month=12, day=30)): 1,
    ('INE', datetime.date(year=2019, month=12, day=31)): 1,
    ('INE', datetime.date(year=2020, month=1, day=1)): 0,
    ('INE', datetime.date(year=2020, month=1, day=2)): 1,
    ('INE', datetime.date(year=2020, month=1, day=3)): 1,
    ('INE', datetime.date(year=2020, month=1, day=4)): 0,
    ('INE', datetime.date(year=2020, month=1, day=5)): 0,
    ('INE', datetime.date(year=2020, month=1, day=6)): 1,
    ('INE', datetime.date(year=2020, month=1, day=7)): 1,
    ('INE', datetime.date(year=2020, month=1, day=8)): 1,
    ('INE', datetime.date(year=2020, month=1, day=9)): 1,
    ('INE', datetime.date(year=2020, month=1, day=10)): 1,
    ('INE', datetime.date(year=2020, month=1, day=11)): 0,
    ('INE', datetime.date(year=2020, month=1, day=12)): 0,
    ('INE', datetime.date(year=2020, month=1, day=13)): 1,
    ('INE', datetime.date(year=2020, month=1, day=14)): 1,
    ('INE', datetime.date(year=2020, month=1, day=15)): 1,
    ('INE', datetime.date(year=2020, month=1, day=16)): 1,
    ('INE', datetime.date(year=2020, month=1, day=17)): 1,
    ('INE', datetime.date(year=2020, month=1, day=18)): 0,
    ('INE', datetime.date(year=2020, month=1, day=19)): 0,
    ('INE', datetime.date(year=2020, month=1, day=20)): 1,
    ('INE', datetime.date(year=2020, month=1, day=21)): 1,
    ('INE', datetime.date(year=2020, month=1, day=22)): 1,
    ('INE', datetime.date(year=2020, month=1, day=23)): 1,
    ('INE', datetime.date(year=2020, month=1, day=24)): 0,
    ('INE', datetime.date(year=2020, month=1, day=25)): 0,
    ('INE', datetime.date(year=2020, month=1, day=26)): 0,
    ('INE', datetime.date(year=2020, month=1, day=27)): 0,
    ('INE', datetime.date(year=2020, month=1, day=28)): 0,
    ('INE', datetime.date(year=2020, month=1, day=29)): 0,
    ('INE', datetime.date(year=2020, month=1, day=30)): 0,
    ('INE', datetime.date(year=2020, month=1, day=31)): 0,
    ('INE', datetime.date(year=2020, month=2, day=1)): 0,
    ('INE', datetime.date(year=2020, month=2, day=2)): 0,
    ('INE', datetime.date(year=2020, month=2, day=3)): 1,
    ('INE', datetime.date(year=2020, month=2, day=4)): 1,
    ('INE', datetime.date(year=2020, month=2, day=5)): 1,
    ('INE', datetime.date(year=2020, month=2, day=6)): 1,
    ('INE', datetime.date(year=2020, month=2, day=7)): 1,
    ('INE', datetime.date(year=2020, month=2, day=8)): 0,
    ('INE', datetime.date(year=2020, month=2, day=9)): 0,
    ('INE', datetime.date(year=2020, month=2, day=10)): 1,
    ('INE', datetime.date(year=2020, month=2, day=11)): 1,
    ('INE', datetime.date(year=2020, month=2, day=12)): 1,
    ('INE', datetime.date(year=2020, month=2, day=13)): 1,
    ('INE', datetime.date(year=2020, month=2, day=14)): 1,
    ('INE', datetime.date(year=2020, month=2, day=15)): 0,
    ('INE', datetime.date(year=2020, month=2, day=16)): 0,
    ('INE', datetime.date(year=2020, month=2, day=17)): 1,
    ('INE', datetime.date(year=2020, month=2, day=18)): 1,
    ('INE', datetime.date(year=2020, month=2, day=19)): 1,
    ('INE', datetime.date(year=2020, month=2, day=20)): 1,
    ('INE', datetime.date(year=2020, month=2, day=21)): 1,
    ('INE', datetime.date(year=2020, month=2, day=22)): 0,
    ('INE', datetime.date(year=2020, month=2, day=23)): 0,
    ('INE', datetime.date(year=2020, month=2, day=24)): 1,
    ('INE', datetime.date(year=2020, month=2, day=25)): 1,
    ('INE', datetime.date(year=2020, month=2, day=26)): 1,
    ('INE', datetime.date(year=2020, month=2, day=27)): 1,
    ('INE', datetime.date(year=2020, month=2, day=28)): 1,
    ('INE', datetime.date(year=2020, month=2, day=29)): 0,
    ('INE', datetime.date(year=2020, month=3, day=1)): 0,
    ('INE', datetime.date(year=2020, month=3, day=2)): 1,
    ('INE', datetime.date(year=2020, month=3, day=3)): 1,
    ('INE', datetime.date(year=2020, month=3, day=4)): 1,
    ('INE', datetime.date(year=2020, month=3, day=5)): 1,
    ('INE', datetime.date(year=2020, month=3, day=6)): 1,
    ('INE', datetime.date(year=2020, month=3, day=7)): 0,
    ('INE', datetime.date(year=2020, month=3, day=8)): 0,
    ('INE', datetime.date(year=2020, month=3, day=9)): 1,
    ('INE', datetime.date(year=2020, month=3, day=10)): 1,
    ('INE', datetime.date(year=2020, month=3, day=11)): 1,
    ('INE', datetime.date(year=2020, month=3, day=12)): 1,
    ('INE', datetime.date(year=2020, month=3, day=13)): 1,
    ('INE', datetime.date(year=2020, month=3, day=14)): 0,
    ('INE', datetime.date(year=2020, month=3, day=15)): 0,
    ('INE', datetime.date(year=2020, month=3, day=16)): 1,
    ('INE', datetime.date(year=2020, month=3, day=17)): 1,
    ('INE', datetime.date(year=2020, month=3, day=18)): 1,
    ('INE', datetime.date(year=2020, month=3, day=19)): 1,
    ('INE', datetime.date(year=2020, month=3, day=20)): 1,
    ('INE', datetime.date(year=2020, month=3, day=21)): 0,
    ('INE', datetime.date(year=2020, month=3, day=22)): 0,
    ('INE', datetime.date(year=2020, month=3, day=23)): 1,
    ('INE', datetime.date(year=2020, month=3, day=24)): 1,
    ('INE', datetime.date(year=2020, month=3, day=25)): 1,
    ('INE', datetime.date(year=2020, month=3, day=26)): 1,
    ('INE', datetime.date(year=2020, month=3, day=27)): 1,
    ('INE', datetime.date(year=2020, month=3, day=28)): 0,
    ('INE', datetime.date(year=2020, month=3, day=29)): 0,
    ('INE', datetime.date(year=2020, month=3, day=30)): 1,
    ('INE', datetime.date(year=2020, month=3, day=31)): 1,
    ('INE', datetime.date(year=2020, month=4, day=1)): 1,
    ('INE', datetime.date(year=2020, month=4, day=2)): 1,
    ('INE', datetime.date(year=2020, month=4, day=3)): 1,
    ('INE', datetime.date(year=2020, month=4, day=4)): 0,
    ('INE', datetime.date(year=2020, month=4, day=5)): 0,
    ('INE', datetime.date(year=2020, month=4, day=6)): 0,
    ('INE', datetime.date(year=2020, month=4, day=7)): 1,
    ('INE', datetime.date(year=2020, month=4, day=8)): 1,
    ('INE', datetime.date(year=2020, month=4, day=9)): 1,
    ('INE', datetime.date(year=2020, month=4, day=10)): 1,
    ('INE', datetime.date(year=2020, month=4, day=11)): 0,
    ('INE', datetime.date(year=2020, month=4, day=12)): 0,
    ('INE', datetime.date(year=2020, month=4, day=13)): 1,
    ('INE', datetime.date(year=2020, month=4, day=14)): 1,
    ('INE', datetime.date(year=2020, month=4, day=15)): 1,
    ('INE', datetime.date(year=2020, month=4, day=16)): 1,
    ('INE', datetime.date(year=2020, month=4, day=17)): 1,
    ('INE', datetime.date(year=2020, month=4, day=18)): 0,
    ('INE', datetime.date(year=2020, month=4, day=19)): 0,
    ('INE', datetime.date(year=2020, month=4, day=20)): 1,
    ('INE', datetime.date(year=2020, month=4, day=21)): 1,
    ('INE', datetime.date(year=2020, month=4, day=22)): 1,
    ('INE', datetime.date(year=2020, month=4, day=23)): 1,
    ('INE', datetime.date(year=2020, month=4, day=24)): 1,
    ('INE', datetime.date(year=2020, month=4, day=25)): 0,
    ('INE', datetime.date(year=2020, month=4, day=26)): 0,
    ('INE', datetime.date(year=2020, month=4, day=27)): 1,
    ('INE', datetime.date(year=2020, month=4, day=28)): 1,
    ('INE', datetime.date(year=2020, month=4, day=29)): 1,
    ('INE', datetime.date(year=2020, month=4, day=30)): 1,
    ('INE', datetime.date(year=2020, month=5, day=1)): 0,
    ('INE', datetime.date(year=2020, month=5, day=2)): 0,
    ('INE', datetime.date(year=2020, month=5, day=3)): 0,
    ('INE', datetime.date(year=2020, month=5, day=4)): 0,
    ('INE', datetime.date(year=2020, month=5, day=5)): 0,
    ('INE', datetime.date(year=2020, month=5, day=6)): 1,
    ('INE', datetime.date(year=2020, month=5, day=7)): 1,
    ('INE', datetime.date(year=2020, month=5, day=8)): 1,
    ('INE', datetime.date(year=2020, month=5, day=9)): 0,
    ('INE', datetime.date(year=2020, month=5, day=10)): 0,
    ('INE', datetime.date(year=2020, month=5, day=11)): 1,
    ('INE', datetime.date(year=2020, month=5, day=12)): 1,
    ('INE', datetime.date(year=2020, month=5, day=13)): 1,
    ('INE', datetime.date(year=2020, month=5, day=14)): 1,
    ('INE', datetime.date(year=2020, month=5, day=15)): 1,
    ('INE', datetime.date(year=2020, month=5, day=16)): 0,
    ('INE', datetime.date(year=2020, month=5, day=17)): 0,
    ('INE', datetime.date(year=2020, month=5, day=18)): 1,
    ('INE', datetime.date(year=2020, month=5, day=19)): 1,
    ('INE', datetime.date(year=2020, month=5, day=20)): 1,
    ('INE', datetime.date(year=2020, month=5, day=21)): 1,
    ('INE', datetime.date(year=2020, month=5, day=22)): 1,
    ('INE', datetime.date(year=2020, month=5, day=23)): 0,
    ('INE', datetime.date(year=2020, month=5, day=24)): 0,
    ('INE', datetime.date(year=2020, month=5, day=25)): 1,
    ('INE', datetime.date(year=2020, month=5, day=26)): 1,
    ('INE', datetime.date(year=2020, month=5, day=27)): 1,
    ('INE', datetime.date(year=2020, month=5, day=28)): 1,
    ('INE', datetime.date(year=2020, month=5, day=29)): 1,
    ('INE', datetime.date(year=2020, month=5, day=30)): 0,
    ('INE', datetime.date(year=2020, month=5, day=31)): 0,
    ('INE', datetime.date(year=2020, month=6, day=1)): 1,
    ('INE', datetime.date(year=2020, month=6, day=2)): 1,
    ('INE', datetime.date(year=2020, month=6, day=3)): 1,
    ('INE', datetime.date(year=2020, month=6, day=4)): 1,
    ('INE', datetime.date(year=2020, month=6, day=5)): 1,
    ('INE', datetime.date(year=2020, month=6, day=6)): 0,
    ('INE', datetime.date(year=2020, month=6, day=7)): 0,
    ('INE', datetime.date(year=2020, month=6, day=8)): 1,
    ('INE', datetime.date(year=2020, month=6, day=9)): 1,
    ('INE', datetime.date(year=2020, month=6, day=10)): 1,
    ('INE', datetime.date(year=2020, month=6, day=11)): 1,
    ('INE', datetime.date(year=2020, month=6, day=12)): 1,
    ('INE', datetime.date(year=2020, month=6, day=13)): 0,
    ('INE', datetime.date(year=2020, month=6, day=14)): 0,
    ('INE', datetime.date(year=2020, month=6, day=15)): 1,
    ('INE', datetime.date(year=2020, month=6, day=16)): 1,
    ('INE', datetime.date(year=2020, month=6, day=17)): 1,
    ('INE', datetime.date(year=2020, month=6, day=18)): 1,
    ('INE', datetime.date(year=2020, month=6, day=19)): 1,
    ('INE', datetime.date(year=2020, month=6, day=20)): 0,
    ('INE', datetime.date(year=2020, month=6, day=21)): 0,
    ('INE', datetime.date(year=2020, month=6, day=22)): 1,
    ('INE', datetime.date(year=2020, month=6, day=23)): 1,
    ('INE', datetime.date(year=2020, month=6, day=24)): 1,
    ('INE', datetime.date(year=2020, month=6, day=25)): 0,
    ('INE', datetime.date(year=2020, month=6, day=26)): 0,
    ('INE', datetime.date(year=2020, month=6, day=27)): 0,
    ('INE', datetime.date(year=2020, month=6, day=28)): 0,
    ('INE', datetime.date(year=2020, month=6, day=29)): 1,
    ('INE', datetime.date(year=2020, month=6, day=30)): 1,
    ('INE', datetime.date(year=2020, month=7, day=1)): 1,
    ('INE', datetime.date(year=2020, month=7, day=2)): 1,
    ('INE', datetime.date(year=2020, month=7, day=3)): 1,
    ('INE', datetime.date(year=2020, month=7, day=4)): 0,
    ('INE', datetime.date(year=2020, month=7, day=5)): 0,
    ('INE', datetime.date(year=2020, month=7, day=6)): 1,
    ('INE', datetime.date(year=2020, month=7, day=7)): 1,
    ('INE', datetime.date(year=2020, month=7, day=8)): 1,
    ('INE', datetime.date(year=2020, month=7, day=9)): 1,
    ('INE', datetime.date(year=2020, month=7, day=10)): 1,
    ('INE', datetime.date(year=2020, month=7, day=11)): 0,
    ('INE', datetime.date(year=2020, month=7, day=12)): 0,
    ('INE', datetime.date(year=2020, month=7, day=13)): 1,
    ('INE', datetime.date(year=2020, month=7, day=14)): 1,
    ('INE', datetime.date(year=2020, month=7, day=15)): 1,
    ('INE', datetime.date(year=2020, month=7, day=16)): 1,
    ('INE', datetime.date(year=2020, month=7, day=17)): 1,
    ('INE', datetime.date(year=2020, month=7, day=18)): 0,
    ('INE', datetime.date(year=2020, month=7, day=19)): 0,
    ('INE', datetime.date(year=2020, month=7, day=20)): 1,
    ('INE', datetime.date(year=2020, month=7, day=21)): 1,
    ('INE', datetime.date(year=2020, month=7, day=22)): 1,
    ('INE', datetime.date(year=2020, month=7, day=23)): 1,
    ('INE', datetime.date(year=2020, month=7, day=24)): 1,
    ('INE', datetime.date(year=2020, month=7, day=25)): 0,
    ('INE', datetime.date(year=2020, month=7, day=26)): 0,
    ('INE', datetime.date(year=2020, month=7, day=27)): 1,
    ('INE', datetime.date(year=2020, month=7, day=28)): 1,
    ('INE', datetime.date(year=2020, month=7, day=29)): 1,
    ('INE', datetime.date(year=2020, month=7, day=30)): 1,
    ('INE', datetime.date(year=2020, month=7, day=31)): 1,
    ('INE', datetime.date(year=2020, month=8, day=1)): 0,
    ('INE', datetime.date(year=2020, month=8, day=2)): 0,
    ('INE', datetime.date(year=2020, month=8, day=3)): 1,
    ('INE', datetime.date(year=2020, month=8, day=4)): 1,
    ('INE', datetime.date(year=2020, month=8, day=5)): 1,
    ('INE', datetime.date(year=2020, month=8, day=6)): 1,
    ('INE', datetime.date(year=2020, month=8, day=7)): 1,
    ('INE', datetime.date(year=2020, month=8, day=8)): 0,
    ('INE', datetime.date(year=2020, month=8, day=9)): 0,
    ('INE', datetime.date(year=2020, month=8, day=10)): 1,
    ('INE', datetime.date(year=2020, month=8, day=11)): 1,
    ('INE', datetime.date(year=2020, month=8, day=12)): 1,
    ('INE', datetime.date(year=2020, month=8, day=13)): 1,
    ('INE', datetime.date(year=2020, month=8, day=14)): 1,
    ('INE', datetime.date(year=2020, month=8, day=15)): 0,
    ('INE', datetime.date(year=2020, month=8, day=16)): 0,
    ('INE', datetime.date(year=2020, month=8, day=17)): 1,
    ('INE', datetime.date(year=2020, month=8, day=18)): 1,
    ('INE', datetime.date(year=2020, month=8, day=19)): 1,
    ('INE', datetime.date(year=2020, month=8, day=20)): 1,
    ('INE', datetime.date(year=2020, month=8, day=21)): 1,
    ('INE', datetime.date(year=2020, month=8, day=22)): 0,
    ('INE', datetime.date(year=2020, month=8, day=23)): 0,
    ('INE', datetime.date(year=2020, month=8, day=24)): 1,
    ('INE', datetime.date(year=2020, month=8, day=25)): 1,
    ('INE', datetime.date(year=2020, month=8, day=26)): 1,
    ('INE', datetime.date(year=2020, month=8, day=27)): 1,
    ('INE', datetime.date(year=2020, month=8, day=28)): 1,
    ('INE', datetime.date(year=2020, month=8, day=29)): 0,
    ('INE', datetime.date(year=2020, month=8, day=30)): 0,
    ('INE', datetime.date(year=2020, month=8, day=31)): 1,
    ('INE', datetime.date(year=2020, month=9, day=1)): 1,
    ('INE', datetime.date(year=2020, month=9, day=2)): 1,
    ('INE', datetime.date(year=2020, month=9, day=3)): 1,
    ('INE', datetime.date(year=2020, month=9, day=4)): 1,
    ('INE', datetime.date(year=2020, month=9, day=5)): 0,
    ('INE', datetime.date(year=2020, month=9, day=6)): 0,
    ('INE', datetime.date(year=2020, month=9, day=7)): 1,
    ('INE', datetime.date(year=2020, month=9, day=8)): 1,
    ('INE', datetime.date(year=2020, month=9, day=9)): 1,
    ('INE', datetime.date(year=2020, month=9, day=10)): 1,
    ('INE', datetime.date(year=2020, month=9, day=11)): 1,
    ('INE', datetime.date(year=2020, month=9, day=12)): 0,
    ('INE', datetime.date(year=2020, month=9, day=13)): 0,
    ('INE', datetime.date(year=2020, month=9, day=14)): 1,
    ('INE', datetime.date(year=2020, month=9, day=15)): 1,
    ('INE', datetime.date(year=2020, month=9, day=16)): 1,
    ('INE', datetime.date(year=2020, month=9, day=17)): 1,
    ('INE', datetime.date(year=2020, month=9, day=18)): 1,
    ('INE', datetime.date(year=2020, month=9, day=19)): 0,
    ('INE', datetime.date(year=2020, month=9, day=20)): 0,
    ('INE', datetime.date(year=2020, month=9, day=21)): 1,
    ('INE', datetime.date(year=2020, month=9, day=22)): 1,
    ('INE', datetime.date(year=2020, month=9, day=23)): 1,
    ('INE', datetime.date(year=2020, month=9, day=24)): 1,
    ('INE', datetime.date(year=2020, month=9, day=25)): 1,
    ('INE', datetime.date(year=2020, month=9, day=26)): 0,
    ('INE', datetime.date(year=2020, month=9, day=27)): 0,
    ('INE', datetime.date(year=2020, month=9, day=28)): 1,
    ('INE', datetime.date(year=2020, month=9, day=29)): 1,
    ('INE', datetime.date(year=2020, month=9, day=30)): 1,
    ('INE', datetime.date(year=2020, month=10, day=1)): 0,
    ('INE', datetime.date(year=2020, month=10, day=2)): 0,
    ('INE', datetime.date(year=2020, month=10, day=3)): 0,
    ('INE', datetime.date(year=2020, month=10, day=4)): 0,
    ('INE', datetime.date(year=2020, month=10, day=5)): 0,
    ('INE', datetime.date(year=2020, month=10, day=6)): 0,
    ('INE', datetime.date(year=2020, month=10, day=7)): 0,
    ('INE', datetime.date(year=2020, month=10, day=8)): 0,
    ('INE', datetime.date(year=2020, month=10, day=9)): 1,
    ('INE', datetime.date(year=2020, month=10, day=10)): 0,
    ('INE', datetime.date(year=2020, month=10, day=11)): 0,
    ('INE', datetime.date(year=2020, month=10, day=12)): 1,
    ('INE', datetime.date(year=2020, month=10, day=13)): 1,
    ('INE', datetime.date(year=2020, month=10, day=14)): 1,
    ('INE', datetime.date(year=2020, month=10, day=15)): 1,
    ('INE', datetime.date(year=2020, month=10, day=16)): 1,
    ('INE', datetime.date(year=2020, month=10, day=17)): 0,
    ('INE', datetime.date(year=2020, month=10, day=18)): 0,
    ('INE', datetime.date(year=2020, month=10, day=19)): 1,
    ('INE', datetime.date(year=2020, month=10, day=20)): 1,
    ('INE', datetime.date(year=2020, month=10, day=21)): 1,
    ('INE', datetime.date(year=2020, month=10, day=22)): 1,
    ('INE', datetime.date(year=2020, month=10, day=23)): 1,
    ('INE', datetime.date(year=2020, month=10, day=24)): 0,
    ('INE', datetime.date(year=2020, month=10, day=25)): 0,
    ('INE', datetime.date(year=2020, month=10, day=26)): 1,
    ('INE', datetime.date(year=2020, month=10, day=27)): 1,
    ('INE', datetime.date(year=2020, month=10, day=28)): 1,
    ('INE', datetime.date(year=2020, month=10, day=29)): 1,
    ('INE', datetime.date(year=2020, month=10, day=30)): 1,
    ('INE', datetime.date(year=2020, month=10, day=31)): 0,
    ('INE', datetime.date(year=2020, month=11, day=1)): 0,
    ('INE', datetime.date(year=2020, month=11, day=2)): 1,
    ('INE', datetime.date(year=2020, month=11, day=3)): 1,
    ('INE', datetime.date(year=2020, month=11, day=4)): 1,
    ('INE', datetime.date(year=2020, month=11, day=5)): 1,
    ('INE', datetime.date(year=2020, month=11, day=6)): 1,
    ('INE', datetime.date(year=2020, month=11, day=7)): 0,
    ('INE', datetime.date(year=2020, month=11, day=8)): 0,
    ('INE', datetime.date(year=2020, month=11, day=9)): 1,
    ('INE', datetime.date(year=2020, month=11, day=10)): 1,
    ('INE', datetime.date(year=2020, month=11, day=11)): 1,
    ('INE', datetime.date(year=2020, month=11, day=12)): 1,
    ('INE', datetime.date(year=2020, month=11, day=13)): 1,
    ('INE', datetime.date(year=2020, month=11, day=14)): 0,
    ('INE', datetime.date(year=2020, month=11, day=15)): 0,
    ('INE', datetime.date(year=2020, month=11, day=16)): 1,
    ('INE', datetime.date(year=2020, month=11, day=17)): 1,
    ('INE', datetime.date(year=2020, month=11, day=18)): 1,
    ('INE', datetime.date(year=2020, month=11, day=19)): 1,
    ('INE', datetime.date(year=2020, month=11, day=20)): 1,
    ('INE', datetime.date(year=2020, month=11, day=21)): 0,
    ('INE', datetime.date(year=2020, month=11, day=22)): 0,
    ('INE', datetime.date(year=2020, month=11, day=23)): 1,
    ('INE', datetime.date(year=2020, month=11, day=24)): 1,
    ('INE', datetime.date(year=2020, month=11, day=25)): 1,
    ('INE', datetime.date(year=2020, month=11, day=26)): 1,
    ('INE', datetime.date(year=2020, month=11, day=27)): 1,
    ('INE', datetime.date(year=2020, month=11, day=28)): 0,
    ('INE', datetime.date(year=2020, month=11, day=29)): 0,
    ('INE', datetime.date(year=2020, month=11, day=30)): 1,
    ('INE', datetime.date(year=2020, month=12, day=1)): 1,
    ('INE', datetime.date(year=2020, month=12, day=2)): 1,
    ('INE', datetime.date(year=2020, month=12, day=3)): 1,
    ('INE', datetime.date(year=2020, month=12, day=4)): 1,
    ('INE', datetime.date(year=2020, month=12, day=5)): 0,
    ('INE', datetime.date(year=2020, month=12, day=6)): 0,
    ('INE', datetime.date(year=2020, month=12, day=7)): 1,
    ('INE', datetime.date(year=2020, month=12, day=8)): 1,
    ('INE', datetime.date(year=2020, month=12, day=9)): 1,
    ('INE', datetime.date(year=2020, month=12, day=10)): 1,
    ('INE', datetime.date(year=2020, month=12, day=11)): 1,
    ('INE', datetime.date(year=2020, month=12, day=12)): 0,
    ('INE', datetime.date(year=2020, month=12, day=13)): 0,
    ('INE', datetime.date(year=2020, month=12, day=14)): 1,
    ('INE', datetime.date(year=2020, month=12, day=15)): 1,
    ('INE', datetime.date(year=2020, month=12, day=16)): 1,
    ('INE', datetime.date(year=2020, month=12, day=17)): 1,
    ('INE', datetime.date(year=2020, month=12, day=18)): 1,
    ('INE', datetime.date(year=2020, month=12, day=19)): 0,
    ('INE', datetime.date(year=2020, month=12, day=20)): 0,
    ('INE', datetime.date(year=2020, month=12, day=21)): 1,
    ('INE', datetime.date(year=2020, month=12, day=22)): 1,
    ('INE', datetime.date(year=2020, month=12, day=23)): 1,
    ('INE', datetime.date(year=2020, month=12, day=24)): 1,
    ('INE', datetime.date(year=2020, month=12, day=25)): 1,
    ('INE', datetime.date(year=2020, month=12, day=26)): 0,
    ('INE', datetime.date(year=2020, month=12, day=27)): 0,
    ('INE', datetime.date(year=2020, month=12, day=28)): 1,
    ('INE', datetime.date(year=2020, month=12, day=29)): 1,
    ('INE', datetime.date(year=2020, month=12, day=30)): 1,
    ('INE', datetime.date(year=2020, month=12, day=31)): 1,
    ('INE', datetime.date(year=2021, month=1, day=1)): 0,
    ('INE', datetime.date(year=2021, month=1, day=2)): 0,
    ('INE', datetime.date(year=2021, month=1, day=3)): 0,
    ('INE', datetime.date(year=2021, month=1, day=4)): 1,
    ('INE', datetime.date(year=2021, month=1, day=5)): 1,
    ('INE', datetime.date(year=2021, month=1, day=6)): 1,
    ('INE', datetime.date(year=2021, month=1, day=7)): 1,
    ('INE', datetime.date(year=2021, month=1, day=8)): 1,
    ('INE', datetime.date(year=2021, month=1, day=9)): 0,
    ('INE', datetime.date(year=2021, month=1, day=10)): 0,
    ('INE', datetime.date(year=2021, month=1, day=11)): 1,
    ('INE', datetime.date(year=2021, month=1, day=12)): 1,
    ('INE', datetime.date(year=2021, month=1, day=13)): 1,
    ('INE', datetime.date(year=2021, month=1, day=14)): 1,
    ('INE', datetime.date(year=2021, month=1, day=15)): 1,
    ('INE', datetime.date(year=2021, month=1, day=16)): 0,
    ('INE', datetime.date(year=2021, month=1, day=17)): 0,
    ('INE', datetime.date(year=2021, month=1, day=18)): 1,
    ('INE', datetime.date(year=2021, month=1, day=19)): 1,
    ('INE', datetime.date(year=2021, month=1, day=20)): 1,
    ('INE', datetime.date(year=2021, month=1, day=21)): 1,
    ('INE', datetime.date(year=2021, month=1, day=22)): 1,
    ('INE', datetime.date(year=2021, month=1, day=23)): 0,
    ('INE', datetime.date(year=2021, month=1, day=24)): 0,
    ('INE', datetime.date(year=2021, month=1, day=25)): 1,
    ('INE', datetime.date(year=2021, month=1, day=26)): 1,
    ('INE', datetime.date(year=2021, month=1, day=27)): 1,
    ('INE', datetime.date(year=2021, month=1, day=28)): 1,
    ('INE', datetime.date(year=2021, month=1, day=29)): 1,
    ('INE', datetime.date(year=2021, month=1, day=30)): 0,
    ('INE', datetime.date(year=2021, month=1, day=31)): 0,
    ('INE', datetime.date(year=2021, month=2, day=1)): 1,
    ('INE', datetime.date(year=2021, month=2, day=2)): 1,
    ('INE', datetime.date(year=2021, month=2, day=3)): 1,
    ('INE', datetime.date(year=2021, month=2, day=4)): 1,
    ('INE', datetime.date(year=2021, month=2, day=5)): 1,
    ('INE', datetime.date(year=2021, month=2, day=6)): 0,
    ('INE', datetime.date(year=2021, month=2, day=7)): 0,
    ('INE', datetime.date(year=2021, month=2, day=8)): 1,
    ('INE', datetime.date(year=2021, month=2, day=9)): 1,
    ('INE', datetime.date(year=2021, month=2, day=10)): 1,
    ('INE', datetime.date(year=2021, month=2, day=11)): 0,
    ('INE', datetime.date(year=2021, month=2, day=12)): 0,
    ('INE', datetime.date(year=2021, month=2, day=13)): 0,
    ('INE', datetime.date(year=2021, month=2, day=14)): 0,
    ('INE', datetime.date(year=2021, month=2, day=15)): 0,
    ('INE', datetime.date(year=2021, month=2, day=16)): 0,
    ('INE', datetime.date(year=2021, month=2, day=17)): 0,
    ('INE', datetime.date(year=2021, month=2, day=18)): 1,
    ('INE', datetime.date(year=2021, month=2, day=19)): 1,
    ('INE', datetime.date(year=2021, month=2, day=20)): 0,
    ('INE', datetime.date(year=2021, month=2, day=21)): 0,
    ('INE', datetime.date(year=2021, month=2, day=22)): 1,
    ('INE', datetime.date(year=2021, month=2, day=23)): 1,
    ('INE', datetime.date(year=2021, month=2, day=24)): 1,
    ('INE', datetime.date(year=2021, month=2, day=25)): 1,
    ('INE', datetime.date(year=2021, month=2, day=26)): 1,
    ('INE', datetime.date(year=2021, month=2, day=27)): 0,
    ('INE', datetime.date(year=2021, month=2, day=28)): 0,
    ('INE', datetime.date(year=2021, month=3, day=1)): 1,
    ('INE', datetime.date(year=2021, month=3, day=2)): 1,
    ('INE', datetime.date(year=2021, month=3, day=3)): 1,
    ('INE', datetime.date(year=2021, month=3, day=4)): 1,
    ('INE', datetime.date(year=2021, month=3, day=5)): 1,
    ('INE', datetime.date(year=2021, month=3, day=6)): 0,
    ('INE', datetime.date(year=2021, month=3, day=7)): 0,
    ('INE', datetime.date(year=2021, month=3, day=8)): 1,
    ('INE', datetime.date(year=2021, month=3, day=9)): 1,
    ('INE', datetime.date(year=2021, month=3, day=10)): 1,
    ('INE', datetime.date(year=2021, month=3, day=11)): 1,
    ('INE', datetime.date(year=2021, month=3, day=12)): 1,
    ('INE', datetime.date(year=2021, month=3, day=13)): 0,
    ('INE', datetime.date(year=2021, month=3, day=14)): 0,
    ('INE', datetime.date(year=2021, month=3, day=15)): 1,
    ('INE', datetime.date(year=2021, month=3, day=16)): 1,
    ('INE', datetime.date(year=2021, month=3, day=17)): 1,
    ('INE', datetime.date(year=2021, month=3, day=18)): 1,
    ('INE', datetime.date(year=2021, month=3, day=19)): 1,
    ('INE', datetime.date(year=2021, month=3, day=20)): 0,
    ('INE', datetime.date(year=2021, month=3, day=21)): 0,
    ('INE', datetime.date(year=2021, month=3, day=22)): 1,
    ('INE', datetime.date(year=2021, month=3, day=23)): 1,
    ('INE', datetime.date(year=2021, month=3, day=24)): 1,
    ('INE', datetime.date(year=2021, month=3, day=25)): 1,
    ('INE', datetime.date(year=2021, month=3, day=26)): 1,
    ('INE', datetime.date(year=2021, month=3, day=27)): 0,
    ('INE', datetime.date(year=2021, month=3, day=28)): 0,
    ('INE', datetime.date(year=2021, month=3, day=29)): 1,
    ('INE', datetime.date(year=2021, month=3, day=30)): 1,
    ('INE', datetime.date(year=2021, month=3, day=31)): 1,
    ('INE', datetime.date(year=2021, month=4, day=1)): 1,
    ('INE', datetime.date(year=2021, month=4, day=2)): 1,
    ('INE', datetime.date(year=2021, month=4, day=3)): 0,
    ('INE', datetime.date(year=2021, month=4, day=4)): 0,
    ('INE', datetime.date(year=2021, month=4, day=5)): 0,
    ('INE', datetime.date(year=2021, month=4, day=6)): 1,
    ('INE', datetime.date(year=2021, month=4, day=7)): 1,
    ('INE', datetime.date(year=2021, month=4, day=8)): 1,
    ('INE', datetime.date(year=2021, month=4, day=9)): 1,
    ('INE', datetime.date(year=2021, month=4, day=10)): 0,
    ('INE', datetime.date(year=2021, month=4, day=11)): 0,
    ('INE', datetime.date(year=2021, month=4, day=12)): 1,
    ('INE', datetime.date(year=2021, month=4, day=13)): 1,
    ('INE', datetime.date(year=2021, month=4, day=14)): 1,
    ('INE', datetime.date(year=2021, month=4, day=15)): 1,
    ('INE', datetime.date(year=2021, month=4, day=16)): 1,
    ('INE', datetime.date(year=2021, month=4, day=17)): 0,
    ('INE', datetime.date(year=2021, month=4, day=18)): 0,
    ('INE', datetime.date(year=2021, month=4, day=19)): 1,
    ('INE', datetime.date(year=2021, month=4, day=20)): 1,
    ('INE', datetime.date(year=2021, month=4, day=21)): 1,
    ('INE', datetime.date(year=2021, month=4, day=22)): 1,
    ('INE', datetime.date(year=2021, month=4, day=23)): 1,
    ('INE', datetime.date(year=2021, month=4, day=24)): 0,
    ('INE', datetime.date(year=2021, month=4, day=25)): 0,
    ('INE', datetime.date(year=2021, month=4, day=26)): 1,
    ('INE', datetime.date(year=2021, month=4, day=27)): 1,
    ('INE', datetime.date(year=2021, month=4, day=28)): 1,
    ('INE', datetime.date(year=2021, month=4, day=29)): 1,
    ('INE', datetime.date(year=2021, month=4, day=30)): 1,
    ('INE', datetime.date(year=2021, month=5, day=1)): 0,
    ('INE', datetime.date(year=2021, month=5, day=2)): 0,
    ('INE', datetime.date(year=2021, month=5, day=3)): 0,
    ('INE', datetime.date(year=2021, month=5, day=4)): 0,
    ('INE', datetime.date(year=2021, month=5, day=5)): 0,
    ('INE', datetime.date(year=2021, month=5, day=6)): 1,
    ('INE', datetime.date(year=2021, month=5, day=7)): 1,
    ('INE', datetime.date(year=2021, month=5, day=8)): 0,
    ('INE', datetime.date(year=2021, month=5, day=9)): 0,
    ('INE', datetime.date(year=2021, month=5, day=10)): 1,
    ('INE', datetime.date(year=2021, month=5, day=11)): 1,
    ('INE', datetime.date(year=2021, month=5, day=12)): 1,
    ('INE', datetime.date(year=2021, month=5, day=13)): 1,
    ('INE', datetime.date(year=2021, month=5, day=14)): 1,
    ('INE', datetime.date(year=2021, month=5, day=15)): 0,
    ('INE', datetime.date(year=2021, month=5, day=16)): 0,
    ('INE', datetime.date(year=2021, month=5, day=17)): 1,
    ('INE', datetime.date(year=2021, month=5, day=18)): 1,
    ('INE', datetime.date(year=2021, month=5, day=19)): 1,
    ('INE', datetime.date(year=2021, month=5, day=20)): 1,
    ('INE', datetime.date(year=2021, month=5, day=21)): 1,
    ('INE', datetime.date(year=2021, month=5, day=22)): 0,
    ('INE', datetime.date(year=2021, month=5, day=23)): 0,
    ('INE', datetime.date(year=2021, month=5, day=24)): 1,
    ('INE', datetime.date(year=2021, month=5, day=25)): 1,
    ('INE', datetime.date(year=2021, month=5, day=26)): 1,
    ('INE', datetime.date(year=2021, month=5, day=27)): 1,
    ('INE', datetime.date(year=2021, month=5, day=28)): 1,
    ('INE', datetime.date(year=2021, month=5, day=29)): 0,
    ('INE', datetime.date(year=2021, month=5, day=30)): 0,
    ('INE', datetime.date(year=2021, month=5, day=31)): 1,
    ('INE', datetime.date(year=2021, month=6, day=1)): 1,
    ('INE', datetime.date(year=2021, month=6, day=2)): 1,
    ('INE', datetime.date(year=2021, month=6, day=3)): 1,
    ('INE', datetime.date(year=2021, month=6, day=4)): 1,
    ('INE', datetime.date(year=2021, month=6, day=5)): 0,
    ('INE', datetime.date(year=2021, month=6, day=6)): 0,
    ('INE', datetime.date(year=2021, month=6, day=7)): 1,
    ('INE', datetime.date(year=2021, month=6, day=8)): 1,
    ('INE', datetime.date(year=2021, month=6, day=9)): 1,
    ('INE', datetime.date(year=2021, month=6, day=10)): 1,
    ('INE', datetime.date(year=2021, month=6, day=11)): 1,
    ('INE', datetime.date(year=2021, month=6, day=12)): 0,
    ('INE', datetime.date(year=2021, month=6, day=13)): 0,
    ('INE', datetime.date(year=2021, month=6, day=14)): 0,
    ('INE', datetime.date(year=2021, month=6, day=15)): 1,
    ('INE', datetime.date(year=2021, month=6, day=16)): 1,
    ('INE', datetime.date(year=2021, month=6, day=17)): 1,
    ('INE', datetime.date(year=2021, month=6, day=18)): 1,
    ('INE', datetime.date(year=2021, month=6, day=19)): 0,
    ('INE', datetime.date(year=2021, month=6, day=20)): 0,
    ('INE', datetime.date(year=2021, month=6, day=21)): 1,
    ('INE', datetime.date(year=2021, month=6, day=22)): 1,
    ('INE', datetime.date(year=2021, month=6, day=23)): 1,
    ('INE', datetime.date(year=2021, month=6, day=24)): 1,
    ('INE', datetime.date(year=2021, month=6, day=25)): 1,
    ('INE', datetime.date(year=2021, month=6, day=26)): 0,
    ('INE', datetime.date(year=2021, month=6, day=27)): 0,
    ('INE', datetime.date(year=2021, month=6, day=28)): 1,
    ('INE', datetime.date(year=2021, month=6, day=29)): 1,
    ('INE', datetime.date(year=2021, month=6, day=30)): 1,
    ('INE', datetime.date(year=2021, month=7, day=1)): 1,
    ('INE', datetime.date(year=2021, month=7, day=2)): 1,
    ('INE', datetime.date(year=2021, month=7, day=3)): 0,
    ('INE', datetime.date(year=2021, month=7, day=4)): 0,
    ('INE', datetime.date(year=2021, month=7, day=5)): 1,
    ('INE', datetime.date(year=2021, month=7, day=6)): 1,
    ('INE', datetime.date(year=2021, month=7, day=7)): 1,
    ('INE', datetime.date(year=2021, month=7, day=8)): 1,
    ('INE', datetime.date(year=2021, month=7, day=9)): 1,
    ('INE', datetime.date(year=2021, month=7, day=10)): 0,
    ('INE', datetime.date(year=2021, month=7, day=11)): 0,
    ('INE', datetime.date(year=2021, month=7, day=12)): 1,
    ('INE', datetime.date(year=2021, month=7, day=13)): 1,
    ('INE', datetime.date(year=2021, month=7, day=14)): 1,
    ('INE', datetime.date(year=2021, month=7, day=15)): 1,
    ('INE', datetime.date(year=2021, month=7, day=16)): 1,
    ('INE', datetime.date(year=2021, month=7, day=17)): 0,
    ('INE', datetime.date(year=2021, month=7, day=18)): 0,
    ('INE', datetime.date(year=2021, month=7, day=19)): 1,
    ('INE', datetime.date(year=2021, month=7, day=20)): 1,
    ('INE', datetime.date(year=2021, month=7, day=21)): 1,
    ('INE', datetime.date(year=2021, month=7, day=22)): 1,
    ('INE', datetime.date(year=2021, month=7, day=23)): 1,
    ('INE', datetime.date(year=2021, month=7, day=24)): 0,
    ('INE', datetime.date(year=2021, month=7, day=25)): 0,
    ('INE', datetime.date(year=2021, month=7, day=26)): 1,
    ('INE', datetime.date(year=2021, month=7, day=27)): 1,
    ('INE', datetime.date(year=2021, month=7, day=28)): 1,
    ('INE', datetime.date(year=2021, month=7, day=29)): 1,
    ('INE', datetime.date(year=2021, month=7, day=30)): 1,
    ('INE', datetime.date(year=2021, month=7, day=31)): 0,
    ('INE', datetime.date(year=2021, month=8, day=1)): 0,
    ('INE', datetime.date(year=2021, month=8, day=2)): 1,
    ('INE', datetime.date(year=2021, month=8, day=3)): 1,
    ('INE', datetime.date(year=2021, month=8, day=4)): 1,
    ('INE', datetime.date(year=2021, month=8, day=5)): 1,
    ('INE', datetime.date(year=2021, month=8, day=6)): 1,
    ('INE', datetime.date(year=2021, month=8, day=7)): 0,
    ('INE', datetime.date(year=2021, month=8, day=8)): 0,
    ('INE', datetime.date(year=2021, month=8, day=9)): 1,
    ('INE', datetime.date(year=2021, month=8, day=10)): 1,
    ('INE', datetime.date(year=2021, month=8, day=11)): 1,
    ('INE', datetime.date(year=2021, month=8, day=12)): 1,
    ('INE', datetime.date(year=2021, month=8, day=13)): 1,
    ('INE', datetime.date(year=2021, month=8, day=14)): 0,
    ('INE', datetime.date(year=2021, month=8, day=15)): 0,
    ('INE', datetime.date(year=2021, month=8, day=16)): 1,
    ('INE', datetime.date(year=2021, month=8, day=17)): 1,
    ('INE', datetime.date(year=2021, month=8, day=18)): 1,
    ('INE', datetime.date(year=2021, month=8, day=19)): 1,
    ('INE', datetime.date(year=2021, month=8, day=20)): 1,
    ('INE', datetime.date(year=2021, month=8, day=21)): 0,
    ('INE', datetime.date(year=2021, month=8, day=22)): 0,
    ('INE', datetime.date(year=2021, month=8, day=23)): 1,
    ('INE', datetime.date(year=2021, month=8, day=24)): 1,
    ('INE', datetime.date(year=2021, month=8, day=25)): 1,
    ('INE', datetime.date(year=2021, month=8, day=26)): 1,
    ('INE', datetime.date(year=2021, month=8, day=27)): 1,
    ('INE', datetime.date(year=2021, month=8, day=28)): 0,
    ('INE', datetime.date(year=2021, month=8, day=29)): 0,
    ('INE', datetime.date(year=2021, month=8, day=30)): 1,
    ('INE', datetime.date(year=2021, month=8, day=31)): 1,
    ('INE', datetime.date(year=2021, month=9, day=1)): 1,
    ('INE', datetime.date(year=2021, month=9, day=2)): 1,
    ('INE', datetime.date(year=2021, month=9, day=3)): 1,
    ('INE', datetime.date(year=2021, month=9, day=4)): 0,
    ('INE', datetime.date(year=2021, month=9, day=5)): 0,
    ('INE', datetime.date(year=2021, month=9, day=6)): 1,
    ('INE', datetime.date(year=2021, month=9, day=7)): 1,
    ('INE', datetime.date(year=2021, month=9, day=8)): 1,
    ('INE', datetime.date(year=2021, month=9, day=9)): 1,
    ('INE', datetime.date(year=2021, month=9, day=10)): 1,
    ('INE', datetime.date(year=2021, month=9, day=11)): 0,
    ('INE', datetime.date(year=2021, month=9, day=12)): 0,
    ('INE', datetime.date(year=2021, month=9, day=13)): 1,
    ('INE', datetime.date(year=2021, month=9, day=14)): 1,
    ('INE', datetime.date(year=2021, month=9, day=15)): 1,
    ('INE', datetime.date(year=2021, month=9, day=16)): 1,
    ('INE', datetime.date(year=2021, month=9, day=17)): 1,
    ('INE', datetime.date(year=2021, month=9, day=18)): 0,
    ('INE', datetime.date(year=2021, month=9, day=19)): 0,
    ('INE', datetime.date(year=2021, month=9, day=20)): 0,
    ('INE', datetime.date(year=2021, month=9, day=21)): 0,
    ('INE', datetime.date(year=2021, month=9, day=22)): 1,
    ('INE', datetime.date(year=2021, month=9, day=23)): 1,
    ('INE', datetime.date(year=2021, month=9, day=24)): 1,
    ('INE', datetime.date(year=2021, month=9, day=25)): 0,
    ('INE', datetime.date(year=2021, month=9, day=26)): 0,
    ('INE', datetime.date(year=2021, month=9, day=27)): 1,
    ('INE', datetime.date(year=2021, month=9, day=28)): 1,
    ('INE', datetime.date(year=2021, month=9, day=29)): 1,
    ('INE', datetime.date(year=2021, month=9, day=30)): 1,
    ('INE', datetime.date(year=2021, month=10, day=1)): 0,
    ('INE', datetime.date(year=2021, month=10, day=2)): 0,
    ('INE', datetime.date(year=2021, month=10, day=3)): 0,
    ('INE', datetime.date(year=2021, month=10, day=4)): 0,
    ('INE', datetime.date(year=2021, month=10, day=5)): 0,
    ('INE', datetime.date(year=2021, month=10, day=6)): 0,
    ('INE', datetime.date(year=2021, month=10, day=7)): 0,
    ('INE', datetime.date(year=2021, month=10, day=8)): 1,
    ('INE', datetime.date(year=2021, month=10, day=9)): 0,
    ('INE', datetime.date(year=2021, month=10, day=10)): 0,
    ('INE', datetime.date(year=2021, month=10, day=11)): 1,
    ('INE', datetime.date(year=2021, month=10, day=12)): 1,
    ('INE', datetime.date(year=2021, month=10, day=13)): 1,
    ('INE', datetime.date(year=2021, month=10, day=14)): 1,
    ('INE', datetime.date(year=2021, month=10, day=15)): 1,
    ('INE', datetime.date(year=2021, month=10, day=16)): 0,
    ('INE', datetime.date(year=2021, month=10, day=17)): 0,
    ('INE', datetime.date(year=2021, month=10, day=18)): 1,
    ('INE', datetime.date(year=2021, month=10, day=19)): 1,
    ('INE', datetime.date(year=2021, month=10, day=20)): 1,
    ('INE', datetime.date(year=2021, month=10, day=21)): 1,
    ('INE', datetime.date(year=2021, month=10, day=22)): 1,
    ('INE', datetime.date(year=2021, month=10, day=23)): 0,
    ('INE', datetime.date(year=2021, month=10, day=24)): 0,
    ('INE', datetime.date(year=2021, month=10, day=25)): 1,
    ('INE', datetime.date(year=2021, month=10, day=26)): 1,
    ('INE', datetime.date(year=2021, month=10, day=27)): 1,
    ('INE', datetime.date(year=2021, month=10, day=28)): 1,
    ('INE', datetime.date(year=2021, month=10, day=29)): 1,
    ('INE', datetime.date(year=2021, month=10, day=30)): 0,
    ('INE', datetime.date(year=2021, month=10, day=31)): 0,
    ('INE', datetime.date(year=2021, month=11, day=1)): 1,
    ('INE', datetime.date(year=2021, month=11, day=2)): 1,
    ('INE', datetime.date(year=2021, month=11, day=3)): 1,
    ('INE', datetime.date(year=2021, month=11, day=4)): 1,
    ('INE', datetime.date(year=2021, month=11, day=5)): 1,
    ('INE', datetime.date(year=2021, month=11, day=6)): 0,
    ('INE', datetime.date(year=2021, month=11, day=7)): 0,
    ('INE', datetime.date(year=2021, month=11, day=8)): 1,
    ('INE', datetime.date(year=2021, month=11, day=9)): 1,
    ('INE', datetime.date(year=2021, month=11, day=10)): 1,
    ('INE', datetime.date(year=2021, month=11, day=11)): 1,
    ('INE', datetime.date(year=2021, month=11, day=12)): 1,
    ('INE', datetime.date(year=2021, month=11, day=13)): 0,
    ('INE', datetime.date(year=2021, month=11, day=14)): 0,
    ('INE', datetime.date(year=2021, month=11, day=15)): 1,
    ('INE', datetime.date(year=2021, month=11, day=16)): 1,
    ('INE', datetime.date(year=2021, month=11, day=17)): 1,
    ('INE', datetime.date(year=2021, month=11, day=18)): 1,
    ('INE', datetime.date(year=2021, month=11, day=19)): 1,
    ('INE', datetime.date(year=2021, month=11, day=20)): 0,
    ('INE', datetime.date(year=2021, month=11, day=21)): 0,
    ('INE', datetime.date(year=2021, month=11, day=22)): 1,
    ('INE', datetime.date(year=2021, month=11, day=23)): 1,
    ('INE', datetime.date(year=2021, month=11, day=24)): 1,
    ('INE', datetime.date(year=2021, month=11, day=25)): 1,
    ('INE', datetime.date(year=2021, month=11, day=26)): 1,
    ('INE', datetime.date(year=2021, month=11, day=27)): 0,
    ('INE', datetime.date(year=2021, month=11, day=28)): 0,
    ('INE', datetime.date(year=2021, month=11, day=29)): 1,
    ('INE', datetime.date(year=2021, month=11, day=30)): 1,
    ('INE', datetime.date(year=2021, month=12, day=1)): 1,
    ('INE', datetime.date(year=2021, month=12, day=2)): 1,
    ('INE', datetime.date(year=2021, month=12, day=3)): 1,
    ('INE', datetime.date(year=2021, month=12, day=4)): 0,
    ('INE', datetime.date(year=2021, month=12, day=5)): 0,
    ('INE', datetime.date(year=2021, month=12, day=6)): 1,
    ('INE', datetime.date(year=2021, month=12, day=7)): 1,
    ('INE', datetime.date(year=2021, month=12, day=8)): 1,
    ('INE', datetime.date(year=2021, month=12, day=9)): 1,
    ('INE', datetime.date(year=2021, month=12, day=10)): 1,
    ('INE', datetime.date(year=2021, month=12, day=11)): 0,
    ('INE', datetime.date(year=2021, month=12, day=12)): 0,
    ('INE', datetime.date(year=2021, month=12, day=13)): 1,
    ('INE', datetime.date(year=2021, month=12, day=14)): 1,
    ('INE', datetime.date(year=2021, month=12, day=15)): 1,
    ('INE', datetime.date(year=2021, month=12, day=16)): 1,
    ('INE', datetime.date(year=2021, month=12, day=17)): 1,
    ('INE', datetime.date(year=2021, month=12, day=18)): 0,
    ('INE', datetime.date(year=2021, month=12, day=19)): 0,
    ('INE', datetime.date(year=2021, month=12, day=20)): 1,
    ('INE', datetime.date(year=2021, month=12, day=21)): 1,
    ('INE', datetime.date(year=2021, month=12, day=22)): 1,
    ('INE', datetime.date(year=2021, month=12, day=23)): 1,
    ('INE', datetime.date(year=2021, month=12, day=24)): 1,
    ('INE', datetime.date(year=2021, month=12, day=25)): 0,
    ('INE', datetime.date(year=2021, month=12, day=26)): 0,
    ('INE', datetime.date(year=2021, month=12, day=27)): 1,
    ('INE', datetime.date(year=2021, month=12, day=28)): 1,
    ('INE', datetime.date(year=2021, month=12, day=29)): 1,
    ('INE', datetime.date(year=2021, month=12, day=30)): 1,
    ('INE', datetime.date(year=2021, month=12, day=31)): 1,
    ('INE', datetime.date(year=2022, month=1, day=1)): 0,
    ('INE', datetime.date(year=2022, month=1, day=2)): 0,
    ('INE', datetime.date(year=2022, month=1, day=3)): 0,
    ('INE', datetime.date(year=2022, month=1, day=4)): 1,
    ('INE', datetime.date(year=2022, month=1, day=5)): 1,
    ('INE', datetime.date(year=2022, month=1, day=6)): 1,
    ('INE', datetime.date(year=2022, month=1, day=7)): 1,
    ('INE', datetime.date(year=2022, month=1, day=8)): 0,
    ('INE', datetime.date(year=2022, month=1, day=9)): 0,
    ('INE', datetime.date(year=2022, month=1, day=10)): 1,
    ('INE', datetime.date(year=2022, month=1, day=11)): 1,
    ('INE', datetime.date(year=2022, month=1, day=12)): 1,
    ('INE', datetime.date(year=2022, month=1, day=13)): 1,
    ('INE', datetime.date(year=2022, month=1, day=14)): 1,
    ('INE', datetime.date(year=2022, month=1, day=15)): 0,
    ('INE', datetime.date(year=2022, month=1, day=16)): 0,
    ('INE', datetime.date(year=2022, month=1, day=17)): 1,
    ('INE', datetime.date(year=2022, month=1, day=18)): 1,
    ('INE', datetime.date(year=2022, month=1, day=19)): 1,
    ('INE', datetime.date(year=2022, month=1, day=20)): 1,
    ('INE', datetime.date(year=2022, month=1, day=21)): 1,
    ('INE', datetime.date(year=2022, month=1, day=22)): 0,
    ('INE', datetime.date(year=2022, month=1, day=23)): 0,
    ('INE', datetime.date(year=2022, month=1, day=24)): 1,
    ('INE', datetime.date(year=2022, month=1, day=25)): 1,
    ('INE', datetime.date(year=2022, month=1, day=26)): 1,
    ('INE', datetime.date(year=2022, month=1, day=27)): 1,
    ('INE', datetime.date(year=2022, month=1, day=28)): 1,
    ('INE', datetime.date(year=2022, month=1, day=29)): 0,
    ('INE', datetime.date(year=2022, month=1, day=30)): 0,
    ('INE', datetime.date(year=2022, month=1, day=31)): 0,
    ('INE', datetime.date(year=2022, month=2, day=1)): 0,
    ('INE', datetime.date(year=2022, month=2, day=2)): 0,
    ('INE', datetime.date(year=2022, month=2, day=3)): 0,
    ('INE', datetime.date(year=2022, month=2, day=4)): 0,
    ('INE', datetime.date(year=2022, month=2, day=5)): 0,
    ('INE', datetime.date(year=2022, month=2, day=6)): 0,
    ('INE', datetime.date(year=2022, month=2, day=7)): 1,
    ('INE', datetime.date(year=2022, month=2, day=8)): 1,
    ('INE', datetime.date(year=2022, month=2, day=9)): 1,
    ('INE', datetime.date(year=2022, month=2, day=10)): 1,
    ('INE', datetime.date(year=2022, month=2, day=11)): 1,
    ('INE', datetime.date(year=2022, month=2, day=12)): 0,
    ('INE', datetime.date(year=2022, month=2, day=13)): 0,
    ('INE', datetime.date(year=2022, month=2, day=14)): 1,
    ('INE', datetime.date(year=2022, month=2, day=15)): 1,
    ('INE', datetime.date(year=2022, month=2, day=16)): 1,
    ('INE', datetime.date(year=2022, month=2, day=17)): 1,
    ('INE', datetime.date(year=2022, month=2, day=18)): 1,
    ('INE', datetime.date(year=2022, month=2, day=19)): 0,
    ('INE', datetime.date(year=2022, month=2, day=20)): 0,
    ('INE', datetime.date(year=2022, month=2, day=21)): 1,
    ('INE', datetime.date(year=2022, month=2, day=22)): 1,
    ('INE', datetime.date(year=2022, month=2, day=23)): 1,
    ('INE', datetime.date(year=2022, month=2, day=24)): 1,
    ('INE', datetime.date(year=2022, month=2, day=25)): 1,
    ('INE', datetime.date(year=2022, month=2, day=26)): 0,
    ('INE', datetime.date(year=2022, month=2, day=27)): 0,
    ('INE', datetime.date(year=2022, month=2, day=28)): 1,
    ('INE', datetime.date(year=2022, month=3, day=1)): 1,
    ('INE', datetime.date(year=2022, month=3, day=2)): 1,
    ('INE', datetime.date(year=2022, month=3, day=3)): 1,
    ('INE', datetime.date(year=2022, month=3, day=4)): 1,
    ('INE', datetime.date(year=2022, month=3, day=5)): 0,
    ('INE', datetime.date(year=2022, month=3, day=6)): 0,
    ('INE', datetime.date(year=2022, month=3, day=7)): 1,
    ('INE', datetime.date(year=2022, month=3, day=8)): 1,
    ('INE', datetime.date(year=2022, month=3, day=9)): 1,
    ('INE', datetime.date(year=2022, month=3, day=10)): 1,
    ('INE', datetime.date(year=2022, month=3, day=11)): 1,
    ('INE', datetime.date(year=2022, month=3, day=12)): 0,
    ('INE', datetime.date(year=2022, month=3, day=13)): 0,
    ('INE', datetime.date(year=2022, month=3, day=14)): 1,
    ('INE', datetime.date(year=2022, month=3, day=15)): 1,
    ('INE', datetime.date(year=2022, month=3, day=16)): 1,
    ('INE', datetime.date(year=2022, month=3, day=17)): 1,
    ('INE', datetime.date(year=2022, month=3, day=18)): 1,
    ('INE', datetime.date(year=2022, month=3, day=19)): 0,
    ('INE', datetime.date(year=2022, month=3, day=20)): 0,
    ('INE', datetime.date(year=2022, month=3, day=21)): 1,
    ('INE', datetime.date(year=2022, month=3, day=22)): 1,
    ('INE', datetime.date(year=2022, month=3, day=23)): 1,
    ('INE', datetime.date(year=2022, month=3, day=24)): 1,
    ('INE', datetime.date(year=2022, month=3, day=25)): 1,
    ('INE', datetime.date(year=2022, month=3, day=26)): 0,
    ('INE', datetime.date(year=2022, month=3, day=27)): 0,
    ('INE', datetime.date(year=2022, month=3, day=28)): 1,
    ('INE', datetime.date(year=2022, month=3, day=29)): 1,
    ('INE', datetime.date(year=2022, month=3, day=30)): 1,
    ('INE', datetime.date(year=2022, month=3, day=31)): 1,
    ('INE', datetime.date(year=2022, month=4, day=1)): 1,
    ('INE', datetime.date(year=2022, month=4, day=2)): 0,
    ('INE', datetime.date(year=2022, month=4, day=3)): 0,
    ('INE', datetime.date(year=2022, month=4, day=4)): 0,
    ('INE', datetime.date(year=2022, month=4, day=5)): 0,
    ('INE', datetime.date(year=2022, month=4, day=6)): 1,
    ('INE', datetime.date(year=2022, month=4, day=7)): 1,
    ('INE', datetime.date(year=2022, month=4, day=8)): 1,
    ('INE', datetime.date(year=2022, month=4, day=9)): 0,
    ('INE', datetime.date(year=2022, month=4, day=10)): 0,
    ('INE', datetime.date(year=2022, month=4, day=11)): 1,
    ('INE', datetime.date(year=2022, month=4, day=12)): 1,
    ('INE', datetime.date(year=2022, month=4, day=13)): 1,
    ('INE', datetime.date(year=2022, month=4, day=14)): 1,
    ('INE', datetime.date(year=2022, month=4, day=15)): 1,
    ('INE', datetime.date(year=2022, month=4, day=16)): 0,
    ('INE', datetime.date(year=2022, month=4, day=17)): 0,
    ('INE', datetime.date(year=2022, month=4, day=18)): 1,
    ('INE', datetime.date(year=2022, month=4, day=19)): 1,
    ('INE', datetime.date(year=2022, month=4, day=20)): 1,
    ('INE', datetime.date(year=2022, month=4, day=21)): 1,
    ('INE', datetime.date(year=2022, month=4, day=22)): 1,
    ('INE', datetime.date(year=2022, month=4, day=23)): 0,
    ('INE', datetime.date(year=2022, month=4, day=24)): 0,
    ('INE', datetime.date(year=2022, month=4, day=25)): 1,
    ('INE', datetime.date(year=2022, month=4, day=26)): 1,
    ('INE', datetime.date(year=2022, month=4, day=27)): 1,
    ('INE', datetime.date(year=2022, month=4, day=28)): 1,
    ('INE', datetime.date(year=2022, month=4, day=29)): 1,
    ('INE', datetime.date(year=2022, month=4, day=30)): 0,
    ('INE', datetime.date(year=2022, month=5, day=1)): 0,
    ('INE', datetime.date(year=2022, month=5, day=2)): 0,
    ('INE', datetime.date(year=2022, month=5, day=3)): 0,
    ('INE', datetime.date(year=2022, month=5, day=4)): 0,
    ('INE', datetime.date(year=2022, month=5, day=5)): 1,
    ('INE', datetime.date(year=2022, month=5, day=6)): 1,
    ('INE', datetime.date(year=2022, month=5, day=7)): 0,
    ('INE', datetime.date(year=2022, month=5, day=8)): 0,
    ('INE', datetime.date(year=2022, month=5, day=9)): 1,
    ('INE', datetime.date(year=2022, month=5, day=10)): 1,
    ('INE', datetime.date(year=2022, month=5, day=11)): 1,
    ('INE', datetime.date(year=2022, month=5, day=12)): 1,
    ('INE', datetime.date(year=2022, month=5, day=13)): 1,
    ('INE', datetime.date(year=2022, month=5, day=14)): 0,
    ('INE', datetime.date(year=2022, month=5, day=15)): 0,
    ('INE', datetime.date(year=2022, month=5, day=16)): 1,
    ('INE', datetime.date(year=2022, month=5, day=17)): 1,
    ('INE', datetime.date(year=2022, month=5, day=18)): 1,
    ('INE', datetime.date(year=2022, month=5, day=19)): 1,
    ('INE', datetime.date(year=2022, month=5, day=20)): 1,
    ('INE', datetime.date(year=2022, month=5, day=21)): 0,
    ('INE', datetime.date(year=2022, month=5, day=22)): 0,
    ('INE', datetime.date(year=2022, month=5, day=23)): 1,
    ('INE', datetime.date(year=2022, month=5, day=24)): 1,
    ('INE', datetime.date(year=2022, month=5, day=25)): 1,
    ('INE', datetime.date(year=2022, month=5, day=26)): 1,
    ('INE', datetime.date(year=2022, month=5, day=27)): 1,
    ('INE', datetime.date(year=2022, month=5, day=28)): 0,
    ('INE', datetime.date(year=2022, month=5, day=29)): 0,
    ('INE', datetime.date(year=2022, month=5, day=30)): 1,
    ('INE', datetime.date(year=2022, month=5, day=31)): 1,
    ('INE', datetime.date(year=2022, month=6, day=1)): 1,
    ('INE', datetime.date(year=2022, month=6, day=2)): 1,
    ('INE', datetime.date(year=2022, month=6, day=3)): 0,
    ('INE', datetime.date(year=2022, month=6, day=4)): 0,
    ('INE', datetime.date(year=2022, month=6, day=5)): 0,
    ('INE', datetime.date(year=2022, month=6, day=6)): 1,
    ('INE', datetime.date(year=2022, month=6, day=7)): 1,
    ('INE', datetime.date(year=2022, month=6, day=8)): 1,
    ('INE', datetime.date(year=2022, month=6, day=9)): 1,
    ('INE', datetime.date(year=2022, month=6, day=10)): 1,
    ('INE', datetime.date(year=2022, month=6, day=11)): 0,
    ('INE', datetime.date(year=2022, month=6, day=12)): 0,
    ('INE', datetime.date(year=2022, month=6, day=13)): 1,
    ('INE', datetime.date(year=2022, month=6, day=14)): 1,
    ('INE', datetime.date(year=2022, month=6, day=15)): 1,
    ('INE', datetime.date(year=2022, month=6, day=16)): 1,
    ('INE', datetime.date(year=2022, month=6, day=17)): 1,
    ('INE', datetime.date(year=2022, month=6, day=18)): 0,
    ('INE', datetime.date(year=2022, month=6, day=19)): 0,
    ('INE', datetime.date(year=2022, month=6, day=20)): 1,
    ('INE', datetime.date(year=2022, month=6, day=21)): 1,
    ('INE', datetime.date(year=2022, month=6, day=22)): 1,
    ('INE', datetime.date(year=2022, month=6, day=23)): 1,
    ('INE', datetime.date(year=2022, month=6, day=24)): 1,
    ('INE', datetime.date(year=2022, month=6, day=25)): 0,
    ('INE', datetime.date(year=2022, month=6, day=26)): 0,
    ('INE', datetime.date(year=2022, month=6, day=27)): 1,
    ('INE', datetime.date(year=2022, month=6, day=28)): 1,
    ('INE', datetime.date(year=2022, month=6, day=29)): 1,
    ('INE', datetime.date(year=2022, month=6, day=30)): 1,
    ('INE', datetime.date(year=2022, month=7, day=1)): 1,
    ('INE', datetime.date(year=2022, month=7, day=2)): 0,
    ('INE', datetime.date(year=2022, month=7, day=3)): 0,
    ('INE', datetime.date(year=2022, month=7, day=4)): 1,
    ('INE', datetime.date(year=2022, month=7, day=5)): 1,
    ('INE', datetime.date(year=2022, month=7, day=6)): 1,
    ('INE', datetime.date(year=2022, month=7, day=7)): 1,
    ('INE', datetime.date(year=2022, month=7, day=8)): 1,
    ('INE', datetime.date(year=2022, month=7, day=9)): 0,
    ('INE', datetime.date(year=2022, month=7, day=10)): 0,
    ('INE', datetime.date(year=2022, month=7, day=11)): 1,
    ('INE', datetime.date(year=2022, month=7, day=12)): 1,
    ('INE', datetime.date(year=2022, month=7, day=13)): 1,
    ('INE', datetime.date(year=2022, month=7, day=14)): 1,
    ('INE', datetime.date(year=2022, month=7, day=15)): 1,
    ('INE', datetime.date(year=2022, month=7, day=16)): 0,
    ('INE', datetime.date(year=2022, month=7, day=17)): 0,
    ('INE', datetime.date(year=2022, month=7, day=18)): 1,
    ('INE', datetime.date(year=2022, month=7, day=19)): 1,
    ('INE', datetime.date(year=2022, month=7, day=20)): 1,
    ('INE', datetime.date(year=2022, month=7, day=21)): 1,
    ('INE', datetime.date(year=2022, month=7, day=22)): 1,
    ('INE', datetime.date(year=2022, month=7, day=23)): 0,
    ('INE', datetime.date(year=2022, month=7, day=24)): 0,
    ('INE', datetime.date(year=2022, month=7, day=25)): 1,
    ('INE', datetime.date(year=2022, month=7, day=26)): 1,
    ('INE', datetime.date(year=2022, month=7, day=27)): 1,
    ('INE', datetime.date(year=2022, month=7, day=28)): 1,
    ('INE', datetime.date(year=2022, month=7, day=29)): 1,
    ('INE', datetime.date(year=2022, month=7, day=30)): 0,
    ('INE', datetime.date(year=2022, month=7, day=31)): 0,
    ('INE', datetime.date(year=2022, month=8, day=1)): 1,
    ('INE', datetime.date(year=2022, month=8, day=2)): 1,
    ('INE', datetime.date(year=2022, month=8, day=3)): 1,
    ('INE', datetime.date(year=2022, month=8, day=4)): 1,
    ('INE', datetime.date(year=2022, month=8, day=5)): 1,
    ('INE', datetime.date(year=2022, month=8, day=6)): 0,
    ('INE', datetime.date(year=2022, month=8, day=7)): 0,
    ('INE', datetime.date(year=2022, month=8, day=8)): 1,
    ('INE', datetime.date(year=2022, month=8, day=9)): 1,
    ('INE', datetime.date(year=2022, month=8, day=10)): 1,
    ('INE', datetime.date(year=2022, month=8, day=11)): 1,
    ('INE', datetime.date(year=2022, month=8, day=12)): 1,
    ('INE', datetime.date(year=2022, month=8, day=13)): 0,
    ('INE', datetime.date(year=2022, month=8, day=14)): 0,
    ('INE', datetime.date(year=2022, month=8, day=15)): 1,
    ('INE', datetime.date(year=2022, month=8, day=16)): 1,
    ('INE', datetime.date(year=2022, month=8, day=17)): 1,
    ('INE', datetime.date(year=2022, month=8, day=18)): 1,
    ('INE', datetime.date(year=2022, month=8, day=19)): 1,
    ('INE', datetime.date(year=2022, month=8, day=20)): 0,
    ('INE', datetime.date(year=2022, month=8, day=21)): 0,
    ('INE', datetime.date(year=2022, month=8, day=22)): 1,
    ('INE', datetime.date(year=2022, month=8, day=23)): 1,
    ('INE', datetime.date(year=2022, month=8, day=24)): 1,
    ('INE', datetime.date(year=2022, month=8, day=25)): 1,
    ('INE', datetime.date(year=2022, month=8, day=26)): 1,
    ('INE', datetime.date(year=2022, month=8, day=27)): 0,
    ('INE', datetime.date(year=2022, month=8, day=28)): 0,
    ('INE', datetime.date(year=2022, month=8, day=29)): 1,
    ('INE', datetime.date(year=2022, month=8, day=30)): 1,
    ('INE', datetime.date(year=2022, month=8, day=31)): 1,
    ('INE', datetime.date(year=2022, month=9, day=1)): 1,
    ('INE', datetime.date(year=2022, month=9, day=2)): 1,
    ('INE', datetime.date(year=2022, month=9, day=3)): 0,
    ('INE', datetime.date(year=2022, month=9, day=4)): 0,
    ('INE', datetime.date(year=2022, month=9, day=5)): 1,
    ('INE', datetime.date(year=2022, month=9, day=6)): 1,
    ('INE', datetime.date(year=2022, month=9, day=7)): 1,
    ('INE', datetime.date(year=2022, month=9, day=8)): 1,
    ('INE', datetime.date(year=2022, month=9, day=9)): 1,
    ('INE', datetime.date(year=2022, month=9, day=10)): 0,
    ('INE', datetime.date(year=2022, month=9, day=11)): 0,
    ('INE', datetime.date(year=2022, month=9, day=12)): 0,
    ('INE', datetime.date(year=2022, month=9, day=13)): 1,
    ('INE', datetime.date(year=2022, month=9, day=14)): 1,
    ('INE', datetime.date(year=2022, month=9, day=15)): 1,
    ('INE', datetime.date(year=2022, month=9, day=16)): 1,
    ('INE', datetime.date(year=2022, month=9, day=17)): 0,
    ('INE', datetime.date(year=2022, month=9, day=18)): 0,
    ('INE', datetime.date(year=2022, month=9, day=19)): 1,
    ('INE', datetime.date(year=2022, month=9, day=20)): 1,
    ('INE', datetime.date(year=2022, month=9, day=21)): 1,
    ('INE', datetime.date(year=2022, month=9, day=22)): 1,
    ('INE', datetime.date(year=2022, month=9, day=23)): 1,
    ('INE', datetime.date(year=2022, month=9, day=24)): 0,
    ('INE', datetime.date(year=2022, month=9, day=25)): 0,
    ('INE', datetime.date(year=2022, month=9, day=26)): 1,
    ('INE', datetime.date(year=2022, month=9, day=27)): 1,
    ('INE', datetime.date(year=2022, month=9, day=28)): 1,
    ('INE', datetime.date(year=2022, month=9, day=29)): 1,
    ('INE', datetime.date(year=2022, month=9, day=30)): 1,
    ('INE', datetime.date(year=2022, month=10, day=1)): 0,
    ('INE', datetime.date(year=2022, month=10, day=2)): 0,
    ('INE', datetime.date(year=2022, month=10, day=3)): 0,
    ('INE', datetime.date(year=2022, month=10, day=4)): 0,
    ('INE', datetime.date(year=2022, month=10, day=5)): 0,
    ('INE', datetime.date(year=2022, month=10, day=6)): 0,
    ('INE', datetime.date(year=2022, month=10, day=7)): 0,
    ('INE', datetime.date(year=2022, month=10, day=8)): 0,
    ('INE', datetime.date(year=2022, month=10, day=9)): 0,
    ('INE', datetime.date(year=2022, month=10, day=10)): 1,
    ('INE', datetime.date(year=2022, month=10, day=11)): 1,
    ('INE', datetime.date(year=2022, month=10, day=12)): 1,
    ('INE', datetime.date(year=2022, month=10, day=13)): 1,
    ('INE', datetime.date(year=2022, month=10, day=14)): 1,
    ('INE', datetime.date(year=2022, month=10, day=15)): 0,
    ('INE', datetime.date(year=2022, month=10, day=16)): 0,
    ('INE', datetime.date(year=2022, month=10, day=17)): 1,
    ('INE', datetime.date(year=2022, month=10, day=18)): 1,
    ('INE', datetime.date(year=2022, month=10, day=19)): 1,
    ('INE', datetime.date(year=2022, month=10, day=20)): 1,
    ('INE', datetime.date(year=2022, month=10, day=21)): 1,
    ('INE', datetime.date(year=2022, month=10, day=22)): 0,
    ('INE', datetime.date(year=2022, month=10, day=23)): 0,
    ('INE', datetime.date(year=2022, month=10, day=24)): 1,
    ('INE', datetime.date(year=2022, month=10, day=25)): 1,
    ('INE', datetime.date(year=2022, month=10, day=26)): 1,
    ('INE', datetime.date(year=2022, month=10, day=27)): 1,
    ('INE', datetime.date(year=2022, month=10, day=28)): 1,
    ('INE', datetime.date(year=2022, month=10, day=29)): 0,
    ('INE', datetime.date(year=2022, month=10, day=30)): 0,
    ('INE', datetime.date(year=2022, month=10, day=31)): 1,
    ('INE', datetime.date(year=2022, month=11, day=1)): 1,
    ('INE', datetime.date(year=2022, month=11, day=2)): 1,
    ('INE', datetime.date(year=2022, month=11, day=3)): 1,
    ('INE', datetime.date(year=2022, month=11, day=4)): 1,
    ('INE', datetime.date(year=2022, month=11, day=5)): 0,
    ('INE', datetime.date(year=2022, month=11, day=6)): 0,
    ('INE', datetime.date(year=2022, month=11, day=7)): 1,
    ('INE', datetime.date(year=2022, month=11, day=8)): 1,
    ('INE', datetime.date(year=2022, month=11, day=9)): 1,
    ('INE', datetime.date(year=2022, month=11, day=10)): 1,
    ('INE', datetime.date(year=2022, month=11, day=11)): 1,
    ('INE', datetime.date(year=2022, month=11, day=12)): 0,
    ('INE', datetime.date(year=2022, month=11, day=13)): 0,
    ('INE', datetime.date(year=2022, month=11, day=14)): 1,
    ('INE', datetime.date(year=2022, month=11, day=15)): 1,
    ('INE', datetime.date(year=2022, month=11, day=16)): 1,
    ('INE', datetime.date(year=2022, month=11, day=17)): 1,
    ('INE', datetime.date(year=2022, month=11, day=18)): 1,
    ('INE', datetime.date(year=2022, month=11, day=19)): 0,
    ('INE', datetime.date(year=2022, month=11, day=20)): 0,
    ('INE', datetime.date(year=2022, month=11, day=21)): 1,
    ('INE', datetime.date(year=2022, month=11, day=22)): 1,
    ('INE', datetime.date(year=2022, month=11, day=23)): 1,
    ('INE', datetime.date(year=2022, month=11, day=24)): 1,
    ('INE', datetime.date(year=2022, month=11, day=25)): 1,
    ('INE', datetime.date(year=2022, month=11, day=26)): 0,
    ('INE', datetime.date(year=2022, month=11, day=27)): 0,
    ('INE', datetime.date(year=2022, month=11, day=28)): 1,
    ('INE', datetime.date(year=2022, month=11, day=29)): 1,
    ('INE', datetime.date(year=2022, month=11, day=30)): 1,
    ('INE', datetime.date(year=2022, month=12, day=1)): 1,
    ('INE', datetime.date(year=2022, month=12, day=2)): 1,
    ('INE', datetime.date(year=2022, month=12, day=3)): 0,
    ('INE', datetime.date(year=2022, month=12, day=4)): 0,
    ('INE', datetime.date(year=2022, month=12, day=5)): 1,
    ('INE', datetime.date(year=2022, month=12, day=6)): 1,
    ('INE', datetime.date(year=2022, month=12, day=7)): 1,
    ('INE', datetime.date(year=2022, month=12, day=8)): 1,
    ('INE', datetime.date(year=2022, month=12, day=9)): 1,
    ('INE', datetime.date(year=2022, month=12, day=10)): 0,
    ('INE', datetime.date(year=2022, month=12, day=11)): 0,
    ('INE', datetime.date(year=2022, month=12, day=12)): 1,
    ('INE', datetime.date(year=2022, month=12, day=13)): 1,
    ('INE', datetime.date(year=2022, month=12, day=14)): 1,
    ('INE', datetime.date(year=2022, month=12, day=15)): 1,
    ('INE', datetime.date(year=2022, month=12, day=16)): 1,
    ('INE', datetime.date(year=2022, month=12, day=17)): 0,
    ('INE', datetime.date(year=2022, month=12, day=18)): 0,
    ('INE', datetime.date(year=2022, month=12, day=19)): 1,
    ('INE', datetime.date(year=2022, month=12, day=20)): 1,
    ('INE', datetime.date(year=2022, month=12, day=21)): 1,
    ('INE', datetime.date(year=2022, month=12, day=22)): 1,
    ('INE', datetime.date(year=2022, month=12, day=23)): 1,
    ('INE', datetime.date(year=2022, month=12, day=24)): 0,
    ('INE', datetime.date(year=2022, month=12, day=25)): 0,
    ('INE', datetime.date(year=2022, month=12, day=26)): 1,
    ('INE', datetime.date(year=2022, month=12, day=27)): 1,
    ('INE', datetime.date(year=2022, month=12, day=28)): 1,
    ('INE', datetime.date(year=2022, month=12, day=29)): 1,
    ('INE', datetime.date(year=2022, month=12, day=30)): 1,
    ('INE', datetime.date(year=2023, month=1, day=1)): 0,
    ('INE', datetime.date(year=2023, month=1, day=2)): 0,
    ('INE', datetime.date(year=2023, month=1, day=3)): 1,
    ('INE', datetime.date(year=2023, month=1, day=4)): 1,
    ('INE', datetime.date(year=2023, month=1, day=5)): 1,
    ('INE', datetime.date(year=2023, month=1, day=6)): 1,
    ('INE', datetime.date(year=2023, month=1, day=7)): 0,
    ('INE', datetime.date(year=2023, month=1, day=8)): 0,
    ('INE', datetime.date(year=2023, month=1, day=9)): 1,
    ('INE', datetime.date(year=2023, month=1, day=10)): 1,
    ('INE', datetime.date(year=2023, month=1, day=11)): 1,
    ('INE', datetime.date(year=2023, month=1, day=12)): 1,
    ('INE', datetime.date(year=2023, month=1, day=13)): 1,
    ('INE', datetime.date(year=2023, month=1, day=14)): 0,
    ('INE', datetime.date(year=2023, month=1, day=15)): 0,
    ('INE', datetime.date(year=2023, month=1, day=16)): 1,
    ('INE', datetime.date(year=2023, month=1, day=17)): 1,
    ('INE', datetime.date(year=2023, month=1, day=18)): 1,
    ('INE', datetime.date(year=2023, month=1, day=19)): 1,
    ('INE', datetime.date(year=2023, month=1, day=20)): 1,
    ('INE', datetime.date(year=2023, month=1, day=21)): 0,
    ('INE', datetime.date(year=2023, month=1, day=22)): 0,
    ('INE', datetime.date(year=2023, month=1, day=23)): 0,
    ('INE', datetime.date(year=2023, month=1, day=24)): 0,
    ('INE', datetime.date(year=2023, month=1, day=25)): 0,
    ('INE', datetime.date(year=2023, month=1, day=26)): 0,
    ('INE', datetime.date(year=2023, month=1, day=27)): 0,
    ('INE', datetime.date(year=2023, month=1, day=28)): 0,
    ('INE', datetime.date(year=2023, month=1, day=29)): 0,
    ('INE', datetime.date(year=2023, month=1, day=30)): 1,
    ('INE', datetime.date(year=2023, month=1, day=31)): 1,
    ('INE', datetime.date(year=2023, month=2, day=1)): 1,
    ('INE', datetime.date(year=2023, month=2, day=2)): 1,
    ('INE', datetime.date(year=2023, month=2, day=3)): 1,
    ('INE', datetime.date(year=2023, month=2, day=4)): 0,
    ('INE', datetime.date(year=2023, month=2, day=5)): 0,
    ('INE', datetime.date(year=2023, month=2, day=6)): 1,
    ('INE', datetime.date(year=2023, month=2, day=7)): 1,
    ('INE', datetime.date(year=2023, month=2, day=8)): 1,
    ('INE', datetime.date(year=2023, month=2, day=9)): 1,
    ('INE', datetime.date(year=2023, month=2, day=10)): 1,
    ('INE', datetime.date(year=2023, month=2, day=11)): 0,
    ('INE', datetime.date(year=2023, month=2, day=12)): 0,
    ('INE', datetime.date(year=2023, month=2, day=13)): 1,
    ('INE', datetime.date(year=2023, month=2, day=14)): 1,
    ('INE', datetime.date(year=2023, month=2, day=15)): 1,
    ('INE', datetime.date(year=2023, month=2, day=16)): 1,
    ('INE', datetime.date(year=2023, month=2, day=17)): 1,
    ('INE', datetime.date(year=2023, month=2, day=18)): 0,
    ('INE', datetime.date(year=2023, month=2, day=19)): 0,
    ('INE', datetime.date(year=2023, month=2, day=20)): 1,
    ('INE', datetime.date(year=2023, month=2, day=21)): 1,
    ('INE', datetime.date(year=2023, month=2, day=22)): 1,
    ('INE', datetime.date(year=2023, month=2, day=23)): 1,
    ('INE', datetime.date(year=2023, month=2, day=24)): 1,
    ('INE', datetime.date(year=2023, month=2, day=25)): 0,
    ('INE', datetime.date(year=2023, month=2, day=26)): 0,
    ('INE', datetime.date(year=2023, month=2, day=27)): 1,
    ('INE', datetime.date(year=2023, month=2, day=28)): 1,
    ('INE', datetime.date(year=2023, month=3, day=1)): 1,
    ('INE', datetime.date(year=2023, month=3, day=2)): 1,
    ('INE', datetime.date(year=2023, month=3, day=3)): 1,
    ('INE', datetime.date(year=2023, month=3, day=4)): 0,
    ('INE', datetime.date(year=2023, month=3, day=5)): 0,
    ('INE', datetime.date(year=2023, month=3, day=6)): 1,
    ('INE', datetime.date(year=2023, month=3, day=7)): 1,
    ('INE', datetime.date(year=2023, month=3, day=8)): 1,
    ('INE', datetime.date(year=2023, month=3, day=9)): 1,
    ('INE', datetime.date(year=2023, month=3, day=10)): 1,
    ('INE', datetime.date(year=2023, month=3, day=11)): 0,
    ('INE', datetime.date(year=2023, month=3, day=12)): 0,
    ('INE', datetime.date(year=2023, month=3, day=13)): 1,
    ('INE', datetime.date(year=2023, month=3, day=14)): 1,
    ('INE', datetime.date(year=2023, month=3, day=15)): 1,
    ('INE', datetime.date(year=2023, month=3, day=16)): 1,
    ('INE', datetime.date(year=2023, month=3, day=17)): 1,
    ('INE', datetime.date(year=2023, month=3, day=18)): 0,
    ('INE', datetime.date(year=2023, month=3, day=19)): 0,
    ('INE', datetime.date(year=2023, month=3, day=20)): 1,
    ('INE', datetime.date(year=2023, month=3, day=21)): 1,
    ('INE', datetime.date(year=2023, month=3, day=22)): 1,
    ('INE', datetime.date(year=2023, month=3, day=23)): 1,
    ('INE', datetime.date(year=2023, month=3, day=24)): 1,
    ('INE', datetime.date(year=2023, month=3, day=25)): 0,
    ('INE', datetime.date(year=2023, month=3, day=26)): 0,
    ('INE', datetime.date(year=2023, month=3, day=27)): 1,
    ('INE', datetime.date(year=2023, month=3, day=28)): 1,
    ('INE', datetime.date(year=2023, month=3, day=29)): 1,
    ('INE', datetime.date(year=2023, month=3, day=30)): 1,
    ('INE', datetime.date(year=2023, month=3, day=31)): 1,
    ('INE', datetime.date(year=2023, month=4, day=1)): 0,
    ('INE', datetime.date(year=2023, month=4, day=2)): 0,
    ('INE', datetime.date(year=2023, month=4, day=3)): 1,
    ('INE', datetime.date(year=2023, month=4, day=4)): 1,
    ('INE', datetime.date(year=2023, month=4, day=5)): 0,
    ('INE', datetime.date(year=2023, month=4, day=6)): 1,
    ('INE', datetime.date(year=2023, month=4, day=7)): 1,
    ('INE', datetime.date(year=2023, month=4, day=8)): 0,
    ('INE', datetime.date(year=2023, month=4, day=9)): 0,
    ('INE', datetime.date(year=2023, month=4, day=10)): 1,
    ('INE', datetime.date(year=2023, month=4, day=11)): 1,
    ('INE', datetime.date(year=2023, month=4, day=12)): 1,
    ('INE', datetime.date(year=2023, month=4, day=13)): 1,
    ('INE', datetime.date(year=2023, month=4, day=14)): 1,
    ('INE', datetime.date(year=2023, month=4, day=15)): 0,
    ('INE', datetime.date(year=2023, month=4, day=16)): 0,
    ('INE', datetime.date(year=2023, month=4, day=17)): 1,
    ('INE', datetime.date(year=2023, month=4, day=18)): 1,
    ('INE', datetime.date(year=2023, month=4, day=19)): 1,
    ('INE', datetime.date(year=2023, month=4, day=20)): 1,
    ('INE', datetime.date(year=2023, month=4, day=21)): 1,
    ('INE', datetime.date(year=2023, month=4, day=22)): 0,
    ('INE', datetime.date(year=2023, month=4, day=23)): 0,
    ('INE', datetime.date(year=2023, month=4, day=24)): 1,
    ('INE', datetime.date(year=2023, month=4, day=25)): 1,
    ('INE', datetime.date(year=2023, month=4, day=26)): 1,
    ('INE', datetime.date(year=2023, month=4, day=27)): 1,
    ('INE', datetime.date(year=2023, month=4, day=28)): 1,
    ('INE', datetime.date(year=2023, month=4, day=29)): 0,
    ('INE', datetime.date(year=2023, month=4, day=30)): 0,
    ('INE', datetime.date(year=2023, month=5, day=1)): 0,
    ('INE', datetime.date(year=2023, month=5, day=2)): 0,
    ('INE', datetime.date(year=2023, month=5, day=3)): 0,
    ('INE', datetime.date(year=2023, month=5, day=4)): 1,
    ('INE', datetime.date(year=2023, month=5, day=5)): 1,
    ('INE', datetime.date(year=2023, month=5, day=6)): 0,
    ('INE', datetime.date(year=2023, month=5, day=7)): 0,
    ('INE', datetime.date(year=2023, month=5, day=8)): 1,
    ('INE', datetime.date(year=2023, month=5, day=9)): 1,
    ('INE', datetime.date(year=2023, month=5, day=10)): 1,
    ('INE', datetime.date(year=2023, month=5, day=11)): 1,
    ('INE', datetime.date(year=2023, month=5, day=12)): 1,
    ('INE', datetime.date(year=2023, month=5, day=13)): 0,
    ('INE', datetime.date(year=2023, month=5, day=14)): 0,
    ('INE', datetime.date(year=2023, month=5, day=15)): 1,
    ('INE', datetime.date(year=2023, month=5, day=16)): 1,
    ('INE', datetime.date(year=2023, month=5, day=17)): 1,
    ('INE', datetime.date(year=2023, month=5, day=18)): 1,
    ('INE', datetime.date(year=2023, month=5, day=19)): 1,
    ('INE', datetime.date(year=2023, month=5, day=20)): 0,
    ('INE', datetime.date(year=2023, month=5, day=21)): 0,
    ('INE', datetime.date(year=2023, month=5, day=22)): 1,
    ('INE', datetime.date(year=2023, month=5, day=23)): 1,
    ('INE', datetime.date(year=2023, month=5, day=24)): 1,
    ('INE', datetime.date(year=2023, month=5, day=25)): 1,
    ('INE', datetime.date(year=2023, month=5, day=26)): 1,
    ('INE', datetime.date(year=2023, month=5, day=27)): 0,
    ('INE', datetime.date(year=2023, month=5, day=28)): 0,
    ('INE', datetime.date(year=2023, month=5, day=29)): 1,
    ('INE', datetime.date(year=2023, month=5, day=30)): 1,
    ('INE', datetime.date(year=2023, month=5, day=31)): 1,
    ('INE', datetime.date(year=2023, month=6, day=1)): 1,
    ('INE', datetime.date(year=2023, month=6, day=2)): 1,
    ('INE', datetime.date(year=2023, month=6, day=3)): 0,
    ('INE', datetime.date(year=2023, month=6, day=4)): 0,
    ('INE', datetime.date(year=2023, month=6, day=5)): 1,
    ('INE', datetime.date(year=2023, month=6, day=6)): 1,
    ('INE', datetime.date(year=2023, month=6, day=7)): 1,
    ('INE', datetime.date(year=2023, month=6, day=8)): 1,
    ('INE', datetime.date(year=2023, month=6, day=9)): 1,
    ('INE', datetime.date(year=2023, month=6, day=10)): 0,
    ('INE', datetime.date(year=2023, month=6, day=11)): 0,
    ('INE', datetime.date(year=2023, month=6, day=12)): 1,
    ('INE', datetime.date(year=2023, month=6, day=13)): 1,
    ('INE', datetime.date(year=2023, month=6, day=14)): 1,
    ('INE', datetime.date(year=2023, month=6, day=15)): 1,
    ('INE', datetime.date(year=2023, month=6, day=16)): 1,
    ('INE', datetime.date(year=2023, month=6, day=17)): 0,
    ('INE', datetime.date(year=2023, month=6, day=18)): 0,
    ('INE', datetime.date(year=2023, month=6, day=19)): 1,
    ('INE', datetime.date(year=2023, month=6, day=20)): 1,
    ('INE', datetime.date(year=2023, month=6, day=21)): 1,
    ('INE', datetime.date(year=2023, month=6, day=22)): 0,
    ('INE', datetime.date(year=2023, month=6, day=23)): 0,
    ('INE', datetime.date(year=2023, month=6, day=24)): 0,
    ('INE', datetime.date(year=2023, month=6, day=25)): 0,
    ('INE', datetime.date(year=2023, month=6, day=26)): 1,
    ('INE', datetime.date(year=2023, month=6, day=27)): 1,
    ('INE', datetime.date(year=2023, month=6, day=28)): 1,
    ('INE', datetime.date(year=2023, month=6, day=29)): 1,
    ('INE', datetime.date(year=2023, month=6, day=30)): 1,
    ('INE', datetime.date(year=2023, month=7, day=1)): 0,
    ('INE', datetime.date(year=2023, month=7, day=2)): 0,
    ('INE', datetime.date(year=2023, month=7, day=3)): 1,
    ('INE', datetime.date(year=2023, month=7, day=4)): 1,
    ('INE', datetime.date(year=2023, month=7, day=5)): 1,
    ('INE', datetime.date(year=2023, month=7, day=6)): 1,
    ('INE', datetime.date(year=2023, month=7, day=7)): 1,
    ('INE', datetime.date(year=2023, month=7, day=8)): 0,
    ('INE', datetime.date(year=2023, month=7, day=9)): 0,
    ('INE', datetime.date(year=2023, month=7, day=10)): 1,
    ('INE', datetime.date(year=2023, month=7, day=11)): 1,
    ('INE', datetime.date(year=2023, month=7, day=12)): 1,
    ('INE', datetime.date(year=2023, month=7, day=13)): 1,
    ('INE', datetime.date(year=2023, month=7, day=14)): 1,
    ('INE', datetime.date(year=2023, month=7, day=15)): 0,
    ('INE', datetime.date(year=2023, month=7, day=16)): 0,
    ('INE', datetime.date(year=2023, month=7, day=17)): 1,
    ('INE', datetime.date(year=2023, month=7, day=18)): 1,
    ('INE', datetime.date(year=2023, month=7, day=19)): 1,
    ('INE', datetime.date(year=2023, month=7, day=20)): 1,
    ('INE', datetime.date(year=2023, month=7, day=21)): 1,
    ('INE', datetime.date(year=2023, month=7, day=22)): 0,
    ('INE', datetime.date(year=2023, month=7, day=23)): 0,
    ('INE', datetime.date(year=2023, month=7, day=24)): 1,
    ('INE', datetime.date(year=2023, month=7, day=25)): 1,
    ('INE', datetime.date(year=2023, month=7, day=26)): 1,
    ('INE', datetime.date(year=2023, month=7, day=27)): 1,
    ('INE', datetime.date(year=2023, month=7, day=28)): 1,
    ('INE', datetime.date(year=2023, month=7, day=29)): 0,
    ('INE', datetime.date(year=2023, month=7, day=30)): 0,
    ('INE', datetime.date(year=2023, month=7, day=31)): 1,
    ('INE', datetime.date(year=2023, month=8, day=1)): 1,
    ('INE', datetime.date(year=2023, month=8, day=2)): 1,
    ('INE', datetime.date(year=2023, month=8, day=3)): 1,
    ('INE', datetime.date(year=2023, month=8, day=4)): 1,
    ('INE', datetime.date(year=2023, month=8, day=5)): 0,
    ('INE', datetime.date(year=2023, month=8, day=6)): 0,
    ('INE', datetime.date(year=2023, month=8, day=7)): 1,
    ('INE', datetime.date(year=2023, month=8, day=8)): 1,
    ('INE', datetime.date(year=2023, month=8, day=9)): 1,
    ('INE', datetime.date(year=2023, month=8, day=10)): 1,
    ('INE', datetime.date(year=2023, month=8, day=11)): 1,
    ('INE', datetime.date(year=2023, month=8, day=12)): 0,
    ('INE', datetime.date(year=2023, month=8, day=13)): 0,
    ('INE', datetime.date(year=2023, month=8, day=14)): 1,
    ('INE', datetime.date(year=2023, month=8, day=15)): 1,
    ('INE', datetime.date(year=2023, month=8, day=16)): 1,
    ('INE', datetime.date(year=2023, month=8, day=17)): 1,
    ('INE', datetime.date(year=2023, month=8, day=18)): 1,
    ('INE', datetime.date(year=2023, month=8, day=19)): 0,
    ('INE', datetime.date(year=2023, month=8, day=20)): 0,
    ('INE', datetime.date(year=2023, month=8, day=21)): 1,
    ('INE', datetime.date(year=2023, month=8, day=22)): 1,
    ('INE', datetime.date(year=2023, month=8, day=23)): 1,
    ('INE', datetime.date(year=2023, month=8, day=24)): 1,
    ('INE', datetime.date(year=2023, month=8, day=25)): 1,
    ('INE', datetime.date(year=2023, month=8, day=26)): 0,
    ('INE', datetime.date(year=2023, month=8, day=27)): 0,
    ('INE', datetime.date(year=2023, month=8, day=28)): 1,
    ('INE', datetime.date(year=2023, month=8, day=29)): 1,
    ('INE', datetime.date(year=2023, month=8, day=30)): 1,
    ('INE', datetime.date(year=2023, month=8, day=31)): 1,
    ('INE', datetime.date(year=2023, month=9, day=1)): 1,
    ('INE', datetime.date(year=2023, month=9, day=2)): 0,
    ('INE', datetime.date(year=2023, month=9, day=3)): 0,
    ('INE', datetime.date(year=2023, month=9, day=4)): 1,
    ('INE', datetime.date(year=2023, month=9, day=5)): 1,
    ('INE', datetime.date(year=2023, month=9, day=6)): 1,
    ('INE', datetime.date(year=2023, month=9, day=7)): 1,
    ('INE', datetime.date(year=2023, month=9, day=8)): 1,
    ('INE', datetime.date(year=2023, month=9, day=9)): 0,
    ('INE', datetime.date(year=2023, month=9, day=10)): 0,
    ('INE', datetime.date(year=2023, month=9, day=11)): 1,
    ('INE', datetime.date(year=2023, month=9, day=12)): 1,
    ('INE', datetime.date(year=2023, month=9, day=13)): 1,
    ('INE', datetime.date(year=2023, month=9, day=14)): 1,
    ('INE', datetime.date(year=2023, month=9, day=15)): 1,
    ('INE', datetime.date(year=2023, month=9, day=16)): 0,
    ('INE', datetime.date(year=2023, month=9, day=17)): 0,
    ('INE', datetime.date(year=2023, month=9, day=18)): 1,
    ('INE', datetime.date(year=2023, month=9, day=19)): 1,
    ('INE', datetime.date(year=2023, month=9, day=20)): 1,
    ('INE', datetime.date(year=2023, month=9, day=21)): 1,
    ('INE', datetime.date(year=2023, month=9, day=22)): 1,
    ('INE', datetime.date(year=2023, month=9, day=23)): 0,
    ('INE', datetime.date(year=2023, month=9, day=24)): 0,
    ('INE', datetime.date(year=2023, month=9, day=25)): 1,
    ('INE', datetime.date(year=2023, month=9, day=26)): 1,
    ('INE', datetime.date(year=2023, month=9, day=27)): 1,
    ('INE', datetime.date(year=2023, month=9, day=28)): 1,
    ('INE', datetime.date(year=2023, month=9, day=29)): 0,
    ('INE', datetime.date(year=2023, month=9, day=30)): 0,
    ('INE', datetime.date(year=2023, month=10, day=1)): 0,
    ('INE', datetime.date(year=2023, month=10, day=2)): 0,
    ('INE', datetime.date(year=2023, month=10, day=3)): 0,
    ('INE', datetime.date(year=2023, month=10, day=4)): 0,
    ('INE', datetime.date(year=2023, month=10, day=5)): 0,
    ('INE', datetime.date(year=2023, month=10, day=6)): 0,
    ('INE', datetime.date(year=2023, month=10, day=7)): 0,
    ('INE', datetime.date(year=2023, month=10, day=8)): 0,
    ('INE', datetime.date(year=2023, month=10, day=9)): 1,
    ('INE', datetime.date(year=2023, month=10, day=10)): 1,
    ('INE', datetime.date(year=2023, month=10, day=11)): 1,
    ('INE', datetime.date(year=2023, month=10, day=12)): 1,
    ('INE', datetime.date(year=2023, month=10, day=13)): 1,
    ('INE', datetime.date(year=2023, month=10, day=14)): 0,
    ('INE', datetime.date(year=2023, month=10, day=15)): 0,
    ('INE', datetime.date(year=2023, month=10, day=16)): 1,
    ('INE', datetime.date(year=2023, month=10, day=17)): 1,
    ('INE', datetime.date(year=2023, month=10, day=18)): 1,
    ('INE', datetime.date(year=2023, month=10, day=19)): 1,
    ('INE', datetime.date(year=2023, month=10, day=20)): 1,
    ('INE', datetime.date(year=2023, month=10, day=21)): 0,
    ('INE', datetime.date(year=2023, month=10, day=22)): 0,
    ('INE', datetime.date(year=2023, month=10, day=23)): 1,
    ('INE', datetime.date(year=2023, month=10, day=24)): 1,
    ('INE', datetime.date(year=2023, month=10, day=25)): 1,
    ('INE', datetime.date(year=2023, month=10, day=26)): 1,
    ('INE', datetime.date(year=2023, month=10, day=27)): 1,
    ('INE', datetime.date(year=2023, month=10, day=28)): 0,
    ('INE', datetime.date(year=2023, month=10, day=29)): 0,
    ('INE', datetime.date(year=2023, month=10, day=30)): 1,
    ('INE', datetime.date(year=2023, month=10, day=31)): 1,
    ('INE', datetime.date(year=2023, month=11, day=1)): 1,
    ('INE', datetime.date(year=2023, month=11, day=2)): 1,
    ('INE', datetime.date(year=2023, month=11, day=3)): 1,
    ('INE', datetime.date(year=2023, month=11, day=4)): 0,
    ('INE', datetime.date(year=2023, month=11, day=5)): 0,
    ('INE', datetime.date(year=2023, month=11, day=6)): 1,
    ('INE', datetime.date(year=2023, month=11, day=7)): 1,
    ('INE', datetime.date(year=2023, month=11, day=8)): 1,
    ('INE', datetime.date(year=2023, month=11, day=9)): 1,
    ('INE', datetime.date(year=2023, month=11, day=10)): 1,
    ('INE', datetime.date(year=2023, month=11, day=11)): 0,
    ('INE', datetime.date(year=2023, month=11, day=12)): 0,
    ('INE', datetime.date(year=2023, month=11, day=13)): 1,
    ('INE', datetime.date(year=2023, month=11, day=14)): 1,
    ('INE', datetime.date(year=2023, month=11, day=15)): 1,
    ('INE', datetime.date(year=2023, month=11, day=16)): 1,
    ('INE', datetime.date(year=2023, month=11, day=17)): 1,
    ('INE', datetime.date(year=2023, month=11, day=18)): 0,
    ('INE', datetime.date(year=2023, month=11, day=19)): 0,
    ('INE', datetime.date(year=2023, month=11, day=20)): 1,
    ('INE', datetime.date(year=2023, month=11, day=21)): 1,
    ('INE', datetime.date(year=2023, month=11, day=22)): 1,
    ('INE', datetime.date(year=2023, month=11, day=23)): 1,
    ('INE', datetime.date(year=2023, month=11, day=24)): 1,
    ('INE', datetime.date(year=2023, month=11, day=25)): 0,
    ('INE', datetime.date(year=2023, month=11, day=26)): 0,
    ('INE', datetime.date(year=2023, month=11, day=27)): 1,
    ('INE', datetime.date(year=2023, month=11, day=28)): 1,
    ('INE', datetime.date(year=2023, month=11, day=29)): 1,
    ('INE', datetime.date(year=2023, month=11, day=30)): 1,
    ('INE', datetime.date(year=2023, month=12, day=1)): 1,
    ('INE', datetime.date(year=2023, month=12, day=2)): 0,
    ('INE', datetime.date(year=2023, month=12, day=3)): 0,
    ('INE', datetime.date(year=2023, month=12, day=4)): 1,
    ('INE', datetime.date(year=2023, month=12, day=5)): 1,
    ('INE', datetime.date(year=2023, month=12, day=6)): 1,
    ('INE', datetime.date(year=2023, month=12, day=7)): 1,
    ('INE', datetime.date(year=2023, month=12, day=8)): 1,
    ('INE', datetime.date(year=2023, month=12, day=9)): 0,
    ('INE', datetime.date(year=2023, month=12, day=10)): 0,
    ('INE', datetime.date(year=2023, month=12, day=11)): 1,
    ('INE', datetime.date(year=2023, month=12, day=12)): 1,
    ('INE', datetime.date(year=2023, month=12, day=13)): 1,
    ('INE', datetime.date(year=2023, month=12, day=14)): 1,
    ('INE', datetime.date(year=2023, month=12, day=15)): 1,
    ('INE', datetime.date(year=2023, month=12, day=16)): 0,
    ('INE', datetime.date(year=2023, month=12, day=17)): 0,
    ('INE', datetime.date(year=2023, month=12, day=18)): 1,
    ('INE', datetime.date(year=2023, month=12, day=19)): 1,
    ('INE', datetime.date(year=2023, month=12, day=20)): 1,
    ('INE', datetime.date(year=2023, month=12, day=21)): 1,
    ('INE', datetime.date(year=2023, month=12, day=22)): 1,
    ('INE', datetime.date(year=2023, month=12, day=23)): 0,
    ('INE', datetime.date(year=2023, month=12, day=24)): 0,
    ('INE', datetime.date(year=2023, month=12, day=25)): 1,
    ('INE', datetime.date(year=2023, month=12, day=26)): 1,
    ('INE', datetime.date(year=2023, month=12, day=27)): 1,
    ('INE', datetime.date(year=2023, month=12, day=28)): 1,
    ('INE', datetime.date(year=2023, month=12, day=29)): 1,
    ('INE', datetime.date(year=2023, month=12, day=30)): 0,
    ('INE', datetime.date(year=2023, month=12, day=31)): 0,
    ('INE', datetime.date(year=2024, month=1, day=1)): 0,
    ('INE', datetime.date(year=2024, month=1, day=2)): 1,
    ('INE', datetime.date(year=2024, month=1, day=3)): 1,
    ('INE', datetime.date(year=2024, month=1, day=4)): 1,
    ('INE', datetime.date(year=2024, month=1, day=5)): 1,
    ('INE', datetime.date(year=2024, month=1, day=6)): 0,
    ('INE', datetime.date(year=2024, month=1, day=7)): 0,
    ('INE', datetime.date(year=2024, month=1, day=8)): 1,
    ('INE', datetime.date(year=2024, month=1, day=9)): 1,
    ('INE', datetime.date(year=2024, month=1, day=10)): 1,
    ('INE', datetime.date(year=2024, month=1, day=11)): 1,
    ('INE', datetime.date(year=2024, month=1, day=12)): 1,
    ('INE', datetime.date(year=2024, month=1, day=13)): 0,
    ('INE', datetime.date(year=2024, month=1, day=14)): 0,
    ('INE', datetime.date(year=2024, month=1, day=15)): 1,
    ('INE', datetime.date(year=2024, month=1, day=16)): 1,
    ('INE', datetime.date(year=2024, month=1, day=17)): 1,
    ('INE', datetime.date(year=2024, month=1, day=18)): 1,
    ('INE', datetime.date(year=2024, month=1, day=19)): 1,
    ('INE', datetime.date(year=2024, month=1, day=20)): 0,
    ('INE', datetime.date(year=2024, month=1, day=21)): 0,
    ('INE', datetime.date(year=2024, month=1, day=22)): 1,
    ('INE', datetime.date(year=2024, month=1, day=23)): 1,
    ('INE', datetime.date(year=2024, month=1, day=24)): 1,
    ('INE', datetime.date(year=2024, month=1, day=25)): 1,
    ('INE', datetime.date(year=2024, month=1, day=26)): 1,
    ('INE', datetime.date(year=2024, month=1, day=27)): 0,
    ('INE', datetime.date(year=2024, month=1, day=28)): 0,
    ('INE', datetime.date(year=2024, month=1, day=29)): 1,
    ('INE', datetime.date(year=2024, month=1, day=30)): 1,
    ('INE', datetime.date(year=2024, month=1, day=31)): 1,
    ('INE', datetime.date(year=2024, month=2, day=1)): 1,
    ('INE', datetime.date(year=2024, month=2, day=2)): 1,
    ('INE', datetime.date(year=2024, month=2, day=3)): 0,
    ('INE', datetime.date(year=2024, month=2, day=4)): 0,
    ('INE', datetime.date(year=2024, month=2, day=5)): 1,
    ('INE', datetime.date(year=2024, month=2, day=6)): 1,
    ('INE', datetime.date(year=2024, month=2, day=7)): 1,
    ('INE', datetime.date(year=2024, month=2, day=8)): 1,
    ('INE', datetime.date(year=2024, month=2, day=9)): 1,
    ('INE', datetime.date(year=2024, month=2, day=10)): 0,
    ('INE', datetime.date(year=2024, month=2, day=11)): 0,
    ('INE', datetime.date(year=2024, month=2, day=12)): 0,
    ('INE', datetime.date(year=2024, month=2, day=13)): 0,
    ('INE', datetime.date(year=2024, month=2, day=14)): 0,
    ('INE', datetime.date(year=2024, month=2, day=15)): 0,
    ('INE', datetime.date(year=2024, month=2, day=16)): 0,
    ('INE', datetime.date(year=2024, month=2, day=17)): 0,
    ('INE', datetime.date(year=2024, month=2, day=18)): 0,
    ('INE', datetime.date(year=2024, month=2, day=19)): 1,
    ('INE', datetime.date(year=2024, month=2, day=20)): 1,
    ('INE', datetime.date(year=2024, month=2, day=21)): 1,
    ('INE', datetime.date(year=2024, month=2, day=22)): 1,
    ('INE', datetime.date(year=2024, month=2, day=23)): 1,
    ('INE', datetime.date(year=2024, month=2, day=24)): 0,
    ('INE', datetime.date(year=2024, month=2, day=25)): 0,
    ('INE', datetime.date(year=2024, month=2, day=26)): 1,
    ('INE', datetime.date(year=2024, month=2, day=27)): 1,
    ('INE', datetime.date(year=2024, month=2, day=28)): 1,
    ('INE', datetime.date(year=2024, month=2, day=29)): 1,
    ('INE', datetime.date(year=2024, month=3, day=1)): 1,
    ('INE', datetime.date(year=2024, month=3, day=2)): 0,
    ('INE', datetime.date(year=2024, month=3, day=3)): 0,
    ('INE', datetime.date(year=2024, month=3, day=4)): 1,
    ('INE', datetime.date(year=2024, month=3, day=5)): 1,
    ('INE', datetime.date(year=2024, month=3, day=6)): 1,
    ('INE', datetime.date(year=2024, month=3, day=7)): 1,
    ('INE', datetime.date(year=2024, month=3, day=8)): 1,
    ('INE', datetime.date(year=2024, month=3, day=9)): 0,
    ('INE', datetime.date(year=2024, month=3, day=10)): 0,
    ('INE', datetime.date(year=2024, month=3, day=11)): 1,
    ('INE', datetime.date(year=2024, month=3, day=12)): 1,
    ('INE', datetime.date(year=2024, month=3, day=13)): 1,
    ('INE', datetime.date(year=2024, month=3, day=14)): 1,
    ('INE', datetime.date(year=2024, month=3, day=15)): 1,
    ('INE', datetime.date(year=2024, month=3, day=16)): 0,
    ('INE', datetime.date(year=2024, month=3, day=17)): 0,
    ('INE', datetime.date(year=2024, month=3, day=18)): 1,
    ('INE', datetime.date(year=2024, month=3, day=19)): 1,
    ('INE', datetime.date(year=2024, month=3, day=20)): 1,
    ('INE', datetime.date(year=2024, month=3, day=21)): 1,
    ('INE', datetime.date(year=2024, month=3, day=22)): 1,
    ('INE', datetime.date(year=2024, month=3, day=23)): 0,
    ('INE', datetime.date(year=2024, month=3, day=24)): 0,
    ('INE', datetime.date(year=2024, month=3, day=25)): 1,
    ('INE', datetime.date(year=2024, month=3, day=26)): 1,
    ('INE', datetime.date(year=2024, month=3, day=27)): 1,
    ('INE', datetime.date(year=2024, month=3, day=28)): 1,
    ('INE', datetime.date(year=2024, month=3, day=29)): 1,
    ('INE', datetime.date(year=2024, month=3, day=30)): 0,
    ('INE', datetime.date(year=2024, month=3, day=31)): 0,
    ('INE', datetime.date(year=2024, month=4, day=1)): 1,
    ('INE', datetime.date(year=2024, month=4, day=2)): 1,
    ('INE', datetime.date(year=2024, month=4, day=3)): 1,
    ('INE', datetime.date(year=2024, month=4, day=4)): 0,
    ('INE', datetime.date(year=2024, month=4, day=5)): 0,
    ('INE', datetime.date(year=2024, month=4, day=6)): 0,
    ('INE', datetime.date(year=2024, month=4, day=7)): 0,
    ('INE', datetime.date(year=2024, month=4, day=8)): 1,
    ('INE', datetime.date(year=2024, month=4, day=9)): 1,
    ('INE', datetime.date(year=2024, month=4, day=10)): 1,
    ('INE', datetime.date(year=2024, month=4, day=11)): 1,
    ('INE', datetime.date(year=2024, month=4, day=12)): 1,
    ('INE', datetime.date(year=2024, month=4, day=13)): 0,
    ('INE', datetime.date(year=2024, month=4, day=14)): 0,
    ('INE', datetime.date(year=2024, month=4, day=15)): 1,
    ('INE', datetime.date(year=2024, month=4, day=16)): 1,
    ('INE', datetime.date(year=2024, month=4, day=17)): 1,
    ('INE', datetime.date(year=2024, month=4, day=18)): 1,
    ('INE', datetime.date(year=2024, month=4, day=19)): 1,
    ('INE', datetime.date(year=2024, month=4, day=20)): 0,
    ('INE', datetime.date(year=2024, month=4, day=21)): 0,
    ('INE', datetime.date(year=2024, month=4, day=22)): 1,
    ('INE', datetime.date(year=2024, month=4, day=23)): 1,
    ('INE', datetime.date(year=2024, month=4, day=24)): 1,
    ('INE', datetime.date(year=2024, month=4, day=25)): 1,
    ('INE', datetime.date(year=2024, month=4, day=26)): 1,
    ('INE', datetime.date(year=2024, month=4, day=27)): 0,
    ('INE', datetime.date(year=2024, month=4, day=28)): 0,
    ('INE', datetime.date(year=2024, month=4, day=29)): 1,
    ('INE', datetime.date(year=2024, month=4, day=30)): 1,
    ('INE', datetime.date(year=2024, month=5, day=1)): 0,
    ('INE', datetime.date(year=2024, month=5, day=2)): 0,
    ('INE', datetime.date(year=2024, month=5, day=3)): 0,
    ('INE', datetime.date(year=2024, month=5, day=4)): 0,
    ('INE', datetime.date(year=2024, month=5, day=5)): 0,
    ('INE', datetime.date(year=2024, month=5, day=6)): 1,
    ('INE', datetime.date(year=2024, month=5, day=7)): 1,
    ('INE', datetime.date(year=2024, month=5, day=8)): 1,
    ('INE', datetime.date(year=2024, month=5, day=9)): 1,
    ('INE', datetime.date(year=2024, month=5, day=10)): 1,
    ('INE', datetime.date(year=2024, month=5, day=11)): 0,
    ('INE', datetime.date(year=2024, month=5, day=12)): 0,
    ('INE', datetime.date(year=2024, month=5, day=13)): 1,
    ('INE', datetime.date(year=2024, month=5, day=14)): 1,
    ('INE', datetime.date(year=2024, month=5, day=15)): 1,
    ('INE', datetime.date(year=2024, month=5, day=16)): 1,
    ('INE', datetime.date(year=2024, month=5, day=17)): 1,
    ('INE', datetime.date(year=2024, month=5, day=18)): 0,
    ('INE', datetime.date(year=2024, month=5, day=19)): 0,
    ('INE', datetime.date(year=2024, month=5, day=20)): 1,
    ('INE', datetime.date(year=2024, month=5, day=21)): 1,
    ('INE', datetime.date(year=2024, month=5, day=22)): 1,
    ('INE', datetime.date(year=2024, month=5, day=23)): 1,
    ('INE', datetime.date(year=2024, month=5, day=24)): 1,
    ('INE', datetime.date(year=2024, month=5, day=25)): 0,
    ('INE', datetime.date(year=2024, month=5, day=26)): 0,
    ('INE', datetime.date(year=2024, month=5, day=27)): 1,
    ('INE', datetime.date(year=2024, month=5, day=28)): 1,
    ('INE', datetime.date(year=2024, month=5, day=29)): 1,
    ('INE', datetime.date(year=2024, month=5, day=30)): 1,
    ('INE', datetime.date(year=2024, month=5, day=31)): 1,
    ('INE', datetime.date(year=2024, month=6, day=1)): 0,
    ('INE', datetime.date(year=2024, month=6, day=2)): 0,
    ('INE', datetime.date(year=2024, month=6, day=3)): 1,
    ('INE', datetime.date(year=2024, month=6, day=4)): 1,
    ('INE', datetime.date(year=2024, month=6, day=5)): 1,
    ('INE', datetime.date(year=2024, month=6, day=6)): 1,
    ('INE', datetime.date(year=2024, month=6, day=7)): 1,
    ('INE', datetime.date(year=2024, month=6, day=8)): 0,
    ('INE', datetime.date(year=2024, month=6, day=9)): 0,
    ('INE', datetime.date(year=2024, month=6, day=10)): 0,
    ('INE', datetime.date(year=2024, month=6, day=11)): 1,
    ('INE', datetime.date(year=2024, month=6, day=12)): 1,
    ('INE', datetime.date(year=2024, month=6, day=13)): 1,
    ('INE', datetime.date(year=2024, month=6, day=14)): 1,
    ('INE', datetime.date(year=2024, month=6, day=15)): 0,
    ('INE', datetime.date(year=2024, month=6, day=16)): 0,
    ('INE', datetime.date(year=2024, month=6, day=17)): 1,
    ('INE', datetime.date(year=2024, month=6, day=18)): 1,
    ('INE', datetime.date(year=2024, month=6, day=19)): 1,
    ('INE', datetime.date(year=2024, month=6, day=20)): 1,
    ('INE', datetime.date(year=2024, month=6, day=21)): 1,
    ('INE', datetime.date(year=2024, month=6, day=22)): 0,
    ('INE', datetime.date(year=2024, month=6, day=23)): 0,
    ('INE', datetime.date(year=2024, month=6, day=24)): 1,
    ('INE', datetime.date(year=2024, month=6, day=25)): 1,
    ('INE', datetime.date(year=2024, month=6, day=26)): 1,
    ('INE', datetime.date(year=2024, month=6, day=27)): 1,
    ('INE', datetime.date(year=2024, month=6, day=28)): 1,
    ('INE', datetime.date(year=2024, month=6, day=29)): 0,
    ('INE', datetime.date(year=2024, month=6, day=30)): 0,
    ('INE', datetime.date(year=2024, month=7, day=1)): 1,
    ('INE', datetime.date(year=2024, month=7, day=2)): 1,
    ('INE', datetime.date(year=2024, month=7, day=3)): 1,
    ('INE', datetime.date(year=2024, month=7, day=4)): 1,
    ('INE', datetime.date(year=2024, month=7, day=5)): 1,
    ('INE', datetime.date(year=2024, month=7, day=6)): 0,
    ('INE', datetime.date(year=2024, month=7, day=7)): 0,
    ('INE', datetime.date(year=2024, month=7, day=8)): 1,
    ('INE', datetime.date(year=2024, month=7, day=9)): 1,
    ('INE', datetime.date(year=2024, month=7, day=10)): 1,
    ('INE', datetime.date(year=2024, month=7, day=11)): 1,
    ('INE', datetime.date(year=2024, month=7, day=12)): 1,
    ('INE', datetime.date(year=2024, month=7, day=13)): 0,
    ('INE', datetime.date(year=2024, month=7, day=14)): 0,
    ('INE', datetime.date(year=2024, month=7, day=15)): 1,
    ('INE', datetime.date(year=2024, month=7, day=16)): 1,
    ('INE', datetime.date(year=2024, month=7, day=17)): 1,
    ('INE', datetime.date(year=2024, month=7, day=18)): 1,
    ('INE', datetime.date(year=2024, month=7, day=19)): 1,
    ('INE', datetime.date(year=2024, month=7, day=20)): 0,
    ('INE', datetime.date(year=2024, month=7, day=21)): 0,
    ('INE', datetime.date(year=2024, month=7, day=22)): 1,
    ('INE', datetime.date(year=2024, month=7, day=23)): 1,
    ('INE', datetime.date(year=2024, month=7, day=24)): 1,
    ('INE', datetime.date(year=2024, month=7, day=25)): 1,
    ('INE', datetime.date(year=2024, month=7, day=26)): 1,
    ('INE', datetime.date(year=2024, month=7, day=27)): 0,
    ('INE', datetime.date(year=2024, month=7, day=28)): 0,
    ('INE', datetime.date(year=2024, month=7, day=29)): 1,
    ('INE', datetime.date(year=2024, month=7, day=30)): 1,
    ('INE', datetime.date(year=2024, month=7, day=31)): 1,
    ('INE', datetime.date(year=2024, month=8, day=1)): 1,
    ('INE', datetime.date(year=2024, month=8, day=2)): 1,
    ('INE', datetime.date(year=2024, month=8, day=3)): 0,
    ('INE', datetime.date(year=2024, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=1991, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1991, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=1991, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=1991, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=1991, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=1991, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=1991, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1991, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=1991, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=1991, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=1991, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=1991, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=3)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=4)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=1991, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=1991, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=1991, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=1991, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=1991, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1991, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=1992, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=1992, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=2, day=29)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=1992, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=1992, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=1992, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=1992, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=1992, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=1992, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=1992, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=5)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=1992, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=1992, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=1992, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=1992, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1992, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=1993, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=1993, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=1993, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=1993, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=1993, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=1993, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=1993, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=1993, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=1993, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=1993, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=1993, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=1993, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1993, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=1994, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=1994, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=1994, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=1994, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=1994, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=1994, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=1994, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=1994, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=1994, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=1994, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=1994, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=1994, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1994, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=1995, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=1995, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=1995, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=1995, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=1995, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=2)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=1995, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=1995, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=1995, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=1995, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=1995, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=1995, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=1995, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=1995, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=1995, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=1995, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1995, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=1995, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=1996, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=1996, month=2, day=29)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=1996, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=1996, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=1996, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=1996, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=1996, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=1996, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=1996, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=1996, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=1996, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=1996, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=1996, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=1996, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1996, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=1997, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=1997, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=1997, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=1997, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=1997, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=1997, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=1997, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=1997, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=1997, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=1997, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=1997, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=1997, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=1997, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1997, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=1998, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=1998, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=1998, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=1998, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=1998, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=1998, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=1998, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=1998, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=1998, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=1998, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=1998, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=1998, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=1998, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1998, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=1999, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=1999, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=1999, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=1999, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=1999, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=1999, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=1999, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=1999, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=1999, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=1999, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=1999, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=1999, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=1999, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2000, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2000, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=2, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2000, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2000, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2000, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2000, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2000, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2000, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2000, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2000, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2000, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2000, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2000, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2000, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2000, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2000, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2000, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2001, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2001, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2001, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2001, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2001, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2001, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2001, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2001, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2001, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2001, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2001, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2001, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2001, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2002, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2002, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2002, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2002, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2002, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2002, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2002, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2002, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2002, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2002, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2002, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2002, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=2002, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2002, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2003, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2003, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2003, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2003, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2003, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2003, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2003, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=2003, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=2003, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=2003, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2003, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=2003, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=2003, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2003, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2004, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=2004, month=2, day=29)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=2004, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=2004, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2004, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=2004, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=2004, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=2004, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=2004, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2004, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=2004, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=2004, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2004, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2005, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2005, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2005, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2005, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2005, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2005, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2005, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2005, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2005, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2005, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2005, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2005, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2005, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2006, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2006, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2006, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2006, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2006, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2006, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2006, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2006, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2006, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2006, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2006, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2006, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2006, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2006, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2006, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2006, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2006, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2007, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2007, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2007, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2007, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2007, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2007, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2007, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2007, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2007, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2007, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2007, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2007, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2007, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2007, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2008, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2008, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=2, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2008, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2008, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2008, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2008, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2008, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=2008, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2008, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=6)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=2008, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2008, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=2008, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=2008, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2008, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2009, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2009, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=2009, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=2009, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2009, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2009, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=2009, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2009, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=2009, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2009, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=2009, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=2009, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2009, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=2009, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2009, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=2009, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=2009, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2009, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2010, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2010, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=2010, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=2010, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2010, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=2010, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=2010, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=2010, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=2010, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2010, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=2010, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=2010, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2010, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2011, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2011, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2011, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2011, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2011, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2011, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2011, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2011, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2011, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2011, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2011, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2011, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2011, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2012, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2012, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=2, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2012, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2012, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=2)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2012, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2012, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2012, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2012, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2012, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2012, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2012, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2012, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2012, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2012, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2013, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2013, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2013, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2013, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=2)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2013, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2013, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2013, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2013, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2013, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2013, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2013, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2013, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=2013, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2013, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2014, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2014, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2014, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2014, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2014, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2014, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2014, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=2014, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=2014, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=2014, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2014, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=2014, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=2014, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2014, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2015, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2015, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=2015, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=2015, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2015, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=2015, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=2015, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=2015, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=2015, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=2015, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2015, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=2015, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=2015, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2015, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2016, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=2016, month=2, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2016, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2016, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2016, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2016, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2016, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2016, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2016, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2016, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2016, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2016, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2016, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2017, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2017, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2017, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2017, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2017, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=2)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2017, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2017, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2017, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2017, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2017, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2017, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2017, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2017, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2017, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2017, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2017, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2017, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2017, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2017, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2018, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2018, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2018, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2018, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2018, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2018, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2018, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2018, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2018, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2018, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2018, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2018, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2018, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2018, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2019, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2019, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2019, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2019, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2019, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2019, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2019, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=4)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=10)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=11)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=17)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=18)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=24)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=25)): 0,
    ('SHFE', datetime.date(year=2019, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=8, day=31)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=1)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=8)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=14)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=15)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=22)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=9, day=28)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2019, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=12)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=13)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=19)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=20)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=26)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=27)): 0,
    ('SHFE', datetime.date(year=2019, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=2)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=3)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=9)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=10)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=16)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=17)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=23)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=24)): 0,
    ('SHFE', datetime.date(year=2019, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2019, month=11, day=30)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=1)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=7)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=8)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=14)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=15)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=21)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=22)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=28)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=29)): 0,
    ('SHFE', datetime.date(year=2019, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2019, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=4)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=11)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=12)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=18)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=19)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2020, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=8)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=22)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=23)): 0,
    ('SHFE', datetime.date(year=2020, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=2, day=29)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=8)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=15)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=22)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=29)): 0,
    ('SHFE', datetime.date(year=2020, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=12)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=19)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=26)): 0,
    ('SHFE', datetime.date(year=2020, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=10)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=17)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=24)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2020, month=5, day=31)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=7)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=21)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=28)): 0,
    ('SHFE', datetime.date(year=2020, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=12)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=19)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=26)): 0,
    ('SHFE', datetime.date(year=2020, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=2)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=9)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=16)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=23)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=30)): 0,
    ('SHFE', datetime.date(year=2020, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=6)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=13)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=27)): 0,
    ('SHFE', datetime.date(year=2020, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=11)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=18)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=25)): 0,
    ('SHFE', datetime.date(year=2020, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=1)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=8)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=15)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=22)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2020, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=29)): 0,
    ('SHFE', datetime.date(year=2020, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=6)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=13)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=20)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=27)): 0,
    ('SHFE', datetime.date(year=2020, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2020, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=10)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=17)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2021, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=4)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=7)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=21)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2021, month=2, day=28)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=7)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=14)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=21)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=28)): 0,
    ('SHFE', datetime.date(year=2021, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=11)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=18)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=25)): 0,
    ('SHFE', datetime.date(year=2021, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=9)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=16)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=23)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=30)): 0,
    ('SHFE', datetime.date(year=2021, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=6)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=13)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=14)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=20)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=27)): 0,
    ('SHFE', datetime.date(year=2021, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=4)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=11)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=18)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=25)): 0,
    ('SHFE', datetime.date(year=2021, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=1)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=8)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=15)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=22)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=29)): 0,
    ('SHFE', datetime.date(year=2021, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=5)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=19)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=20)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=21)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=26)): 0,
    ('SHFE', datetime.date(year=2021, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=10)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=17)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=24)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2021, month=10, day=31)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=5)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=7)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=12)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=14)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=19)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=21)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=26)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=28)): 0,
    ('SHFE', datetime.date(year=2021, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=3)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=5)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=10)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=12)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=17)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=19)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=24)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=26)): 0,
    ('SHFE', datetime.date(year=2021, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2021, month=12, day=31)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=9)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=16)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=30)): 0,
    ('SHFE', datetime.date(year=2022, month=1, day=31)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=1)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=2)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=6)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=20)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=27)): 0,
    ('SHFE', datetime.date(year=2022, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=6)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=13)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=20)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=27)): 0,
    ('SHFE', datetime.date(year=2022, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2022, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=10)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=17)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=24)): 0,
    ('SHFE', datetime.date(year=2022, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=8)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=15)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=22)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=29)): 0,
    ('SHFE', datetime.date(year=2022, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2022, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=5)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=12)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=19)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=26)): 0,
    ('SHFE', datetime.date(year=2022, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=10)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=17)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=24)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2022, month=7, day=31)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=5)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=7)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=14)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=21)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=28)): 0,
    ('SHFE', datetime.date(year=2022, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2022, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=2)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=11)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=12)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=18)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=25)): 0,
    ('SHFE', datetime.date(year=2022, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=9, day=30)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=9)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=16)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=23)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=30)): 0,
    ('SHFE', datetime.date(year=2022, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=4)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=6)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=11)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=13)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=18)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=20)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=25)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=27)): 0,
    ('SHFE', datetime.date(year=2022, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=2)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=4)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=9)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=11)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=16)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=18)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=23)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=25)): 0,
    ('SHFE', datetime.date(year=2022, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2022, month=12, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=8)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=15)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=22)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=23)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=24)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=25)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=26)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=29)): 0,
    ('SHFE', datetime.date(year=2023, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=5)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=19)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=26)): 0,
    ('SHFE', datetime.date(year=2023, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=2)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=4)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=5)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=11)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=12)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=18)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=19)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=23)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=25)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=26)): 0,
    ('SHFE', datetime.date(year=2023, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=3, day=31)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=1)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=8)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=9)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=15)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=16)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=22)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=23)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=4, day=29)): 0,
    ('SHFE', datetime.date(year=2023, month=4, day=30)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=5)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=6)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=7)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=13)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=14)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=20)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=21)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=27)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=28)): 0,
    ('SHFE', datetime.date(year=2023, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=2)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=3)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=4)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=11)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=17)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=18)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=24)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=25)): 0,
    ('SHFE', datetime.date(year=2023, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=29)): 1,
    ('SHFE', datetime.date(year=2023, month=6, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=1)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=8)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=9)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=15)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=16)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=22)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=23)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=7, day=29)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=30)): 0,
    ('SHFE', datetime.date(year=2023, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=5)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=6)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=12)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=13)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=19)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=20)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=23)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=26)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=27)): 0,
    ('SHFE', datetime.date(year=2023, month=8, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=29)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=8, day=31)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=3)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=5)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=9)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=10)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=16)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=17)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=23)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=24)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=9, day=29)): 0,
    ('SHFE', datetime.date(year=2023, month=9, day=30)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=1)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=3)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=4)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=5)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=6)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=7)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=8)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=14)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=15)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=21)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=22)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=23)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=28)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=29)): 0,
    ('SHFE', datetime.date(year=2023, month=10, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=10, day=31)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=2)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=3)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=4)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=5)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=9)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=10)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=11)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=12)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=16)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=17)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=18)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=19)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=23)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=24)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=25)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=26)): 0,
    ('SHFE', datetime.date(year=2023, month=11, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=29)): 1,
    ('SHFE', datetime.date(year=2023, month=11, day=30)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=1)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=2)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=3)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=4)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=5)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=6)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=7)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=8)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=9)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=10)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=11)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=12)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=13)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=14)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=15)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=16)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=17)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=18)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=19)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=20)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=21)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=22)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=23)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=24)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=25)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=26)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=27)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=28)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=29)): 1,
    ('SHFE', datetime.date(year=2023, month=12, day=30)): 0,
    ('SHFE', datetime.date(year=2023, month=12, day=31)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=1)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=2)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=3)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=4)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=5)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=6)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=7)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=8)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=9)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=10)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=11)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=12)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=13)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=14)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=15)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=16)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=17)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=18)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=19)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=20)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=21)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=22)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=23)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=24)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=25)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=26)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=27)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=28)): 0,
    ('SHFE', datetime.date(year=2024, month=1, day=29)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=30)): 1,
    ('SHFE', datetime.date(year=2024, month=1, day=31)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=1)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=2)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=3)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=4)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=5)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=6)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=7)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=8)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=9)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=10)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=11)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=12)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=13)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=14)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=15)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=16)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=17)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=18)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=19)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=20)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=21)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=22)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=23)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=24)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=25)): 0,
    ('SHFE', datetime.date(year=2024, month=2, day=26)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=27)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=28)): 1,
    ('SHFE', datetime.date(year=2024, month=2, day=29)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=1)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=2)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=3)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=4)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=5)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=6)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=7)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=8)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=9)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=10)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=11)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=12)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=13)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=14)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=15)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=16)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=17)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=18)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=19)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=20)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=21)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=22)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=23)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=24)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=25)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=26)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=27)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=28)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=29)): 1,
    ('SHFE', datetime.date(year=2024, month=3, day=30)): 0,
    ('SHFE', datetime.date(year=2024, month=3, day=31)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=1)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=2)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=3)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=4)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=5)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=6)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=7)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=8)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=9)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=10)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=11)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=12)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=13)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=14)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=15)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=16)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=17)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=18)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=19)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=20)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=21)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=22)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=23)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=24)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=25)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=26)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=27)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=28)): 0,
    ('SHFE', datetime.date(year=2024, month=4, day=29)): 1,
    ('SHFE', datetime.date(year=2024, month=4, day=30)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=1)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=2)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=3)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=4)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=5)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=6)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=7)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=8)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=9)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=10)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=11)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=12)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=13)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=14)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=15)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=16)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=17)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=18)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=19)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=20)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=21)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=22)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=23)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=24)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=25)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=26)): 0,
    ('SHFE', datetime.date(year=2024, month=5, day=27)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=28)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=29)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=30)): 1,
    ('SHFE', datetime.date(year=2024, month=5, day=31)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=1)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=2)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=3)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=4)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=5)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=6)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=7)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=8)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=9)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=10)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=11)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=12)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=13)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=14)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=15)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=16)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=17)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=18)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=19)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=20)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=21)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=22)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=23)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=24)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=25)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=26)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=27)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=28)): 1,
    ('SHFE', datetime.date(year=2024, month=6, day=29)): 0,
    ('SHFE', datetime.date(year=2024, month=6, day=30)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=1)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=2)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=3)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=4)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=5)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=6)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=7)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=8)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=9)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=10)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=11)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=12)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=13)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=14)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=15)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=16)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=17)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=18)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=19)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=20)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=21)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=22)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=23)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=24)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=25)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=26)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=27)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=28)): 0,
    ('SHFE', datetime.date(year=2024, month=7, day=29)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=30)): 1,
    ('SHFE', datetime.date(year=2024, month=7, day=31)): 1,
    ('SHFE', datetime.date(year=2024, month=8, day=1)): 1,
    ('SHFE', datetime.date(year=2024, month=8, day=2)): 1,
    ('SHFE', datetime.date(year=2024, month=8, day=3)): 0,
    ('SHFE', datetime.date(year=2024, month=8, day=4)): 0,
    ('SSE', datetime.date(year=1990, month=12, day=19)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=20)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=22)): 0,
    ('SSE', datetime.date(year=1990, month=12, day=23)): 0,
    ('SSE', datetime.date(year=1990, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=26)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1990, month=12, day=29)): 0,
    ('SSE', datetime.date(year=1990, month=12, day=30)): 0,
    ('SSE', datetime.date(year=1990, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=5)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=6)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=12)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=13)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=19)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=20)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=26)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=27)): 0,
    ('SSE', datetime.date(year=1991, month=1, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=1, day=31)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=1)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=2)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=3)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=9)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=10)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=15)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=16)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=17)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=18)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=23)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=24)): 0,
    ('SSE', datetime.date(year=1991, month=2, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=2, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=1)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=2)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=3)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=9)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=10)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=16)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=17)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=23)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=24)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=3, day=30)): 0,
    ('SSE', datetime.date(year=1991, month=3, day=31)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=6)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=7)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=13)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=14)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=20)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=21)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=27)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=28)): 0,
    ('SSE', datetime.date(year=1991, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=4)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=5)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=11)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=12)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=18)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=19)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=25)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=26)): 0,
    ('SSE', datetime.date(year=1991, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=5, day=31)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=1)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=2)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=8)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=9)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=15)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=16)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=22)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=23)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=6, day=29)): 0,
    ('SSE', datetime.date(year=1991, month=6, day=30)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=6)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=7)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=13)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=14)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=20)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=21)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=27)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=28)): 0,
    ('SSE', datetime.date(year=1991, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=7, day=31)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=1)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=3)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=4)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=10)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=11)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=17)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=18)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=24)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=25)): 0,
    ('SSE', datetime.date(year=1991, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=8, day=31)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=1)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=7)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=8)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=14)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=15)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=21)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=22)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=9, day=28)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=29)): 0,
    ('SSE', datetime.date(year=1991, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=5)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=6)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=12)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=13)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=19)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=20)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=26)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=27)): 0,
    ('SSE', datetime.date(year=1991, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=10, day=31)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=1)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=2)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=3)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=7)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=8)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=9)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=10)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=14)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=15)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=16)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=17)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=21)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=22)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=23)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=24)): 0,
    ('SSE', datetime.date(year=1991, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=28)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=29)): 1,
    ('SSE', datetime.date(year=1991, month=11, day=30)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=1)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=4)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=5)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=6)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=7)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=8)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=11)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=12)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=13)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=14)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=15)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=18)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=19)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=20)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=21)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=22)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=26)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=28)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=29)): 0,
    ('SSE', datetime.date(year=1991, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1991, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=4)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=5)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=11)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=12)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=18)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=19)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=25)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=26)): 0,
    ('SSE', datetime.date(year=1992, month=1, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=1, day=31)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=2)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=4)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=5)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=6)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=8)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=9)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=15)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=16)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=22)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=23)): 0,
    ('SSE', datetime.date(year=1992, month=2, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=2, day=29)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=7)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=8)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=14)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=15)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=21)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=22)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=28)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=29)): 0,
    ('SSE', datetime.date(year=1992, month=3, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=4)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=5)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=11)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=12)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=18)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=19)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=25)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=26)): 0,
    ('SSE', datetime.date(year=1992, month=4, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=2)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=3)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=9)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=10)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=16)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=17)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=23)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=24)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=5, day=30)): 0,
    ('SSE', datetime.date(year=1992, month=5, day=31)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=1)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=5)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=6)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=7)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=13)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=14)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=20)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=21)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=27)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=28)): 0,
    ('SSE', datetime.date(year=1992, month=6, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=6, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=4)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=5)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=11)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=12)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=18)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=19)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=25)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=26)): 0,
    ('SSE', datetime.date(year=1992, month=7, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=7, day=31)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=2)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=8)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=9)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=15)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=16)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=22)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=23)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=8, day=29)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=30)): 0,
    ('SSE', datetime.date(year=1992, month=8, day=31)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=5)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=6)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=12)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=13)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=19)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=20)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=26)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=27)): 0,
    ('SSE', datetime.date(year=1992, month=9, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=4)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=5)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=10)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=11)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=17)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=18)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=24)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=25)): 0,
    ('SSE', datetime.date(year=1992, month=10, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=10, day=31)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=1)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=6)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=7)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=8)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=13)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=14)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=15)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=20)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=21)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=22)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=27)): 1,
    ('SSE', datetime.date(year=1992, month=11, day=28)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=29)): 0,
    ('SSE', datetime.date(year=1992, month=11, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=4)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=5)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=6)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=7)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=11)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=12)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=13)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=14)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=18)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=19)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=20)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=26)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=27)): 0,
    ('SSE', datetime.date(year=1992, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1992, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=2)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=3)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=9)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=10)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=16)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=17)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=23)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=24)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=25)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=26)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=1, day=30)): 0,
    ('SSE', datetime.date(year=1993, month=1, day=31)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=6)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=7)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=13)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=14)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=20)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=21)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=2, day=27)): 0,
    ('SSE', datetime.date(year=1993, month=2, day=28)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=6)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=7)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=13)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=14)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=20)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=21)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=27)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=28)): 0,
    ('SSE', datetime.date(year=1993, month=3, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=3)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=4)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=10)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=11)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=17)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=18)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=24)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=25)): 0,
    ('SSE', datetime.date(year=1993, month=4, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=2)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=8)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=9)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=15)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=16)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=22)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=23)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=5, day=29)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=30)): 0,
    ('SSE', datetime.date(year=1993, month=5, day=31)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=5)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=6)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=12)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=13)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=19)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=20)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=26)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=27)): 0,
    ('SSE', datetime.date(year=1993, month=6, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=6, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=3)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=4)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=10)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=11)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=17)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=18)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=24)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=25)): 0,
    ('SSE', datetime.date(year=1993, month=7, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=7, day=31)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=1)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=7)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=8)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=14)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=15)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=21)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=22)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=28)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=29)): 0,
    ('SSE', datetime.date(year=1993, month=8, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=8, day=31)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=4)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=5)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=11)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=12)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=18)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=19)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=25)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=26)): 0,
    ('SSE', datetime.date(year=1993, month=9, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=9)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=10)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=16)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=17)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=23)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=24)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=10, day=30)): 0,
    ('SSE', datetime.date(year=1993, month=10, day=31)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=6)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=7)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=13)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=14)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=20)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=21)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=27)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=28)): 0,
    ('SSE', datetime.date(year=1993, month=11, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=11, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=4)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=5)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=6)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=7)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=11)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=12)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=13)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=14)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=18)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=19)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=20)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=25)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=26)): 0,
    ('SSE', datetime.date(year=1993, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1993, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=2)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=8)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=9)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=15)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=16)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=22)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=23)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=1, day=29)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=30)): 0,
    ('SSE', datetime.date(year=1994, month=1, day=31)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=5)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=6)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=7)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=8)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=9)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=10)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=11)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=12)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=13)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=19)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=20)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=2, day=26)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=27)): 0,
    ('SSE', datetime.date(year=1994, month=2, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=5)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=6)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=12)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=13)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=19)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=20)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=26)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=27)): 0,
    ('SSE', datetime.date(year=1994, month=3, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=2)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=3)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=9)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=10)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=16)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=17)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=23)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=24)): 0,
    ('SSE', datetime.date(year=1994, month=4, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=4, day=30)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=2)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=7)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=8)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=14)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=15)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=21)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=22)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=28)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=29)): 0,
    ('SSE', datetime.date(year=1994, month=5, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=5, day=31)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=4)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=5)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=11)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=12)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=18)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=19)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=25)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=26)): 0,
    ('SSE', datetime.date(year=1994, month=6, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=6, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=2)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=3)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=9)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=10)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=16)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=17)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=23)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=24)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=7, day=30)): 0,
    ('SSE', datetime.date(year=1994, month=7, day=31)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=6)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=7)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=13)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=14)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=20)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=21)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=27)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=28)): 0,
    ('SSE', datetime.date(year=1994, month=8, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=8, day=31)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=3)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=4)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=10)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=11)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=17)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=18)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=24)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=25)): 0,
    ('SSE', datetime.date(year=1994, month=9, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=4)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=8)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=9)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=15)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=16)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=22)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=23)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=10, day=29)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=30)): 0,
    ('SSE', datetime.date(year=1994, month=10, day=31)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=5)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=6)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=12)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=13)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=19)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=20)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=26)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=27)): 0,
    ('SSE', datetime.date(year=1994, month=11, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=11, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=3)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=4)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=5)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=6)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=7)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=10)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=11)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=12)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=13)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=14)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=17)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=18)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=19)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=20)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=24)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=25)): 0,
    ('SSE', datetime.date(year=1994, month=12, day=26)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1994, month=12, day=31)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=7)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=8)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=14)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=15)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=21)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=22)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=1, day=28)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=29)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=30)): 0,
    ('SSE', datetime.date(year=1995, month=1, day=31)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=1)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=3)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=4)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=5)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=11)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=12)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=18)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=19)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=25)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=26)): 0,
    ('SSE', datetime.date(year=1995, month=2, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=2, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=1)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=2)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=4)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=5)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=11)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=12)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=18)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=19)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=25)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=26)): 0,
    ('SSE', datetime.date(year=1995, month=3, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=30)): 1,
    ('SSE', datetime.date(year=1995, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=1)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=8)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=9)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=15)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=16)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=22)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=23)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=4, day=29)): 0,
    ('SSE', datetime.date(year=1995, month=4, day=30)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=2)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=6)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=7)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=13)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=14)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=20)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=21)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=27)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=28)): 0,
    ('SSE', datetime.date(year=1995, month=5, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=30)): 1,
    ('SSE', datetime.date(year=1995, month=5, day=31)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=1)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=3)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=4)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=10)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=11)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=17)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=18)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=24)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=25)): 0,
    ('SSE', datetime.date(year=1995, month=6, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=6, day=30)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=1)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=8)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=9)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=15)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=16)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=22)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=23)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=7, day=29)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=30)): 0,
    ('SSE', datetime.date(year=1995, month=7, day=31)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=1)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=2)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=5)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=6)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=12)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=13)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=19)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=20)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=26)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=27)): 0,
    ('SSE', datetime.date(year=1995, month=8, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=30)): 1,
    ('SSE', datetime.date(year=1995, month=8, day=31)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=3)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=9)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=10)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=16)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=17)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=23)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=24)): 0,
    ('SSE', datetime.date(year=1995, month=9, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=9, day=30)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=7)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=8)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=14)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=15)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=21)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=22)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=28)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=29)): 0,
    ('SSE', datetime.date(year=1995, month=10, day=30)): 1,
    ('SSE', datetime.date(year=1995, month=10, day=31)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=1)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=2)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=4)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=5)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=9)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=11)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=12)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=16)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=18)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=19)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=23)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=25)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=26)): 0,
    ('SSE', datetime.date(year=1995, month=11, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=11, day=30)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=2)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=3)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=4)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=5)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=6)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=7)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=9)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=10)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=11)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=12)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=13)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=14)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=16)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=17)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=18)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=19)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=20)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=23)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=24)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=26)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1995, month=12, day=30)): 0,
    ('SSE', datetime.date(year=1995, month=12, day=31)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=6)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=7)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=13)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=14)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=20)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=21)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=27)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=28)): 0,
    ('SSE', datetime.date(year=1996, month=1, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=1, day=31)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=1)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=3)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=4)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=10)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=11)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=2, day=17)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=18)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=19)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=20)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=21)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=22)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=23)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=24)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=25)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=26)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=27)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=28)): 0,
    ('SSE', datetime.date(year=1996, month=2, day=29)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=2)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=3)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=9)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=10)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=16)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=17)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=21)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=23)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=24)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=28)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=3, day=30)): 0,
    ('SSE', datetime.date(year=1996, month=3, day=31)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=6)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=7)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=13)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=14)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=20)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=21)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=27)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=28)): 0,
    ('SSE', datetime.date(year=1996, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=4)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=5)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=11)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=12)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=18)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=19)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=25)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=26)): 0,
    ('SSE', datetime.date(year=1996, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=5, day=31)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=2)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=8)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=9)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=15)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=16)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=21)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=22)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=23)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=28)): 1,
    ('SSE', datetime.date(year=1996, month=6, day=29)): 0,
    ('SSE', datetime.date(year=1996, month=6, day=30)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=6)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=7)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=13)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=14)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=20)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=21)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=27)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=28)): 0,
    ('SSE', datetime.date(year=1996, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=7, day=31)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=1)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=3)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=4)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=10)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=11)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=17)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=18)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=21)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=24)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=25)): 0,
    ('SSE', datetime.date(year=1996, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=28)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=8, day=31)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=7)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=8)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=14)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=15)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=21)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=22)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=9, day=28)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=29)): 0,
    ('SSE', datetime.date(year=1996, month=9, day=30)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=5)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=6)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=12)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=13)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=19)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=20)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=26)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=27)): 0,
    ('SSE', datetime.date(year=1996, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=10, day=31)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=1)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=2)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=3)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=7)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=8)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=9)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=10)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=14)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=15)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=16)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=17)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=21)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=22)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=23)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=24)): 0,
    ('SSE', datetime.date(year=1996, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=28)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=29)): 1,
    ('SSE', datetime.date(year=1996, month=11, day=30)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=1)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=4)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=5)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=6)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=7)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=8)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=11)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=12)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=13)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=14)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=15)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=18)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=19)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=20)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=21)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=22)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=26)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=28)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=29)): 0,
    ('SSE', datetime.date(year=1996, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1996, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=2)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=4)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=5)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=11)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=12)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=18)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=19)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=25)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=26)): 0,
    ('SSE', datetime.date(year=1997, month=1, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=1, day=31)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=2)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=3)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=4)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=5)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=6)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=7)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=8)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=9)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=10)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=11)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=12)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=13)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=14)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=15)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=16)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=22)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=23)): 0,
    ('SSE', datetime.date(year=1997, month=2, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=2, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=2)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=8)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=9)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=15)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=16)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=22)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=23)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=3, day=29)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=30)): 0,
    ('SSE', datetime.date(year=1997, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=5)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=6)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=12)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=13)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=19)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=20)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=26)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=27)): 0,
    ('SSE', datetime.date(year=1997, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=2)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=3)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=4)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=10)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=11)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=17)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=18)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=24)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=25)): 0,
    ('SSE', datetime.date(year=1997, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=5, day=31)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=7)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=8)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=14)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=15)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=21)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=22)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=6, day=28)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=29)): 0,
    ('SSE', datetime.date(year=1997, month=6, day=30)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=5)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=6)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=12)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=13)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=19)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=20)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=26)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=27)): 0,
    ('SSE', datetime.date(year=1997, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=7, day=31)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=1)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=2)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=3)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=9)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=10)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=16)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=17)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=23)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=24)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=8, day=30)): 0,
    ('SSE', datetime.date(year=1997, month=8, day=31)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=6)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=7)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=13)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=14)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=20)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=21)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=27)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=28)): 0,
    ('SSE', datetime.date(year=1997, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=4)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=5)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=11)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=12)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=18)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=19)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=25)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=26)): 0,
    ('SSE', datetime.date(year=1997, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=10, day=31)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=1)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=2)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=6)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=7)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=8)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=9)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=13)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=14)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=15)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=16)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=20)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=21)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=22)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=23)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=27)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=28)): 1,
    ('SSE', datetime.date(year=1997, month=11, day=29)): 0,
    ('SSE', datetime.date(year=1997, month=11, day=30)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=4)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=5)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=6)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=7)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=11)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=12)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=13)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=14)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=18)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=19)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=20)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=21)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=26)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=27)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=28)): 0,
    ('SSE', datetime.date(year=1997, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1997, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=2)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=3)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=4)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=10)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=11)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=17)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=18)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=1, day=24)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=25)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=26)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=27)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=28)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=29)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=30)): 0,
    ('SSE', datetime.date(year=1998, month=1, day=31)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=2)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=3)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=4)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=5)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=6)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=7)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=8)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=14)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=15)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=21)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=22)): 0,
    ('SSE', datetime.date(year=1998, month=2, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=2, day=28)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=7)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=8)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=14)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=15)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=21)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=22)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=28)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=29)): 0,
    ('SSE', datetime.date(year=1998, month=3, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=4)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=5)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=11)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=12)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=18)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=19)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=25)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=26)): 0,
    ('SSE', datetime.date(year=1998, month=4, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=2)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=3)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=9)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=10)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=16)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=17)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=23)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=24)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=5, day=30)): 0,
    ('SSE', datetime.date(year=1998, month=5, day=31)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=1)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=6)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=7)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=13)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=14)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=20)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=21)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=27)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=28)): 0,
    ('SSE', datetime.date(year=1998, month=6, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=6, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=4)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=5)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=11)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=12)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=18)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=19)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=25)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=26)): 0,
    ('SSE', datetime.date(year=1998, month=7, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=7, day=31)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=2)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=8)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=9)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=15)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=16)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=22)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=23)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=8, day=29)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=30)): 0,
    ('SSE', datetime.date(year=1998, month=8, day=31)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=5)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=6)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=12)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=13)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=19)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=20)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=26)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=27)): 0,
    ('SSE', datetime.date(year=1998, month=9, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=4)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=10)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=11)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=17)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=18)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=24)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=25)): 0,
    ('SSE', datetime.date(year=1998, month=10, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=10, day=31)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=1)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=6)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=7)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=8)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=13)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=14)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=15)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=20)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=21)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=22)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=27)): 1,
    ('SSE', datetime.date(year=1998, month=11, day=28)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=29)): 0,
    ('SSE', datetime.date(year=1998, month=11, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=4)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=5)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=6)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=7)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=11)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=12)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=13)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=14)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=18)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=19)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=20)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=25)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=26)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=27)): 0,
    ('SSE', datetime.date(year=1998, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1998, month=12, day=31)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=1)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=2)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=3)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=9)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=10)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=16)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=17)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=23)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=24)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=1, day=30)): 0,
    ('SSE', datetime.date(year=1999, month=1, day=31)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=6)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=7)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=2, day=10)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=11)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=12)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=13)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=14)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=15)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=16)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=17)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=18)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=19)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=20)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=21)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=22)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=23)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=24)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=25)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=26)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=27)): 0,
    ('SSE', datetime.date(year=1999, month=2, day=28)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=6)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=7)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=13)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=14)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=20)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=21)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=27)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=28)): 0,
    ('SSE', datetime.date(year=1999, month=3, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=3, day=31)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=3)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=4)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=10)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=11)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=17)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=18)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=24)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=25)): 0,
    ('SSE', datetime.date(year=1999, month=4, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=4, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=1)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=2)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=3)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=8)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=9)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=15)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=16)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=22)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=23)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=5, day=29)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=30)): 0,
    ('SSE', datetime.date(year=1999, month=5, day=31)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=5)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=6)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=12)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=13)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=19)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=20)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=26)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=27)): 0,
    ('SSE', datetime.date(year=1999, month=6, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=6, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=3)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=4)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=10)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=11)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=17)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=18)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=24)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=25)): 0,
    ('SSE', datetime.date(year=1999, month=7, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=7, day=31)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=1)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=7)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=8)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=14)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=15)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=21)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=22)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=28)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=29)): 0,
    ('SSE', datetime.date(year=1999, month=8, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=8, day=31)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=4)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=5)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=11)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=12)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=18)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=19)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=25)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=26)): 0,
    ('SSE', datetime.date(year=1999, month=9, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=9, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=1)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=2)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=3)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=4)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=5)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=6)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=7)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=9)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=10)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=16)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=17)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=20)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=23)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=24)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=10, day=30)): 0,
    ('SSE', datetime.date(year=1999, month=10, day=31)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=4)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=5)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=6)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=7)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=11)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=12)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=13)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=14)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=18)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=19)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=20)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=21)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=25)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=26)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=27)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=28)): 0,
    ('SSE', datetime.date(year=1999, month=11, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=11, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=1)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=2)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=3)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=4)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=5)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=6)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=7)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=8)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=9)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=10)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=11)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=12)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=13)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=14)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=15)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=16)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=17)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=18)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=19)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=20)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=21)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=22)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=23)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=24)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=25)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=26)): 0,
    ('SSE', datetime.date(year=1999, month=12, day=27)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=28)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=29)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=30)): 1,
    ('SSE', datetime.date(year=1999, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2000, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2000, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=2, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2000, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2000, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2000, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2000, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2000, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2000, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2000, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2000, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2000, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2000, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2000, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2000, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2000, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2000, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2000, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2001, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2001, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2001, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2001, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2001, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2001, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2001, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2001, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2001, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2001, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2001, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2001, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2001, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2001, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2001, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2002, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2002, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2002, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2002, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2002, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2002, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2002, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=10)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=17)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=24)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2002, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=8, day=31)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=7)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=14)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=9, day=28)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2002, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=12)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=19)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=26)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2002, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=2)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=9)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=16)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=23)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2002, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2002, month=11, day=30)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=7)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=14)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=21)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=28)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2002, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2002, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=4)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=11)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=18)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2003, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2003, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=8)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=15)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=22)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=3, day=29)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2003, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=12)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=19)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=26)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2003, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=10)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=17)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=24)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2003, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=5, day=31)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=21)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=6, day=28)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2003, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=5)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=12)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=19)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=26)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2003, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=2)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=9)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=10)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=16)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=17)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=23)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=24)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=8, day=30)): 0,
    ('SSE', datetime.date(year=2003, month=8, day=31)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=7)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=14)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=27)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=28)): 0,
    ('SSE', datetime.date(year=2003, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=11)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=12)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=18)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=19)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=25)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=26)): 0,
    ('SSE', datetime.date(year=2003, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=1)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=2)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=8)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=9)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=15)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=16)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=22)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=23)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2003, month=11, day=29)): 0,
    ('SSE', datetime.date(year=2003, month=11, day=30)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=6)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=7)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=13)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=14)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=20)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=21)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=27)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=28)): 0,
    ('SSE', datetime.date(year=2003, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2003, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=10)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=11)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=17)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=18)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2004, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=2, day=28)): 0,
    ('SSE', datetime.date(year=2004, month=2, day=29)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=7)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=14)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=21)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=28)): 0,
    ('SSE', datetime.date(year=2004, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=11)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=18)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=25)): 0,
    ('SSE', datetime.date(year=2004, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=16)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=23)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2004, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=13)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=20)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=27)): 0,
    ('SSE', datetime.date(year=2004, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=11)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=18)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=25)): 0,
    ('SSE', datetime.date(year=2004, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=1)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=8)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=15)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=22)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=29)): 0,
    ('SSE', datetime.date(year=2004, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=5)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=26)): 0,
    ('SSE', datetime.date(year=2004, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=10)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=17)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=24)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2004, month=10, day=31)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=7)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=14)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=21)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=28)): 0,
    ('SSE', datetime.date(year=2004, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=5)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=12)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=19)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=26)): 0,
    ('SSE', datetime.date(year=2004, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2004, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2005, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2005, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2005, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2005, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2005, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2005, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2005, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2005, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2005, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2005, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2005, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2005, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2005, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2006, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2006, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2006, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2006, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2006, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2006, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2006, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2006, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2006, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2006, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2006, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2006, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2006, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2006, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2006, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2006, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2006, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2007, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2007, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2007, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2007, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2007, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2007, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2007, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2007, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2007, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2007, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2007, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2007, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2007, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2007, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2008, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2008, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=2, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=1)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=8)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=15)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=22)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=3, day=29)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2008, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=12)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=19)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=26)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2008, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=10)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=17)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=24)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2008, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=5, day=31)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=21)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=6, day=28)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2008, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=5)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=12)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=19)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=26)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2008, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=2)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=9)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=10)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=16)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=17)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=23)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=24)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=8, day=30)): 0,
    ('SSE', datetime.date(year=2008, month=8, day=31)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=6)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=7)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=14)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=9, day=27)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=28)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2008, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=6)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=11)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=12)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=18)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=19)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=25)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=26)): 0,
    ('SSE', datetime.date(year=2008, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=1)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=2)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=8)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=9)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=15)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=16)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=22)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=23)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2008, month=11, day=29)): 0,
    ('SSE', datetime.date(year=2008, month=11, day=30)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=6)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=7)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=13)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=14)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=20)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=21)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=27)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=28)): 0,
    ('SSE', datetime.date(year=2008, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2008, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=4)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=10)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=11)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=17)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=18)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2009, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2009, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=2, day=28)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=7)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=8)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=14)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=15)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=21)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=22)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=28)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=29)): 0,
    ('SSE', datetime.date(year=2009, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=11)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=12)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=18)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=19)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=25)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=26)): 0,
    ('SSE', datetime.date(year=2009, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2009, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=10)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=16)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=17)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=23)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=24)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2009, month=5, day=31)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=13)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=20)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=21)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=27)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=28)): 0,
    ('SSE', datetime.date(year=2009, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2009, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=4)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=5)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=11)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=12)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=18)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=19)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=25)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=26)): 0,
    ('SSE', datetime.date(year=2009, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=2)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=8)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=9)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=15)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=16)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=22)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=23)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2009, month=8, day=29)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=30)): 0,
    ('SSE', datetime.date(year=2009, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=5)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=6)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=26)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=27)): 0,
    ('SSE', datetime.date(year=2009, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2009, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=10)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=11)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=17)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=18)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=24)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=25)): 0,
    ('SSE', datetime.date(year=2009, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=10, day=31)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=1)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=7)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=8)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=14)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=15)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=21)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=22)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2009, month=11, day=28)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=29)): 0,
    ('SSE', datetime.date(year=2009, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=5)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=6)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=12)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=13)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=19)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=20)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=26)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=27)): 0,
    ('SSE', datetime.date(year=2009, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2009, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=10)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=17)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2010, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2010, month=2, day=28)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=7)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=14)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=21)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=28)): 0,
    ('SSE', datetime.date(year=2010, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=11)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=18)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=25)): 0,
    ('SSE', datetime.date(year=2010, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=16)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=23)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2010, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=13)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=20)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=27)): 0,
    ('SSE', datetime.date(year=2010, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=4)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=11)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=18)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=25)): 0,
    ('SSE', datetime.date(year=2010, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=1)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=8)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=15)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=22)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=29)): 0,
    ('SSE', datetime.date(year=2010, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=5)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=26)): 0,
    ('SSE', datetime.date(year=2010, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=10)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=17)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=24)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2010, month=10, day=31)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=7)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=14)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=21)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=28)): 0,
    ('SSE', datetime.date(year=2010, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=5)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=12)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=19)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=26)): 0,
    ('SSE', datetime.date(year=2010, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2010, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2011, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2011, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2011, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2011, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=3)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2011, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2011, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2011, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2011, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2011, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2011, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2011, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2011, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2011, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2012, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2012, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=2, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2012, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2012, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=2)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=3)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2012, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2012, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2012, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2012, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2012, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2012, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2012, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2012, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2012, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2012, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2013, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2013, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2013, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2013, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=2)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=3)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2013, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2013, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2013, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=10)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=17)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=24)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2013, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=8, day=31)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=7)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=14)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=9, day=28)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2013, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=12)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=19)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=26)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2013, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=2)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=9)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=16)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=23)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2013, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2013, month=11, day=30)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=7)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=14)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=21)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=28)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2013, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2013, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=4)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=11)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=18)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2014, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2014, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=8)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=15)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=22)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=3, day=29)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2014, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=12)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=19)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=26)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2014, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=10)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=17)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=24)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2014, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=5, day=31)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=21)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=6, day=28)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2014, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=5)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=12)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=19)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=26)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2014, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=9)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=10)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=16)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=17)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=23)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=24)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=8, day=30)): 0,
    ('SSE', datetime.date(year=2014, month=8, day=31)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=6)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=7)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=14)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=27)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=28)): 0,
    ('SSE', datetime.date(year=2014, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=11)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=12)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=18)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=19)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=25)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=26)): 0,
    ('SSE', datetime.date(year=2014, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=1)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=2)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=8)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=9)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=15)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=16)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=22)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=23)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2014, month=11, day=29)): 0,
    ('SSE', datetime.date(year=2014, month=11, day=30)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=6)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=7)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=13)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=14)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=20)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=21)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=27)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=28)): 0,
    ('SSE', datetime.date(year=2014, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2014, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=4)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=10)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=11)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=17)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=18)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2015, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2015, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=2, day=28)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=7)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=8)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=14)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=15)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=21)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=22)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=28)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=29)): 0,
    ('SSE', datetime.date(year=2015, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=11)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=12)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=18)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=19)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=25)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=26)): 0,
    ('SSE', datetime.date(year=2015, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=10)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=16)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=17)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=23)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=24)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2015, month=5, day=31)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=13)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=20)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=21)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=27)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=28)): 0,
    ('SSE', datetime.date(year=2015, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=4)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=5)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=11)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=12)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=18)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=19)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=25)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=26)): 0,
    ('SSE', datetime.date(year=2015, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=2)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=8)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=9)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=15)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=16)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=22)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=23)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=8, day=29)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=30)): 0,
    ('SSE', datetime.date(year=2015, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=5)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=6)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=26)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=27)): 0,
    ('SSE', datetime.date(year=2015, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=10)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=11)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=17)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=18)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=24)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=25)): 0,
    ('SSE', datetime.date(year=2015, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=10, day=31)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=1)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=7)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=8)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=14)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=15)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=21)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=22)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2015, month=11, day=28)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=29)): 0,
    ('SSE', datetime.date(year=2015, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=5)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=6)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=12)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=13)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=19)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=20)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=26)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=27)): 0,
    ('SSE', datetime.date(year=2015, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2015, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=17)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2016, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=28)): 0,
    ('SSE', datetime.date(year=2016, month=2, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2016, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2016, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=3)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2016, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2016, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2016, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2016, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2016, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2016, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2016, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2016, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2016, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2017, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2017, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2017, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2017, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2017, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=2)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2017, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2017, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2017, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2017, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2017, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2017, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2017, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2017, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2017, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2017, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2017, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2017, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2017, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2017, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2018, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2018, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2018, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2018, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2018, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2018, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2018, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2018, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2018, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2018, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2018, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2018, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2018, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2018, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2019, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2019, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2019, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2019, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2019, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2019, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2019, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=4)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=10)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=11)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=17)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=18)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=24)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=25)): 0,
    ('SSE', datetime.date(year=2019, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=8, day=31)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=1)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=8)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=14)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=15)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=22)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=9, day=28)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2019, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=12)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=13)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=19)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=20)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=26)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=27)): 0,
    ('SSE', datetime.date(year=2019, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=2)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=3)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=9)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=10)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=16)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=17)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=23)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=24)): 0,
    ('SSE', datetime.date(year=2019, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2019, month=11, day=30)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=1)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=7)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=8)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=14)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=15)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=21)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=22)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=28)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=29)): 0,
    ('SSE', datetime.date(year=2019, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2019, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=4)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=11)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=12)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=18)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=19)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2020, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=8)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=22)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=23)): 0,
    ('SSE', datetime.date(year=2020, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=2, day=29)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=7)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=8)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=14)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=15)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=21)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=22)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=28)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=29)): 0,
    ('SSE', datetime.date(year=2020, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=11)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=12)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=18)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=19)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=25)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=26)): 0,
    ('SSE', datetime.date(year=2020, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=10)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=16)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=17)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=23)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=24)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2020, month=5, day=31)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=7)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=13)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=20)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=21)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=27)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=28)): 0,
    ('SSE', datetime.date(year=2020, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=4)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=11)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=12)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=18)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=19)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=25)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=26)): 0,
    ('SSE', datetime.date(year=2020, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=2)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=8)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=9)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=15)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=16)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=22)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=23)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=8, day=29)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=30)): 0,
    ('SSE', datetime.date(year=2020, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=6)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=13)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=26)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=27)): 0,
    ('SSE', datetime.date(year=2020, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=10)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=11)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=17)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=18)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=24)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=25)): 0,
    ('SSE', datetime.date(year=2020, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=10, day=31)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=1)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=7)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=8)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=14)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=15)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=21)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=22)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2020, month=11, day=28)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=29)): 0,
    ('SSE', datetime.date(year=2020, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=5)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=6)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=12)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=13)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=19)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=20)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=26)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=27)): 0,
    ('SSE', datetime.date(year=2020, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2020, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=10)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=17)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2021, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=4)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=7)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=21)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2021, month=2, day=28)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=7)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=14)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=21)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=28)): 0,
    ('SSE', datetime.date(year=2021, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=11)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=18)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=25)): 0,
    ('SSE', datetime.date(year=2021, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=9)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=16)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=23)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=30)): 0,
    ('SSE', datetime.date(year=2021, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=6)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=13)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=14)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=20)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=27)): 0,
    ('SSE', datetime.date(year=2021, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=4)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=11)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=18)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=25)): 0,
    ('SSE', datetime.date(year=2021, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=1)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=8)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=15)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=22)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=29)): 0,
    ('SSE', datetime.date(year=2021, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=5)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=19)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=20)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=21)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=26)): 0,
    ('SSE', datetime.date(year=2021, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=10)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=17)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=24)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2021, month=10, day=31)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=5)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=7)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=12)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=14)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=19)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=21)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=26)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=28)): 0,
    ('SSE', datetime.date(year=2021, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=3)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=5)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=10)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=12)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=17)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=19)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=24)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=26)): 0,
    ('SSE', datetime.date(year=2021, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2021, month=12, day=31)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=9)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=16)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=30)): 0,
    ('SSE', datetime.date(year=2022, month=1, day=31)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=1)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=2)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=6)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=20)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=27)): 0,
    ('SSE', datetime.date(year=2022, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=6)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=13)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=20)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=27)): 0,
    ('SSE', datetime.date(year=2022, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=10)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=17)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=24)): 0,
    ('SSE', datetime.date(year=2022, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=8)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=15)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=22)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=29)): 0,
    ('SSE', datetime.date(year=2022, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=5)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=12)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=19)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=26)): 0,
    ('SSE', datetime.date(year=2022, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=10)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=17)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=24)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2022, month=7, day=31)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=5)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=7)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=14)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=21)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=28)): 0,
    ('SSE', datetime.date(year=2022, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=2)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=11)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=12)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=18)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=25)): 0,
    ('SSE', datetime.date(year=2022, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=9, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=9)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=16)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=23)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=30)): 0,
    ('SSE', datetime.date(year=2022, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=4)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=6)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=11)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=13)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=18)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=20)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=25)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=27)): 0,
    ('SSE', datetime.date(year=2022, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=2)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=4)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=9)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=11)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=16)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=18)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=23)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=25)): 0,
    ('SSE', datetime.date(year=2022, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=30)): 1,
    ('SSE', datetime.date(year=2022, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=8)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=15)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=22)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=23)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=24)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=25)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=26)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=29)): 0,
    ('SSE', datetime.date(year=2023, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=5)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=19)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=26)): 0,
    ('SSE', datetime.date(year=2023, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=2)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=4)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=5)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=11)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=12)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=18)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=19)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=23)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=25)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=26)): 0,
    ('SSE', datetime.date(year=2023, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=3, day=31)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=1)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=8)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=9)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=15)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=16)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=22)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=23)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=4, day=29)): 0,
    ('SSE', datetime.date(year=2023, month=4, day=30)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=5)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=6)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=7)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=13)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=14)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=20)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=21)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=27)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=28)): 0,
    ('SSE', datetime.date(year=2023, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=2)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=3)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=4)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=11)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=17)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=18)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=24)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=25)): 0,
    ('SSE', datetime.date(year=2023, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=29)): 1,
    ('SSE', datetime.date(year=2023, month=6, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=1)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=8)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=9)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=15)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=16)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=22)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=23)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=7, day=29)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=30)): 0,
    ('SSE', datetime.date(year=2023, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=5)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=6)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=12)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=13)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=19)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=20)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=23)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=26)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=27)): 0,
    ('SSE', datetime.date(year=2023, month=8, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=29)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=8, day=31)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=3)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=5)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=9)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=10)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=16)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=17)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=23)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=24)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=9, day=29)): 0,
    ('SSE', datetime.date(year=2023, month=9, day=30)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=1)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=3)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=4)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=5)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=6)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=7)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=8)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=14)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=15)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=21)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=22)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=23)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=28)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=29)): 0,
    ('SSE', datetime.date(year=2023, month=10, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=10, day=31)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=2)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=3)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=4)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=5)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=9)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=10)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=11)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=12)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=16)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=17)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=18)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=19)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=23)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=24)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=25)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=26)): 0,
    ('SSE', datetime.date(year=2023, month=11, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=29)): 1,
    ('SSE', datetime.date(year=2023, month=11, day=30)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=1)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=2)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=3)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=4)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=5)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=6)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=7)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=8)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=9)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=10)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=11)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=12)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=13)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=14)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=15)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=16)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=17)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=18)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=19)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=20)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=21)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=22)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=23)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=24)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=25)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=26)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=27)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=28)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=29)): 1,
    ('SSE', datetime.date(year=2023, month=12, day=30)): 0,
    ('SSE', datetime.date(year=2023, month=12, day=31)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=1)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=2)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=3)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=4)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=5)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=6)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=7)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=8)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=9)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=10)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=11)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=12)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=13)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=14)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=15)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=16)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=17)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=18)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=19)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=20)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=21)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=22)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=23)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=24)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=25)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=26)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=27)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=28)): 0,
    ('SSE', datetime.date(year=2024, month=1, day=29)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=30)): 1,
    ('SSE', datetime.date(year=2024, month=1, day=31)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=1)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=2)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=3)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=4)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=5)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=6)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=7)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=8)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=9)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=10)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=11)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=12)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=13)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=14)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=15)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=16)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=17)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=18)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=19)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=20)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=21)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=22)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=23)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=24)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=25)): 0,
    ('SSE', datetime.date(year=2024, month=2, day=26)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=27)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=28)): 1,
    ('SSE', datetime.date(year=2024, month=2, day=29)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=1)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=2)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=3)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=4)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=5)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=6)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=7)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=8)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=9)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=10)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=11)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=12)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=13)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=14)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=15)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=16)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=17)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=18)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=19)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=20)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=21)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=22)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=23)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=24)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=25)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=26)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=27)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=28)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=29)): 1,
    ('SSE', datetime.date(year=2024, month=3, day=30)): 0,
    ('SSE', datetime.date(year=2024, month=3, day=31)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=1)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=2)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=3)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=4)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=5)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=6)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=7)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=8)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=9)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=10)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=11)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=12)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=13)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=14)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=15)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=16)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=17)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=18)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=19)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=20)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=21)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=22)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=23)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=24)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=25)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=26)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=27)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=28)): 0,
    ('SSE', datetime.date(year=2024, month=4, day=29)): 1,
    ('SSE', datetime.date(year=2024, month=4, day=30)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=1)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=2)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=3)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=4)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=5)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=6)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=7)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=8)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=9)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=10)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=11)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=12)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=13)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=14)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=15)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=16)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=17)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=18)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=19)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=20)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=21)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=22)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=23)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=24)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=25)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=26)): 0,
    ('SSE', datetime.date(year=2024, month=5, day=27)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=28)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=29)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=30)): 1,
    ('SSE', datetime.date(year=2024, month=5, day=31)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=1)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=2)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=3)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=4)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=5)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=6)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=7)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=8)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=9)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=10)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=11)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=12)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=13)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=14)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=15)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=16)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=17)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=18)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=19)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=20)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=21)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=22)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=23)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=24)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=25)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=26)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=27)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=28)): 1,
    ('SSE', datetime.date(year=2024, month=6, day=29)): 0,
    ('SSE', datetime.date(year=2024, month=6, day=30)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=1)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=2)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=3)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=4)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=5)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=6)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=7)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=8)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=9)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=10)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=11)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=12)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=13)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=14)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=15)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=16)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=17)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=18)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=19)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=20)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=21)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=22)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=23)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=24)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=25)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=26)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=27)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=28)): 0,
    ('SSE', datetime.date(year=2024, month=7, day=29)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=30)): 1,
    ('SSE', datetime.date(year=2024, month=7, day=31)): 1,
    ('SSE', datetime.date(year=2024, month=8, day=1)): 1,
    ('SSE', datetime.date(year=2024, month=8, day=2)): 1,
    ('SSE', datetime.date(year=2024, month=8, day=3)): 0,
    ('SSE', datetime.date(year=2024, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=1991, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1991, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=1991, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=1991, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=1991, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=1991, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=3)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=4)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=1991, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=1991, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=1991, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=1991, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=1991, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1991, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=1992, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=1992, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=2, day=29)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=1992, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=1992, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=1992, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=1992, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=1992, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=1992, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=1992, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=5)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=1992, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=1992, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=1992, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=1992, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1992, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=1993, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=1993, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=1993, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=1993, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=1993, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=1993, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=1993, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=1993, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=1993, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=1993, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=1993, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=1993, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1993, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=1994, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=1994, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=1994, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=1994, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=1994, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=1994, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=1994, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=1994, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=1994, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=1994, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=1994, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=1994, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1994, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=1995, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=1995, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=1995, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=1995, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=1995, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=2)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=1995, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=1995, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=1995, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=1995, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=1995, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=1995, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=1995, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=1995, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=1995, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=1995, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1995, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=1995, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=1996, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=1996, month=2, day=29)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=1996, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=1996, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=1996, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=1996, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=1996, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=1996, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=1996, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=1996, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=1996, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=1996, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=1996, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=1996, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1996, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=1997, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=1997, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=1997, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=1997, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=1997, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=1997, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=1997, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=1997, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=1997, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=1997, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=1997, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=1997, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=1997, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1997, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=1998, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=1998, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=1998, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=1998, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=1998, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=1998, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=1998, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=1998, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=1998, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=1998, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=1998, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=1998, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=1998, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1998, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=1999, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=1999, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=1999, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=1999, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=1999, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=1999, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=1999, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=1999, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=1999, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=1999, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=1999, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=1999, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=1999, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2000, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2000, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=2, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2000, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2000, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2000, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2000, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2000, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2000, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2000, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2000, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2000, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2000, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2000, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2000, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2000, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2000, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2000, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2001, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2001, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2001, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2001, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2001, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2001, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2001, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2001, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2001, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2001, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2001, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2001, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2001, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2001, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2001, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2002, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2002, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2002, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2002, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2002, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2002, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2002, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2002, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2002, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2002, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2002, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2002, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2002, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2002, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2003, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2003, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2003, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2003, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2003, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2003, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2003, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=2003, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=2003, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=2003, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2003, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=2003, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=2003, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2003, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2004, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=2004, month=2, day=29)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=2004, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=2004, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2004, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=2004, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=2004, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=2004, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=2004, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2004, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=2004, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=2004, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2004, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2005, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2005, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2005, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2005, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2005, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2005, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2005, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2005, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2005, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2005, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2005, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2005, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2005, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2006, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2006, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2006, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2006, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2006, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2006, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2006, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2006, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2006, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2006, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2006, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2006, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2006, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2006, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2006, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2006, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2006, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2007, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2007, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2007, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2007, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2007, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2007, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2007, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2007, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2007, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2007, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2007, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2007, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2007, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2007, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2008, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2008, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=2, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2008, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2008, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2008, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2008, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2008, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=2008, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2008, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=6)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=2008, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2008, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=2008, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=2008, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2008, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2009, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2009, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=2009, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=2009, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2009, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2009, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=2009, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2009, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=2009, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2009, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=2009, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=2009, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2009, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=2009, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2009, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=2009, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=2009, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2009, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2010, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2010, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=2010, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=2010, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2010, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=2010, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=2010, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=2010, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=2010, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2010, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=2010, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=2010, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2010, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2011, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2011, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2011, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2011, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2011, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2011, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2011, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2011, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2011, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2011, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2011, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2011, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2011, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2012, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2012, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=2, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2012, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2012, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=2)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2012, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2012, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2012, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2012, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2012, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2012, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2012, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2012, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2012, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2012, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2013, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2013, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2013, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2013, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=2)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2013, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2013, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2013, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2013, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2013, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2013, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2013, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2013, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2013, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2013, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2014, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2014, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2014, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2014, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2014, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2014, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2014, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=2014, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=2014, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=2014, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2014, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=2014, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=2014, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2014, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2015, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2015, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=2015, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=2015, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2015, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=2015, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=2015, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=2015, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=2015, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=2015, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2015, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=2015, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=2015, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2015, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2016, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=2016, month=2, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2016, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2016, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2016, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2016, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2016, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2016, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2016, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2016, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2016, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2016, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2016, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2017, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2017, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2017, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2017, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2017, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=2)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2017, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2017, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2017, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2017, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2017, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2017, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2017, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2017, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2017, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2017, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2017, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2017, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2017, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2017, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2018, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2018, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2018, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2018, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2018, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2018, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2018, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2018, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2018, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2018, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2018, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2018, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2018, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2018, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2019, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2019, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2019, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2019, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2019, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2019, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2019, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=4)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=10)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=11)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=17)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=18)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=24)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=25)): 0,
    ('SZSE', datetime.date(year=2019, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=8, day=31)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=1)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=8)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=14)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=15)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=22)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=9, day=28)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2019, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=12)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=13)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=19)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=20)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=26)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=27)): 0,
    ('SZSE', datetime.date(year=2019, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=2)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=3)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=9)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=10)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=16)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=17)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=23)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=24)): 0,
    ('SZSE', datetime.date(year=2019, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2019, month=11, day=30)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=1)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=7)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=8)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=14)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=15)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=21)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=22)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=28)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=29)): 0,
    ('SZSE', datetime.date(year=2019, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2019, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=4)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=11)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=12)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=18)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=19)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2020, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=8)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=22)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=23)): 0,
    ('SZSE', datetime.date(year=2020, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=2, day=29)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=8)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=15)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=22)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=29)): 0,
    ('SZSE', datetime.date(year=2020, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=12)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=19)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=26)): 0,
    ('SZSE', datetime.date(year=2020, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=10)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=17)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=24)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2020, month=5, day=31)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=7)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=21)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=28)): 0,
    ('SZSE', datetime.date(year=2020, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=12)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=19)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=26)): 0,
    ('SZSE', datetime.date(year=2020, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=2)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=9)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=16)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=23)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=30)): 0,
    ('SZSE', datetime.date(year=2020, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=6)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=13)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=27)): 0,
    ('SZSE', datetime.date(year=2020, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=11)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=18)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=25)): 0,
    ('SZSE', datetime.date(year=2020, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=1)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=8)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=15)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=22)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2020, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=29)): 0,
    ('SZSE', datetime.date(year=2020, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=6)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=13)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=20)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=27)): 0,
    ('SZSE', datetime.date(year=2020, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2020, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=10)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=17)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2021, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=4)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=7)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=21)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2021, month=2, day=28)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=7)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=14)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=21)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=28)): 0,
    ('SZSE', datetime.date(year=2021, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=11)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=18)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=25)): 0,
    ('SZSE', datetime.date(year=2021, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=9)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=16)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=23)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=30)): 0,
    ('SZSE', datetime.date(year=2021, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=6)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=13)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=14)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=20)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=27)): 0,
    ('SZSE', datetime.date(year=2021, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=4)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=11)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=18)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=25)): 0,
    ('SZSE', datetime.date(year=2021, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=1)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=8)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=15)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=22)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=29)): 0,
    ('SZSE', datetime.date(year=2021, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=5)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=19)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=20)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=21)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=26)): 0,
    ('SZSE', datetime.date(year=2021, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=10)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=17)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=24)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2021, month=10, day=31)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=5)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=7)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=12)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=14)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=19)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=21)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=26)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=28)): 0,
    ('SZSE', datetime.date(year=2021, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=3)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=5)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=10)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=12)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=17)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=19)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=24)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=26)): 0,
    ('SZSE', datetime.date(year=2021, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2021, month=12, day=31)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=9)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=16)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=30)): 0,
    ('SZSE', datetime.date(year=2022, month=1, day=31)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=1)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=2)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=6)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=20)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=27)): 0,
    ('SZSE', datetime.date(year=2022, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=6)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=13)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=20)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=27)): 0,
    ('SZSE', datetime.date(year=2022, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=10)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=17)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=24)): 0,
    ('SZSE', datetime.date(year=2022, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=8)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=15)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=22)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=29)): 0,
    ('SZSE', datetime.date(year=2022, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=5)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=12)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=19)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=26)): 0,
    ('SZSE', datetime.date(year=2022, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=10)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=17)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=24)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2022, month=7, day=31)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=5)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=7)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=14)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=21)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=28)): 0,
    ('SZSE', datetime.date(year=2022, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=2)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=11)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=12)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=18)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=25)): 0,
    ('SZSE', datetime.date(year=2022, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=9, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=9)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=16)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=23)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=30)): 0,
    ('SZSE', datetime.date(year=2022, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=4)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=6)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=11)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=13)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=18)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=20)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=25)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=27)): 0,
    ('SZSE', datetime.date(year=2022, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=2)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=4)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=9)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=11)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=16)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=18)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=23)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=25)): 0,
    ('SZSE', datetime.date(year=2022, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=30)): 1,
    ('SZSE', datetime.date(year=2022, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=8)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=15)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=22)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=23)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=24)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=25)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=26)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=29)): 0,
    ('SZSE', datetime.date(year=2023, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=5)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=19)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=26)): 0,
    ('SZSE', datetime.date(year=2023, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=2)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=4)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=5)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=11)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=12)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=18)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=19)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=23)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=25)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=26)): 0,
    ('SZSE', datetime.date(year=2023, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=3, day=31)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=1)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=8)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=9)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=15)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=16)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=22)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=23)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=4, day=29)): 0,
    ('SZSE', datetime.date(year=2023, month=4, day=30)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=5)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=6)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=7)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=13)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=14)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=20)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=21)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=27)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=28)): 0,
    ('SZSE', datetime.date(year=2023, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=2)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=3)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=4)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=11)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=17)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=18)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=24)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=25)): 0,
    ('SZSE', datetime.date(year=2023, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=29)): 1,
    ('SZSE', datetime.date(year=2023, month=6, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=1)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=8)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=9)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=15)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=16)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=22)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=23)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=7, day=29)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=30)): 0,
    ('SZSE', datetime.date(year=2023, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=5)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=6)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=12)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=13)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=19)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=20)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=23)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=26)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=27)): 0,
    ('SZSE', datetime.date(year=2023, month=8, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=29)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=8, day=31)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=3)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=5)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=9)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=10)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=16)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=17)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=23)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=24)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=9, day=29)): 0,
    ('SZSE', datetime.date(year=2023, month=9, day=30)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=1)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=3)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=4)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=5)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=6)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=7)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=8)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=14)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=15)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=21)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=22)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=23)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=28)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=29)): 0,
    ('SZSE', datetime.date(year=2023, month=10, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=10, day=31)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=2)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=3)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=4)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=5)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=9)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=10)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=11)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=12)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=16)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=17)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=18)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=19)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=23)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=24)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=25)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=26)): 0,
    ('SZSE', datetime.date(year=2023, month=11, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=29)): 1,
    ('SZSE', datetime.date(year=2023, month=11, day=30)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=1)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=2)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=3)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=4)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=5)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=6)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=7)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=8)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=9)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=10)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=11)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=12)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=13)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=14)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=15)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=16)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=17)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=18)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=19)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=20)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=21)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=22)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=23)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=24)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=25)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=26)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=27)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=28)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=29)): 1,
    ('SZSE', datetime.date(year=2023, month=12, day=30)): 0,
    ('SZSE', datetime.date(year=2023, month=12, day=31)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=1)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=2)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=3)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=4)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=5)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=6)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=7)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=8)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=9)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=10)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=11)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=12)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=13)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=14)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=15)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=16)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=17)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=18)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=19)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=20)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=21)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=22)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=23)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=24)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=25)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=26)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=27)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=28)): 0,
    ('SZSE', datetime.date(year=2024, month=1, day=29)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=30)): 1,
    ('SZSE', datetime.date(year=2024, month=1, day=31)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=1)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=2)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=3)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=4)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=5)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=6)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=7)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=8)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=9)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=10)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=11)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=12)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=13)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=14)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=15)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=16)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=17)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=18)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=19)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=20)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=21)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=22)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=23)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=24)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=25)): 0,
    ('SZSE', datetime.date(year=2024, month=2, day=26)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=27)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=28)): 1,
    ('SZSE', datetime.date(year=2024, month=2, day=29)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=1)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=2)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=3)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=4)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=5)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=6)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=7)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=8)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=9)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=10)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=11)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=12)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=13)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=14)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=15)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=16)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=17)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=18)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=19)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=20)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=21)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=22)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=23)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=24)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=25)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=26)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=27)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=28)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=29)): 1,
    ('SZSE', datetime.date(year=2024, month=3, day=30)): 0,
    ('SZSE', datetime.date(year=2024, month=3, day=31)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=1)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=2)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=3)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=4)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=5)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=6)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=7)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=8)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=9)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=10)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=11)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=12)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=13)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=14)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=15)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=16)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=17)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=18)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=19)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=20)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=21)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=22)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=23)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=24)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=25)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=26)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=27)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=28)): 0,
    ('SZSE', datetime.date(year=2024, month=4, day=29)): 1,
    ('SZSE', datetime.date(year=2024, month=4, day=30)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=1)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=2)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=3)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=4)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=5)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=6)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=7)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=8)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=9)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=10)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=11)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=12)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=13)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=14)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=15)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=16)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=17)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=18)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=19)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=20)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=21)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=22)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=23)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=24)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=25)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=26)): 0,
    ('SZSE', datetime.date(year=2024, month=5, day=27)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=28)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=29)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=30)): 1,
    ('SZSE', datetime.date(year=2024, month=5, day=31)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=1)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=2)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=3)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=4)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=5)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=6)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=7)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=8)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=9)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=10)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=11)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=12)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=13)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=14)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=15)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=16)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=17)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=18)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=19)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=20)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=21)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=22)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=23)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=24)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=25)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=26)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=27)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=28)): 1,
    ('SZSE', datetime.date(year=2024, month=6, day=29)): 0,
    ('SZSE', datetime.date(year=2024, month=6, day=30)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=1)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=2)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=3)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=4)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=5)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=6)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=7)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=8)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=9)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=10)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=11)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=12)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=13)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=14)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=15)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=16)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=17)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=18)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=19)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=20)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=21)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=22)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=23)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=24)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=25)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=26)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=27)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=28)): 0,
    ('SZSE', datetime.date(year=2024, month=7, day=29)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=30)): 1,
    ('SZSE', datetime.date(year=2024, month=7, day=31)): 1,
    ('SZSE', datetime.date(year=2024, month=8, day=1)): 1,
    ('SZSE', datetime.date(year=2024, month=8, day=2)): 1,
    ('SZSE', datetime.date(year=2024, month=8, day=3)): 0,
    ('SZSE', datetime.date(year=2024, month=8, day=4)): 0,
}
